@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.adapter.readers.cif");
-Clazz.load (["J.adapter.readers.cif.CifReader"], "J.adapter.readers.cif.MMCifReader", ["java.util.Hashtable", "JU.BS", "$.Lst", "$.M4", "$.P3", "$.PT", "$.SB", "J.adapter.smarter.Atom", "$.Structure", "J.api.Interface", "$.JmolAdapter", "J.c.STR", "JU.Logger"], function () {
+Clazz.load (["J.adapter.readers.cif.CifReader"], "J.adapter.readers.cif.MMCifReader", ["java.util.Hashtable", "JU.BS", "$.Lst", "$.M4", "$.P3", "$.PT", "$.Rdr", "$.SB", "J.adapter.smarter.Atom", "$.Structure", "J.c.STR", "JU.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.isBiomolecule = false;
 this.byChain = false;
@@ -14,6 +14,7 @@ this.assemblyIdAtoms = null;
 this.thisChain = -1;
 this.chainSum = null;
 this.chainAtomCount = null;
+this.isLigandBondBug = false;
 this.assem = null;
 this.hetatmData = null;
 this.htHetero = null;
@@ -26,11 +27,12 @@ this.isMMCIF = true;
 this.byChain = this.checkFilterKey ("BYCHAIN");
 this.bySymop = this.checkFilterKey ("BYSYMOP");
 this.isCourseGrained = this.byChain || this.bySymop;
-if (this.byChain) {
+if (this.isCourseGrained) {
 this.chainAtomMap =  new java.util.Hashtable ();
 this.chainAtomCounts =  new java.util.Hashtable ();
 }if (this.checkFilterKey ("BIOMOLECULE")) this.filter = JU.PT.rep (this.filter, "BIOMOLECULE", "ASSEMBLY");
 this.isBiomolecule = this.checkFilterKey ("ASSEMBLY");
+this.isLigandBondBug = (this.stateScriptVersionInt >= 140204 && this.stateScriptVersionInt <= 140208 || this.stateScriptVersionInt >= 140304 && this.stateScriptVersionInt <= 140308);
 });
 Clazz.overrideMethod (c$, "finalizeSubclass", 
 function () {
@@ -39,14 +41,21 @@ if (this.byChain && !this.isBiomolecule) for (var id, $id = this.chainAtomMap.ke
 if (!this.isCourseGrained && this.asc.ac == this.nAtoms) {
 this.asc.removeCurrentAtomSet ();
 } else {
-if (this.validation != null && !this.isCourseGrained) {
-var vs = (J.api.Interface.getInterface ("J.adapter.readers.cif.MMCifValidationParser")).set (this);
-var note = vs.finalizeValidations (this.modelMap);
-if (note != null) this.appendLoadNote (note);
-}this.applySymmetryAndSetTrajectory ();
+if ((this.validation != null || this.addedData != null) && !this.isCourseGrained) {
+var vs = (this.getInterface ("J.adapter.readers.cif.MMCifValidationParser")).set (this);
+var note = null;
+if (this.addedData == null) {
+note = vs.finalizeValidations (this.modelMap);
+} else if (this.addedDataKey.equals ("_rna3d")) {
+note = vs.finalizeRna3d (this.modelMap);
+} else {
+this.reader = JU.Rdr.getBR (this.addedData);
+this.processDSSR (this, this.htGroup1);
+}if (note != null) this.appendLoadNote (note);
+}if (!this.isCourseGrained) this.applySymmetryAndSetTrajectory ();
 }if (this.htSites != null) this.addSites (this.htSites);
 if (this.vBiomolecules != null && this.vBiomolecules.size () == 1 && (this.isCourseGrained || this.asc.ac > 0)) {
-this.asc.setAtomSetAuxiliaryInfo ("biomolecules", this.vBiomolecules);
+this.asc.setCurrentModelInfo ("biomolecules", this.vBiomolecules);
 var ht = this.vBiomolecules.get (0);
 this.appendLoadNote ("Constructing " + ht.get ("name"));
 this.setBiomolecules (ht);
@@ -58,6 +67,12 @@ Clazz.overrideMethod (c$, "processSubclassEntry",
 function () {
 if (this.key.startsWith ("_pdbx_entity_nonpoly")) this.processDataNonpoly ();
  else if (this.key.startsWith ("_pdbx_struct_assembly_gen")) this.processDataAssemblyGen ();
+ else if (this.key.equals ("_rna3d") || this.key.equals ("_dssr")) this.processAddedData ();
+});
+Clazz.defineMethod (c$, "processAddedData", 
+ function () {
+this.addedData = this.data;
+this.addedDataKey = this.key;
 });
 Clazz.defineMethod (c$, "processSequence", 
  function () {
@@ -102,7 +117,7 @@ if (this.assem[0] != null && this.assem[1] != null && this.assem[2] != null) thi
 });
 Clazz.defineMethod (c$, "processAssemblyGenBlock", 
  function () {
-this.parseLoopParameters (J.adapter.readers.cif.MMCifReader.assemblyFields);
+this.parseLoopParametersFor ("_pdbx_struct_assembly_gen", J.adapter.readers.cif.MMCifReader.assemblyFields);
 while (this.parser.getData ()) {
 this.assem =  new Array (3);
 var count = 0;
@@ -129,7 +144,7 @@ var id = this.assem[0];
 var iMolecule = this.parseIntStr (id);
 var list = this.assem[2];
 this.appendLoadNote ("found biomolecule " + id + ": " + list);
-if (!this.checkFilterKey ("ASSEMBLY " + id + ";")) return;
+if (!this.checkFilterKey ("ASSEMBLY " + id + ";") && !this.checkFilterKey ("ASSEMBLY=" + id + ";")) return;
 if (this.vBiomolecules == null) {
 this.vBiomolecules =  new JU.Lst ();
 }var info =  new java.util.Hashtable ();
@@ -148,7 +163,7 @@ Clazz.defineMethod (c$, "decodeAssemblyOperators",
 var pt = ops.indexOf (")(");
 if (pt >= 0) return this.crossBinary (this.decodeAssemblyOperators (ops.substring (0, pt + 1)), this.decodeAssemblyOperators (ops.substring (pt + 1)));
 if (ops.startsWith ("(")) {
-if (ops.indexOf ("-") >= 0) ops = JU.BS.unescape ("({" + ops.substring (1, ops.length - 1).$replace ('-', ':') + "})").toString ();
+if (ops.indexOf ("-") >= 0) ops = JU.BS.unescape ("({" + ops.substring (1, ops.length - 1).$replace ('-', ':') + "})").toJSON ();
 ops = JU.PT.rep (ops, " ", "");
 ops = ops.substring (1, ops.length - 1);
 }return ops;
@@ -165,7 +180,7 @@ return sb.toString ().substring (1);
 }, "~S,~S");
 Clazz.defineMethod (c$, "processStructOperListBlock", 
  function () {
-this.parseLoopParameters (J.adapter.readers.cif.MMCifReader.operFields);
+this.parseLoopParametersFor ("_pdbx_struct_oper_list", J.adapter.readers.cif.MMCifReader.operFields);
 var m =  Clazz.newFloatArray (16, 0);
 m[15] = 1;
 while (this.parser.getData ()) {
@@ -253,7 +268,7 @@ return true;
 });
 Clazz.defineMethod (c$, "addHetero", 
  function (groupName, hetName) {
-if (!J.api.JmolAdapter.isHetero (groupName)) return;
+if (!this.vwr.getJBR ().isHetero (groupName)) return;
 if (this.htHetero == null) this.htHetero =  new java.util.Hashtable ();
 this.htHetero.put (groupName, hetName);
 if (JU.Logger.debugging) {
@@ -261,7 +276,7 @@ JU.Logger.debug ("hetero: " + groupName + " = " + hetName);
 }}, "~S,~S");
 Clazz.defineMethod (c$, "processStructConfLoopBlock", 
  function () {
-this.parseLoopParameters (J.adapter.readers.cif.MMCifReader.structConfFields);
+this.parseLoopParametersFor ("_struct_conf", J.adapter.readers.cif.MMCifReader.structConfFields);
 for (var i = this.propertyCount; --i >= 0; ) if (this.fieldOf[i] == -1) {
 JU.Logger.warn ("?que? missing property: " + J.adapter.readers.cif.MMCifReader.structConfFields[i]);
 return false;
@@ -279,7 +294,7 @@ if (this.field.startsWith ("TURN")) structure.structureType = structure.substruc
 break;
 case 1:
 structure.startChainStr = this.field;
-structure.startChainID = this.vwr.getChainID (this.field);
+structure.startChainID = this.vwr.getChainID (this.field, true);
 break;
 case 2:
 structure.startSequenceNumber = this.parseIntStr (this.field);
@@ -289,7 +304,7 @@ structure.startInsertionCode = this.firstChar;
 break;
 case 4:
 structure.endChainStr = this.field;
-structure.endChainID = this.vwr.getChainID (this.field);
+structure.endChainID = this.vwr.getChainID (this.field, true);
 break;
 case 5:
 structure.endSequenceNumber = this.parseIntStr (this.field);
@@ -314,7 +329,7 @@ return true;
 });
 Clazz.defineMethod (c$, "processStructSheetRangeLoopBlock", 
  function () {
-this.parseLoopParameters (J.adapter.readers.cif.MMCifReader.structSheetRangeFields);
+this.parseLoopParametersFor ("_struct_sheet_range", J.adapter.readers.cif.MMCifReader.structSheetRangeFields);
 for (var i = this.propertyCount; --i >= 0; ) if (this.fieldOf[i] == -1) {
 JU.Logger.warn ("?que? missing property:" + J.adapter.readers.cif.MMCifReader.structSheetRangeFields[i]);
 return false;
@@ -325,7 +340,7 @@ var n = this.parser.getFieldCount ();
 for (var i = 0; i < n; ++i) {
 switch (this.fieldProperty (i)) {
 case 1:
-structure.startChainID = this.vwr.getChainID (this.field);
+structure.startChainID = this.vwr.getChainID (this.field, true);
 break;
 case 2:
 structure.startSequenceNumber = this.parseIntStr (this.field);
@@ -334,7 +349,7 @@ case 3:
 structure.startInsertionCode = this.firstChar;
 break;
 case 4:
-structure.endChainID = this.vwr.getChainID (this.field);
+structure.endChainID = this.vwr.getChainID (this.field, true);
 break;
 case 5:
 structure.endSequenceNumber = this.parseIntStr (this.field);
@@ -355,16 +370,11 @@ this.asc.addStructure (structure);
 }
 return true;
 });
-Clazz.defineMethod (c$, "parseSubclassLoopParameters", 
-function (fields) {
-this.parseLoopParameters (fields);
-this.propertyCount = fields.length;
-}, "~A");
 Clazz.defineMethod (c$, "processStructSiteBlock", 
  function () {
-this.parseLoopParameters (J.adapter.readers.cif.MMCifReader.structSiteRangeFields);
+this.parseLoopParametersFor ("_struct_site_gen", J.adapter.readers.cif.MMCifReader.structSiteFields);
 for (var i = 3; --i >= 0; ) if (this.fieldOf[i] == -1) {
-JU.Logger.warn ("?que? missing property: " + J.adapter.readers.cif.MMCifReader.structSiteRangeFields[i]);
+JU.Logger.warn ("?que? missing property: " + J.adapter.readers.cif.MMCifReader.structSiteFields[i]);
 return false;
 }
 var siteID = "";
@@ -461,6 +471,7 @@ var a1 =  new J.adapter.smarter.Atom ();
 a1.setT (sum);
 a1.scale (1 / count);
 a1.radius = 16;
+this.asc.addAtom (a1);
 }} else {
 nAtoms = bsAll.cardinality ();
 if (nAtoms < this.asc.ac) this.asc.bsAtoms = bsAll;
@@ -474,7 +485,7 @@ var a =  new J.adapter.smarter.Atom ();
 a.setT (asum);
 a.scale (1 / c);
 a.elementSymbol = "Pt";
-a.chainID = this.vwr.getChainID (id);
+this.setChainID (a, id);
 a.radius = 16;
 this.asc.addAtom (a);
 }, "~S");
@@ -490,7 +501,8 @@ return m;
 }, "~S");
 Clazz.defineMethod (c$, "processLigandBondLoopBlock", 
  function () {
-this.parseLoopParameters (J.adapter.readers.cif.MMCifReader.chemCompBondFields);
+this.parseLoopParametersFor ("_chem_comp_bond", J.adapter.readers.cif.MMCifReader.chemCompBondFields);
+if (this.isLigandBondBug) return false;
 for (var i = this.propertyCount; --i >= 0; ) if (this.fieldOf[i] == -1) {
 JU.Logger.warn ("?que? missing property: " + J.adapter.readers.cif.MMCifReader.chemCompBondFields[i]);
 return false;
@@ -558,7 +570,7 @@ var bs = this.assemblyIdAtoms.get (assemblyId);
 if (bs == null) this.assemblyIdAtoms.put (assemblyId, bs =  new JU.BS ());
 bs.set (this.ac);
 }if (atom.isHetero && this.htHetero != null) {
-this.asc.setAtomSetAuxiliaryInfo ("hetNames", this.htHetero);
+this.asc.setCurrentModelInfo ("hetNames", this.htHetero);
 this.asc.setInfo ("hetNames", this.htHetero);
 this.htHetero = null;
 }return true;
@@ -580,11 +592,13 @@ return false;
 Clazz.defineStatics (c$,
 "OPER_ID", 12,
 "OPER_XYZ", 13,
-"operFields", ["_pdbx_struct_oper_list_matrix[1][1]", "_pdbx_struct_oper_list_matrix[1][2]", "_pdbx_struct_oper_list_matrix[1][3]", "_pdbx_struct_oper_list_vector[1]", "_pdbx_struct_oper_list_matrix[2][1]", "_pdbx_struct_oper_list_matrix[2][2]", "_pdbx_struct_oper_list_matrix[2][3]", "_pdbx_struct_oper_list_vector[2]", "_pdbx_struct_oper_list_matrix[3][1]", "_pdbx_struct_oper_list_matrix[3][2]", "_pdbx_struct_oper_list_matrix[3][3]", "_pdbx_struct_oper_list_vector[3]", "_pdbx_struct_oper_list_id", "_pdbx_struct_oper_list_symmetry_operation"],
+"FAMILY_OPER", "_pdbx_struct_oper_list",
+"operFields", ["*_matrix[1][1]", "*_matrix[1][2]", "*_matrix[1][3]", "*_vector[1]", "*_matrix[2][1]", "*_matrix[2][2]", "*_matrix[2][3]", "*_vector[2]", "*_matrix[3][1]", "*_matrix[3][2]", "*_matrix[3][3]", "*_vector[3]", "*_id", "*_symmetry_operation"],
 "ASSEM_ID", 0,
 "ASSEM_OPERS", 1,
 "ASSEM_LIST", 2,
-"assemblyFields", ["_pdbx_struct_assembly_gen_assembly_id", "_pdbx_struct_assembly_gen_oper_expression", "_pdbx_struct_assembly_gen_asym_id_list"],
+"FAMILY_ASSEM", "_pdbx_struct_assembly_gen",
+"assemblyFields", ["*_assembly_id", "*_oper_expression", "*_asym_id_list"],
 "STRUCT_REF_G3", 0,
 "STRUCT_REF_G1", 1,
 "structRefFields", ["_struct_ref_seq_dif_mon_id", "_struct_ref_seq_dif.db_mon_id"],
@@ -605,19 +619,23 @@ Clazz.defineStatics (c$,
 "STRUCT_ID", 7,
 "SERIAL_NO", 8,
 "HELIX_CLASS", 9,
-"structConfFields", ["_struct_conf_conf_type_id", "_struct_conf_beg_auth_asym_id", "_struct_conf_beg_auth_seq_id", "_struct_conf_pdbx_beg_pdb_ins_code", "_struct_conf_end_auth_asym_id", "_struct_conf_end_auth_seq_id", "_struct_conf_pdbx_end_pdb_ins_code", "_struct_conf_id", "_struct_conf_pdbx_pdb_helix_id", "_struct_conf_pdbx_pdb_helix_class"],
+"structConfFields", ["*_conf_type_id", "*_beg_auth_asym_id", "*_beg_auth_seq_id", "*_pdbx_beg_pdb_ins_code", "*_end_auth_asym_id", "*_end_auth_seq_id", "*_pdbx_end_pdb_ins_code", "*_id", "*_pdbx_pdb_helix_id", "*_pdbx_pdb_helix_class"],
+"FAMILY_STRUCTCONF", "_struct_conf",
 "SHEET_ID", 0,
 "STRAND_ID", 7,
-"structSheetRangeFields", ["_struct_sheet_range_sheet_id", "_struct_sheet_range_beg_auth_asym_id", "_struct_sheet_range_beg_auth_seq_id", "_struct_sheet_range_pdbx_beg_pdb_ins_code", "_struct_sheet_range_end_auth_asym_id", "_struct_sheet_range_end_auth_seq_id", "_struct_sheet_range_pdbx_end_pdb_ins_code", "_struct_sheet_range_id"],
+"FAMILY_SHEET", "_struct_sheet_range",
+"structSheetRangeFields", ["*_sheet_id", "*_beg_auth_asym_id", "*_beg_auth_seq_id", "*_pdbx_beg_pdb_ins_code", "*_end_auth_asym_id", "*_end_auth_seq_id", "*_pdbx_end_pdb_ins_code", "*_id"],
 "SITE_ID", 0,
 "SITE_COMP_ID", 1,
 "SITE_ASYM_ID", 2,
 "SITE_SEQ_ID", 3,
 "SITE_INS_CODE", 4,
-"structSiteRangeFields", ["_struct_site_gen_site_id", "_struct_site_gen_auth_comp_id", "_struct_site_gen_auth_asym_id", "_struct_site_gen_auth_seq_id", "_struct_site_gen_label_alt_id"],
+"FAMILY_STRUCSITE", "_struct_site_gen",
+"structSiteFields", ["*_site_id", "*_auth_comp_id", "*_auth_asym_id", "*_auth_seq_id", "*_label_alt_id"],
 "CHEM_COMP_BOND_ATOM_ID_1", 0,
 "CHEM_COMP_BOND_ATOM_ID_2", 1,
 "CHEM_COMP_BOND_VALUE_ORDER", 2,
 "CHEM_COMP_BOND_AROMATIC_FLAG", 3,
-"chemCompBondFields", ["_chem_comp_bond_atom_id_1", "_chem_comp_bond_atom_id_2", "_chem_comp_bond_value_order", "_chem_comp_bond_pdbx_aromatic_flag"]);
+"FAMILY_COMPBOND", "_chem_comp_bond",
+"chemCompBondFields", ["*_atom_id_1", "*_atom_id_2", "*_value_order", "*_pdbx_aromatic_flag"]);
 });
