@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.adapter.readers.pdb");
-Clazz.load (["J.adapter.smarter.AtomSetCollectionReader", "java.util.Hashtable"], "J.adapter.readers.pdb.PdbReader", ["java.lang.Boolean", "$.Character", "$.Float", "JU.Lst", "$.M4", "$.P3", "$.PT", "$.SB", "J.adapter.smarter.Atom", "$.Structure", "J.api.Interface", "$.JmolAdapter", "J.c.STR", "JU.Escape", "$.Logger"], function () {
+Clazz.load (["J.adapter.smarter.AtomSetCollectionReader", "java.util.Hashtable"], "J.adapter.readers.pdb.PdbReader", ["java.lang.Boolean", "$.Float", "JU.Lst", "$.M4", "$.P3", "$.PT", "$.SB", "J.adapter.smarter.Atom", "$.Structure", "J.api.JmolAdapter", "J.c.STR", "JU.Escape", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.serMode = 0;
 this.seqMode = 0;
@@ -24,7 +24,7 @@ this.thisBiomolecule = null;
 this.vBiomolecules = null;
 this.vTlsModels = null;
 this.sbTlsErrors = null;
-this.chainAtomCounts = null;
+this.biomtChainAtomCounts = null;
 this.sbIgnored = null;
 this.sbSelected = null;
 this.sbConect = null;
@@ -52,9 +52,9 @@ this.atomTypePt0 = 0;
 this.atomTypeLen = 0;
 this.isCourseGrained = false;
 this.isbiomol = false;
-this.isConcatenated = false;
 this.htGroup1 = null;
 this.haveDoubleBonds = false;
+this.$cryst1 = 0;
 this.dataT = null;
 this.tlsU = null;
 this.vConnect = null;
@@ -79,7 +79,7 @@ var byChain = this.isbiomol && this.checkFilterKey ("BYCHAIN");
 var bySymop = this.isbiomol && this.checkFilterKey ("BYSYMOP");
 this.isCourseGrained = byChain || bySymop;
 if (!this.isCourseGrained) this.setIsPDB ();
-this.isConcatenated = this.htParams.containsKey ("concatenate") || this.filePath.endsWith (".dssr");
+this.isConcatenated = new Boolean (this.isConcatenated | this.filePath.endsWith (".dssr")).valueOf ();
 if (this.htParams.containsKey ("vTlsModels")) {
 this.vTlsModels = this.htParams.remove ("vTlsModels");
 }var s = this.getFilter ("TYPE ");
@@ -221,7 +221,7 @@ if (!this.getHeader) return this.line;
 }this.pdbHeader.append (this.line).appendC ('\n');
 return this.line;
 }, "~B");
-Clazz.overrideMethod (c$, "finalizeReader", 
+Clazz.overrideMethod (c$, "finalizeSubclassReader", 
 function () {
 this.finalizeReaderPDB ();
 });
@@ -231,14 +231,14 @@ this.checkNotPDB ();
 if (!this.isCourseGrained) this.connectAll (this.maxSerial, this.isConnectStateBug);
 var symmetry;
 if (this.vBiomolecules != null && this.vBiomolecules.size () > 0 && this.asc.ac > 0) {
-this.asc.setAtomSetAuxiliaryInfo ("biomolecules", this.vBiomolecules);
+this.asc.setCurrentModelInfo ("biomolecules", this.vBiomolecules);
 this.setBiomoleculeAtomCounts ();
 if (this.thisBiomolecule != null && this.applySymmetry) {
 this.asc.getXSymmetry ().applySymmetryBio (this.thisBiomolecule, this.notionalUnitCell, this.applySymmetryToBonds, this.filter);
 this.vTlsModels = null;
 this.asc.xtalSymmetry = null;
 }}if (this.vTlsModels != null) {
-symmetry = J.api.Interface.getSymmetry ();
+symmetry = this.getInterface ("JS.Symmetry");
 var n = this.asc.atomSetCount;
 if (n == this.vTlsModels.size ()) {
 for (var i = n; --i >= 0; ) this.setTlsGroups (i, i, symmetry);
@@ -257,7 +257,7 @@ this.appendLoadNote (this.sbTlsErrors.toString ());
 this.finalizeReaderASCR ();
 if (this.vCompnds != null) {
 this.asc.setInfo ("compoundSource", this.vCompnds);
-for (var i = this.asc.iSet + 1; --i >= 0; ) this.asc.setAtomSetAuxiliaryInfoForSet ("compoundSource", this.vCompnds, i);
+for (var i = this.asc.iSet + 1; --i >= 0; ) this.asc.setModelInfoForSet ("compoundSource", this.vCompnds, i);
 
 }if (this.htSites != null) {
 this.addSites (this.htSites);
@@ -287,7 +287,7 @@ if (!isResidual) resid -= (anisou[0] + anisou[1] + anisou[2]) / 3;
 anisou[0] += resid;
 anisou[1] += resid;
 anisou[2] += resid;
-entry.getKey ().addTensor (symmetry.getTensor (anisou).setType (null), "TLS-R", false);
+entry.getKey ().addTensor (symmetry.getTensor (this.vwr, anisou).setType (null), "TLS-R", false);
 JU.Logger.info ("TLS-U:  " + JU.Escape.eAF (anisou));
 anisou = (entry.getKey ().anisoBorU);
 if (anisou != null) JU.Logger.info ("ANISOU: " + JU.Escape.eAF (anisou));
@@ -360,10 +360,10 @@ Clazz.defineMethod (c$, "setBiomoleculeAtomCounts",
  function () {
 for (var i = this.vBiomolecules.size (); --i >= 0; ) {
 var biomolecule = this.vBiomolecules.get (i);
-var chain = biomolecule.get ("chains");
+var chains = biomolecule.get ("chains");
 var nTransforms = (biomolecule.get ("biomts")).size ();
 var nAtoms = 0;
-for (var j = chain.length - 1; --j >= 0; ) if (chain.charAt (j) == ':') nAtoms += this.chainAtomCounts[chain.charCodeAt (j + 1)];
+for (var j = chains.length - 1; --j >= 0; ) if (chains.charAt (j) == ':') nAtoms += this.biomtChainAtomCounts[0 + chains.charCodeAt (j + 1)];
 
 biomolecule.put ("atomCount", Integer.$valueOf (nAtoms * nTransforms));
 }
@@ -372,7 +372,7 @@ Clazz.defineMethod (c$, "remark350",
  function () {
 var biomts = null;
 this.vBiomolecules =  new JU.Lst ();
-this.chainAtomCounts =  Clazz.newIntArray (255, 0);
+this.biomtChainAtomCounts =  Clazz.newIntArray (255, 0);
 var title = "";
 var chainlist = "";
 var id = "";
@@ -409,7 +409,7 @@ chainlist = ":" + list.$replace (' ', ':');
 needLine = false;
 while (this.readHeader (true) != null && this.line.indexOf ("BIOMT") < 0 && this.line.indexOf ("350") == 7) chainlist += ":" + this.line.substring (11).trim ().$replace (' ', ':');
 
-if (this.checkFilterKey ("BIOMOLECULE " + id + ";")) {
+if (this.checkFilterKey ("BIOMOLECULE " + id + ";") || this.checkFilterKey ("BIOMOLECULE=" + id + ";")) {
 this.setFilter (this.filter.$replace (':', '_') + chainlist);
 JU.Logger.info ("filter set to \"" + this.filter + "\"");
 this.thisBiomolecule = info;
@@ -467,14 +467,14 @@ try {
 return this.serial = Integer.parseInt (this.line.substring (i, j));
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
-this.serMode = (Character.isDigit (c) ? 1 : 2);
+this.serMode = (JU.PT.isDigit (c) ? 1 : 2);
 return this.getSerial (i, j);
 } else {
 throw e;
 }
 }
 case 2:
-return (isBase10 || Character.isDigit (c) ? this.parseIntRange (this.line, i, j) : JU.PT.parseIntRadix (this.line.substring (i, j), 36) + (Character.isUpperCase (c) ? -16696160 : 26973856));
+return (isBase10 || JU.PT.isDigit (c) ? this.parseIntRange (this.line, i, j) : JU.PT.parseIntRadix (this.line.substring (i, j), 36) + (JU.PT.isUpperCase (c) ? -16696160 : 26973856));
 case 1:
 if (!isBase10) return this.serial = JU.PT.parseIntRadix (this.line.substring (i, j), 16);
 this.serMode = 0;
@@ -493,14 +493,14 @@ try {
 return Integer.parseInt (this.line.substring (i, j));
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
-this.seqMode = (Character.isDigit (c) ? 1 : 2);
+this.seqMode = (JU.PT.isDigit (c) ? 1 : 2);
 return this.getSeqNo (i, j);
 } else {
 throw e;
 }
 }
 case 2:
-return (isBase10 || Character.isDigit (c) ? this.parseIntRange (this.line, i, j) : JU.PT.parseIntRadix (this.line.substring (i, j), 36) + (Character.isUpperCase (c) ? -456560 : 756496));
+return (isBase10 || JU.PT.isDigit (c) ? this.parseIntRange (this.line, i, j) : JU.PT.parseIntRadix (this.line.substring (i, j), 36) + (JU.PT.isUpperCase (c) ? -456560 : 756496));
 case 1:
 if (!isBase10) return JU.PT.parseIntRadix (this.line.substring (i, j), 16);
 this.seqMode = 0;
@@ -508,14 +508,12 @@ return this.getSeqNo (i, j);
 }
 }, "~N,~N");
 Clazz.defineMethod (c$, "processAtom", 
-function (atom, name, altID, group3, chain, seqNo, insCode, isHetero, sym) {
+function (atom, name, altID, group3, chainID, seqNo, insCode, isHetero, sym) {
 atom.atomName = name;
-var ch = altID;
-if (ch != ' ') atom.altLoc = ch;
+if (altID != ' ') atom.altLoc = altID;
 atom.group3 = group3;
-ch = chain < 256 ? String.fromCharCode (chain) : 0;
-if (this.chainAtomCounts != null) this.chainAtomCounts[ch.charCodeAt (0)]++;
-this.setChainID (atom, ch);
+atom.chainID = chainID;
+if (this.biomtChainAtomCounts != null) this.biomtChainAtomCounts[chainID % 256]++;
 atom.sequenceNumber = seqNo;
 atom.insertionCode = J.api.JmolAdapter.canonizeInsertionCode (insCode);
 atom.isHetero = isHetero;
@@ -545,13 +543,13 @@ if (this.haveMappedSerials) this.asc.addAtomWithMappedSerialNumber (atom);
 if (this.ac++ == 0 && !this.isCourseGrained) this.setModelPDB (true);
 if (atom.isHetero) {
 if (this.htHetero != null) {
-this.asc.setAtomSetAuxiliaryInfo ("hetNames", this.htHetero);
+this.asc.setCurrentModelInfo ("hetNames", this.htHetero);
 this.htHetero = null;
 }}}, "J.adapter.smarter.Atom,~N,~N,~N,~N,~N");
 Clazz.defineMethod (c$, "atom", 
  function () {
 var isHetero = this.line.startsWith ("HETATM");
-var atom = this.processAtom ( new J.adapter.smarter.Atom (), this.line.substring (12, 16).trim (), this.line.charAt (16), this.parseTokenRange (this.line, 17, 20), this.line.charCodeAt (21), this.getSeqNo (22, 26), this.line.charAt (26), isHetero, this.deduceElementSymbol (isHetero));
+var atom = this.processAtom ( new J.adapter.smarter.Atom (), this.line.substring (12, 16).trim (), this.line.charAt (16), this.parseTokenRange (this.line, 17, 20), this.vwr.getChainID (this.line.substring (21, 22), true), this.getSeqNo (22, 26), this.line.charAt (26), isHetero, this.deduceElementSymbol (isHetero));
 if (this.atomTypeLen > 0) {
 var s = this.line.substring (this.atomTypePt0, this.atomTypePt0 + this.atomTypeLen).trim ();
 if (s.length > 0) atom.atomName += "\0" + s;
@@ -626,16 +624,16 @@ function (isHetero) {
 if (this.lineLength >= 78) {
 var ch76 = this.line.charAt (76);
 var ch77 = this.line.charAt (77);
-if (ch76 == ' ' && J.adapter.smarter.Atom.isValidElementSymbol (ch77)) return "" + ch77;
-if (J.adapter.smarter.Atom.isValidElementSymbolNoCaseSecondChar2 (ch76, ch77)) return "" + ch76 + ch77;
+if (ch76 == ' ' && J.adapter.smarter.Atom.isValidSym1 (ch77)) return "" + ch77;
+if (J.adapter.smarter.Atom.isValidSymNoCase (ch76, ch77)) return "" + ch76 + ch77;
 }var ch12 = this.line.charAt (12);
 var ch13 = this.line.charAt (13);
-if ((this.htElementsInCurrentGroup == null || this.htElementsInCurrentGroup.get (this.line.substring (12, 14)) != null) && J.adapter.smarter.Atom.isValidElementSymbolNoCaseSecondChar2 (ch12, ch13)) return (isHetero || ch12 != 'H' ? "" + ch12 + ch13 : "H");
+if ((this.htElementsInCurrentGroup == null || this.htElementsInCurrentGroup.get (this.line.substring (12, 14)) != null) && J.adapter.smarter.Atom.isValidSymNoCase (ch12, ch13)) return (isHetero || ch12 != 'H' ? "" + ch12 + ch13 : "H");
 if (ch12 == 'H') return "H";
-if ((this.htElementsInCurrentGroup == null || this.htElementsInCurrentGroup.get ("" + ch13) != null) && J.adapter.smarter.Atom.isValidElementSymbol (ch13)) return "" + ch13;
-if (ch12 != ' ' && (this.htElementsInCurrentGroup == null || this.htElementsInCurrentGroup.get ("" + ch12) != null) && J.adapter.smarter.Atom.isValidElementSymbol (ch12)) return "" + ch12;
+if ((this.htElementsInCurrentGroup == null || this.htElementsInCurrentGroup.get ("" + ch13) != null) && J.adapter.smarter.Atom.isValidSym1 (ch13)) return "" + ch13;
+if (ch12 != ' ' && (this.htElementsInCurrentGroup == null || this.htElementsInCurrentGroup.get ("" + ch12) != null) && J.adapter.smarter.Atom.isValidSym1 (ch12)) return "" + ch12;
 var ch14 = this.line.charAt (14);
-if (ch12 == ' ' && ch13 != 'X' && (this.htElementsInCurrentGroup == null || this.htElementsInCurrentGroup.get (this.line.substring (13, 15)) != null) && J.adapter.smarter.Atom.isValidElementSymbolNoCaseSecondChar2 (ch13, ch14)) return "" + ch13 + ch14;
+if (ch12 == ' ' && ch13 != 'X' && (this.htElementsInCurrentGroup == null || this.htElementsInCurrentGroup.get (this.line.substring (13, 15)) != null) && J.adapter.smarter.Atom.isValidSymNoCase (ch13, ch14)) return "" + ch13 + ch14;
 return "Xx";
 }, "~B");
 Clazz.defineMethod (c$, "conect", 
@@ -645,13 +643,20 @@ this.sbConect =  new JU.SB ();
 this.sb =  new JU.SB ();
 } else {
 this.sb.setLength (0);
-}var sourceSerial = -1;
-sourceSerial = this.getSerial (6, 11);
+}var sourceSerial = this.getSerial (6, 11);
 if (sourceSerial < 0) return;
-for (var i = 0; i < 9; i += (i == 5 ? 2 : 1)) {
-var offset = i * 5 + 11;
-var offsetEnd = offset + 5;
-var targetSerial = (offsetEnd <= this.lineLength ? this.getSerial (offset, offsetEnd) : -1);
+var order = 1;
+var pt1 = this.line.trim ().length;
+if (pt1 > 56) pt1 = this.line.substring (0, 56).trim ().length;
+for (var pt = 11; pt < pt1; pt += 5) {
+switch (pt) {
+case 31:
+order = 2048;
+break;
+case 41:
+continue;
+}
+var targetSerial = this.getSerial (pt, pt + 5);
 if (targetSerial < 0) continue;
 var isDoubleBond = (sourceSerial == this.lastSourceSerial && targetSerial == this.lastTargetSerial);
 if (isDoubleBond) this.haveDoubleBonds = true;
@@ -669,11 +674,9 @@ if (this.sbConect.indexOf (st) >= 0 && !isDoubleBond) continue;
 if (this.haveDoubleBonds) {
 var st1 = "--" + st;
 if (this.sbConect.indexOf (st1) >= 0) continue;
-this.sbConect.append (st);
 this.sb.append (st1);
-} else {
-this.sbConect.append (st);
-}this.addConnection ([i1, targetSerial, i < 4 ? 1 : 2048]);
+}this.sbConect.append (st);
+this.addConnection ([i1, targetSerial, order]);
 }
 this.sbConect.appendSB (this.sb);
 });
@@ -710,16 +713,16 @@ endIndex = 31;
 if (this.lineLength < endIndex + 4) return;
 var structureID = this.line.substring (11, 15).trim ();
 var serialID = this.parseIntRange (this.line, 7, 10);
-var startChainID = this.line.charAt (startChainIDIndex);
+var startChainID = this.vwr.getChainID (this.line.substring (startChainIDIndex, startChainIDIndex + 1), true);
 var startSequenceNumber = this.parseIntRange (this.line, startIndex, startIndex + 4);
 var startInsertionCode = this.line.charAt (startIndex + 4);
-var endChainID = this.line.charAt (endChainIDIndex);
+var endChainID = this.vwr.getChainID (this.line.substring (endChainIDIndex, endChainIDIndex + 1), true);
 var endSequenceNumber = this.parseIntRange (this.line, endIndex, endIndex + 4);
 var endInsertionCode = ' ';
 if (this.lineLength > endIndex + 4) endInsertionCode = this.line.charAt (endIndex + 4);
 if (substructureType === J.c.STR.NONE) substructureType = structureType;
 var structure =  new J.adapter.smarter.Structure (-1, structureType, substructureType, structureID, serialID, strandCount);
-structure.set (startChainID.charCodeAt (0), startSequenceNumber, startInsertionCode, endChainID.charCodeAt (0), endSequenceNumber, endInsertionCode, -2147483648, 2147483647);
+structure.set (startChainID, startSequenceNumber, startInsertionCode, endChainID, endSequenceNumber, endInsertionCode, -2147483648, 2147483647);
 this.asc.addStructure (structure);
 });
 Clazz.defineMethod (c$, "getModelNumber", 
@@ -738,22 +741,22 @@ this.sbConect = null;
 this.asc.newAtomSet ();
 if (!this.isCourseGrained) this.setModelPDB (true);
 this.asc.setCurrentAtomSetNumber (modelNumber);
-if (this.isCourseGrained) this.asc.setAtomSetAuxiliaryInfo ("courseGrained", Boolean.TRUE);
+if (this.isCourseGrained) this.asc.setCurrentModelInfo ("courseGrained", Boolean.TRUE);
 }, "~N");
 Clazz.defineMethod (c$, "checkNotPDB", 
  function () {
 var isPDB = (!this.isCourseGrained && (this.nRes == 0 || this.nUNK != this.nRes));
-this.asc.setCheckSpecial (!isPDB);
+this.asc.checkSpecial = !isPDB;
 this.setModelPDB (isPDB);
 this.nUNK = this.nRes = 0;
 this.currentGroup3 = null;
 });
 Clazz.defineMethod (c$, "cryst1", 
  function () {
-var a = this.getFloat (6, 9);
+var a = this.$cryst1 = this.getFloat (6, 9);
 if (a == 1) a = NaN;
 this.setUnitCell (a, this.getFloat (15, 9), this.getFloat (24, 9), this.getFloat (33, 7), this.getFloat (40, 7), this.getFloat (47, 7));
-if (this.sgName == null) this.setSpaceGroupName (J.adapter.smarter.AtomSetCollectionReader.parseTrimmedRange (this.line, 55, 66));
+if (this.sgName == null) this.setSpaceGroupName (JU.PT.parseTrimmedRange (this.line, 55, 66));
 });
 Clazz.defineMethod (c$, "getFloat", 
  function (ich, cch) {
@@ -761,7 +764,9 @@ return this.parseFloatRange (this.line, ich, ich + cch);
 }, "~N,~N");
 Clazz.defineMethod (c$, "scale", 
  function (n) {
+if (this.notionalUnitCell == null) return;
 var pt = n * 4 + 2;
+this.notionalUnitCell[0] = this.$cryst1;
 this.setUnitCellItem (pt++, this.getFloat (10, 10));
 this.setUnitCellItem (pt++, this.getFloat (20, 10));
 this.setUnitCellItem (pt++, this.getFloat (30, 10));
@@ -774,12 +779,12 @@ if (this.line.toUpperCase ().indexOf ("NMR") >= 0) this.asc.setInfo ("isNMRdata"
 Clazz.defineMethod (c$, "formul", 
  function () {
 var groupName = this.parseTokenRange (this.line, 12, 15);
-var formula = J.adapter.smarter.AtomSetCollectionReader.parseTrimmedRange (this.line, 19, 70);
+var formula = JU.PT.parseTrimmedRange (this.line, 19, 70);
 var ichLeftParen = formula.indexOf ('(');
 if (ichLeftParen >= 0) {
 var ichRightParen = formula.indexOf (')');
 if (ichRightParen < 0 || ichLeftParen >= ichRightParen || ichLeftParen + 1 == ichRightParen) return;
-formula = J.adapter.smarter.AtomSetCollectionReader.parseTrimmedRange (formula, ichLeftParen + 1, ichRightParen);
+formula = JU.PT.parseTrimmedRange (formula, ichLeftParen + 1, ichRightParen);
 }var htElementsInGroup = this.htFormul.get (groupName);
 if (htElementsInGroup == null) this.htFormul.put (groupName, htElementsInGroup =  new java.util.Hashtable ());
 this.next[0] = 0;
@@ -788,8 +793,8 @@ while ((elementWithCount = this.parseTokenNext (formula)) != null) {
 if (elementWithCount.length < 2) continue;
 var chFirst = elementWithCount.charAt (0);
 var chSecond = elementWithCount.charAt (1);
-if (J.adapter.smarter.Atom.isValidElementSymbolNoCaseSecondChar2 (chFirst, chSecond)) htElementsInGroup.put ("" + chFirst + chSecond, Boolean.TRUE);
- else if (J.adapter.smarter.Atom.isValidElementSymbol (chFirst)) htElementsInGroup.put ("" + chFirst, Boolean.TRUE);
+if (J.adapter.smarter.Atom.isValidSymNoCase (chFirst, chSecond)) htElementsInGroup.put ("" + chFirst + chSecond, Boolean.TRUE);
+ else if (J.adapter.smarter.Atom.isValidSym1 (chFirst)) htElementsInGroup.put ("" + chFirst, Boolean.TRUE);
 }
 });
 Clazz.defineMethod (c$, "het", 
@@ -801,7 +806,7 @@ this.htHetero =  new java.util.Hashtable ();
 }var groupName = this.parseTokenRange (this.line, 7, 10);
 if (this.htHetero.containsKey (groupName)) {
 return;
-}var hetName = J.adapter.smarter.AtomSetCollectionReader.parseTrimmedRange (this.line, 30, 70);
+}var hetName = JU.PT.parseTrimmedRange (this.line, 30, 70);
 this.htHetero.put (groupName, hetName);
 });
 Clazz.defineMethod (c$, "hetnam", 
@@ -809,7 +814,7 @@ Clazz.defineMethod (c$, "hetnam",
 if (this.htHetero == null) {
 this.htHetero =  new java.util.Hashtable ();
 }var groupName = this.parseTokenRange (this.line, 11, 14);
-var hetName = J.adapter.smarter.AtomSetCollectionReader.parseTrimmedRange (this.line, 15, 70);
+var hetName = JU.PT.parseTrimmedRange (this.line, 15, 70);
 if (groupName == null) {
 JU.Logger.error ("ERROR: HETNAM record does not contain a group name: " + this.line);
 return;
@@ -847,7 +852,7 @@ Clazz.defineMethod (c$, "site",
 if (this.htSites == null) {
 this.htSites =  new java.util.Hashtable ();
 }var nResidues = this.parseIntRange (this.line, 15, 17);
-var siteID = J.adapter.smarter.AtomSetCollectionReader.parseTrimmedRange (this.line, 11, 14);
+var siteID = JU.PT.parseTrimmedRange (this.line, 11, 14);
 var htSite = this.htSites.get (siteID);
 if (htSite == null) {
 htSite =  new java.util.Hashtable ();
@@ -857,11 +862,11 @@ this.htSites.put (siteID, htSite);
 }var groups = htSite.get ("groups");
 for (var i = 0; i < 4; i++) {
 var pt = 18 + i * 11;
-var resName = J.adapter.smarter.AtomSetCollectionReader.parseTrimmedRange (this.line, pt, pt + 3);
+var resName = JU.PT.parseTrimmedRange (this.line, pt, pt + 3);
 if (resName.length == 0) break;
-var chainID = J.adapter.smarter.AtomSetCollectionReader.parseTrimmedRange (this.line, pt + 4, pt + 5);
-var seq = J.adapter.smarter.AtomSetCollectionReader.parseTrimmedRange (this.line, pt + 5, pt + 9);
-var iCode = J.adapter.smarter.AtomSetCollectionReader.parseTrimmedRange (this.line, pt + 9, pt + 10);
+var chainID = JU.PT.parseTrimmedRange (this.line, pt + 4, pt + 5);
+var seq = JU.PT.parseTrimmedRange (this.line, pt + 5, pt + 9);
+var iCode = JU.PT.parseTrimmedRange (this.line, pt + 9, pt + 10);
 groups += (groups.length == 0 ? "" : ",") + "[" + resName + "]" + seq;
 if (iCode.length > 0) groups += "^" + iCode;
 if (chainID.length > 0) groups += ":" + chainID;
@@ -880,7 +885,7 @@ var range = null;
 var remark = this.line.substring (0, 11);
 while (this.readHeader (true) != null && this.line.startsWith (remark)) {
 try {
-var tokens = J.adapter.smarter.AtomSetCollectionReader.getTokensStr (this.line.substring (10).$replace (':', ' '));
+var tokens = JU.PT.getTokens (this.line.substring (10).$replace (':', ' '));
 if (tokens.length < 2) continue;
 JU.Logger.info (this.line);
 if (tokens[1].equalsIgnoreCase ("GROUP")) {
@@ -954,7 +959,7 @@ this.tlsAddError ("invalid origin: " + this.line);
 }} else if (tokens[1].equalsIgnoreCase ("TENSOR")) {
 var tensorType = tokens[0].charAt (0);
 var s = (this.readHeader (true).substring (10) + this.readHeader (true).substring (10) + this.readHeader (true).substring (10)).$replace (tensorType, ' ').$replace (':', ' ');
-tokens = J.adapter.smarter.AtomSetCollectionReader.getTokensStr (s);
+tokens = JU.PT.getTokens (s);
 var data =  Clazz.newFloatArray (3, 3, 0);
 tlsGroup.put ("t" + tensorType, data);
 for (var i = 0; i < tokens.length; i++) {
@@ -1029,7 +1034,7 @@ this.setTlsTensor (atom, group, symmetry);
 }
 }
 this.asc.setAtomProperties ("tlsGroup", data, iModel, true);
-this.asc.setAtomSetAuxiliaryInfoForSet ("TLS", tlsGroupInfo, iModel);
+this.asc.setModelInfoForSet ("TLS", tlsGroupInfo, iModel);
 this.asc.setTensors ();
 }, "~N,~N,J.api.SymmetryInterface");
 Clazz.defineMethod (c$, "findAtomForRange", 
@@ -1085,7 +1090,7 @@ anisou[6] = 12;
 anisou[7] = bresidual;
 if (this.tlsU == null) this.tlsU =  new java.util.Hashtable ();
 this.tlsU.put (atom, anisou);
-atom.addTensor (symmetry.getTensor (this.dataT).setType (null), "TLS-U", false);
+atom.addTensor (symmetry.getTensor (this.vwr, this.dataT).setType (null), "TLS-U", false);
 }, "J.adapter.smarter.Atom,java.util.Map,J.api.SymmetryInterface");
 Clazz.defineMethod (c$, "tlsAddError", 
  function (error) {
@@ -1112,9 +1117,9 @@ Clazz.defineMethod (c$, "connectAllBad",
 var firstAtom = this.connectNextAtomIndex;
 for (var i = this.connectNextAtomSet; i < this.asc.atomSetCount; i++) {
 var count = this.asc.getAtomSetAtomCount (i);
-this.asc.setAtomSetAuxiliaryInfoForSet ("PDB_CONECT_firstAtom_count_max", [firstAtom, count, maxSerial], i);
+this.asc.setModelInfoForSet ("PDB_CONECT_firstAtom_count_max", [firstAtom, count, maxSerial], i);
 if (this.vConnect != null) {
-this.asc.setAtomSetAuxiliaryInfoForSet ("PDB_CONECT_bonds", this.vConnect, i);
+this.asc.setModelInfoForSet ("PDB_CONECT_bonds", this.vConnect, i);
 this.asc.setGlobalBoolean (3);
 }firstAtom += count;
 }
@@ -1130,11 +1135,11 @@ if (index < 0) return;
 if (isConnectStateBug) {
 this.connectAllBad (maxSerial);
 return;
-}a.setAtomSetAuxiliaryInfo ("PDB_CONECT_firstAtom_count_max", [a.getAtomSetAtomIndex (index), a.getAtomSetAtomCount (index), maxSerial]);
+}a.setCurrentModelInfo ("PDB_CONECT_firstAtom_count_max", [a.getAtomSetAtomIndex (index), a.getAtomSetAtomCount (index), maxSerial]);
 if (this.vConnect == null) return;
 var firstAtom = this.connectNextAtomIndex;
 for (var i = a.atomSetCount; --i >= this.connectNextAtomSet; ) {
-a.setAtomSetAuxiliaryInfoForSet ("PDB_CONECT_bonds", this.vConnect, i);
+a.setModelInfoForSet ("PDB_CONECT_bonds", this.vConnect, i);
 a.setGlobalBoolean (3);
 firstAtom += a.getAtomSetAtomCount (i);
 }
