@@ -1,9 +1,11 @@
 Clazz.declarePackage ("J.adapter.smarter");
-Clazz.load (["JU.P3"], "J.adapter.smarter.XtalSymmetry", ["java.lang.Boolean", "$.Float", "java.util.Hashtable", "JU.BS", "$.Lst", "$.M3", "$.M4", "$.P3i", "$.PT", "$.SB", "$.V3", "J.adapter.smarter.Atom", "J.api.Interface", "JU.BSUtil", "$.Logger", "$.Vibration"], function () {
+Clazz.load (["JU.P3"], "J.adapter.smarter.XtalSymmetry", ["java.lang.Boolean", "$.Float", "java.util.Hashtable", "JU.BS", "$.Lst", "$.M3", "$.M4", "$.P3i", "$.PT", "$.SB", "$.V3", "J.adapter.smarter.Atom", "JU.BSUtil", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.asc = null;
+this.acr = null;
 this.symmetry = null;
 this.notionalUnitCell = null;
+this.baseUnitCell = null;
 this.symmetryRange = 0;
 this.doCentroidUnitCell = false;
 this.centroidPacked = false;
@@ -12,12 +14,11 @@ this.filterSymop = null;
 this.applySymmetryToBonds = false;
 this.latticeCells = null;
 this.ptSupercell = null;
-this.fmatSupercell = null;
 this.matSupercell = null;
 this.trajectoryUnitCells = null;
 this.doNormalize = true;
 this.doPackUnitCell = false;
-this.vibsFractional = false;
+this.baseSymmetry = null;
 this.rminx = 0;
 this.rminy = 0;
 this.rminz = 0;
@@ -51,14 +52,15 @@ Clazz.makeConstructor (c$,
 function () {
 });
 Clazz.defineMethod (c$, "set", 
-function (asc) {
-this.asc = asc;
+function (reader) {
+this.acr = reader;
+this.asc = reader.asc;
 this.getSymmetry ();
 return this;
-}, "J.adapter.smarter.AtomSetCollection");
+}, "J.adapter.smarter.AtomSetCollectionReader");
 Clazz.defineMethod (c$, "getSymmetry", 
 function () {
-return (this.symmetry == null ? (this.symmetry = J.api.Interface.getSymmetry ()) : this.symmetry);
+return (this.symmetry == null ? (this.symmetry = this.acr.getInterface ("JS.Symmetry")) : this.symmetry);
 });
 Clazz.defineMethod (c$, "setSymmetry", 
 function (symmetry) {
@@ -70,18 +72,17 @@ this.symmetryRange = factor;
 this.asc.setInfo ("symmetryRange", Float.$valueOf (factor));
 }, "~N");
 Clazz.defineMethod (c$, "setLatticeCells", 
- function (acr) {
-this.latticeCells = acr.latticeCells;
+ function () {
+this.latticeCells = this.acr.latticeCells;
 var isLatticeRange = (this.latticeCells[0] <= 555 && this.latticeCells[1] >= 555 && (this.latticeCells[2] == 0 || this.latticeCells[2] == 1 || this.latticeCells[2] == -1));
 this.doNormalize = this.latticeCells[0] != 0 && (!isLatticeRange || this.latticeCells[2] == 1);
-this.applySymmetryToBonds = acr.applySymmetryToBonds;
-this.doPackUnitCell = acr.doPackUnitCell;
-this.doCentroidUnitCell = acr.doCentroidUnitCell;
-this.centroidPacked = acr.centroidPacked;
-this.filterSymop = acr.filterSymop;
-if (acr.strSupercell == null) this.setSupercellFromPoint (acr.ptSupercell);
- else this.setSuperCellFromString (acr.strSupercell);
-}, "J.adapter.smarter.AtomSetCollectionReader");
+this.applySymmetryToBonds = this.acr.applySymmetryToBonds;
+this.doPackUnitCell = this.acr.doPackUnitCell;
+this.doCentroidUnitCell = this.acr.doCentroidUnitCell;
+this.centroidPacked = this.acr.centroidPacked;
+this.filterSymop = this.acr.filterSymop;
+if (this.acr.strSupercell == null) this.setSupercellFromPoint (this.acr.ptSupercell);
+});
 Clazz.defineMethod (c$, "setSupercellFromPoint", 
 function (pt) {
 this.ptSupercell = pt;
@@ -95,17 +96,6 @@ this.matSupercell.m22 = pt.z;
 this.matSupercell.m33 = 1;
 JU.Logger.info ("Using supercell \n" + this.matSupercell);
 }, "JU.P3");
-Clazz.defineMethod (c$, "setSuperCellFromString", 
- function (supercell) {
-if (this.fmatSupercell != null) return;
-this.fmatSupercell =  Clazz.newFloatArray (16, 0);
-if (this.symmetry.getMatrixFromString (supercell, this.fmatSupercell, true, 0) == null) {
-this.fmatSupercell = null;
-this.matSupercell = null;
-return;
-}this.matSupercell = JU.M4.newA16 (this.fmatSupercell);
-JU.Logger.info ("Using supercell \n" + this.matSupercell);
-}, "~S");
 Clazz.defineMethod (c$, "setNotionalUnitCell", 
  function (info, matUnitCellOrientation, unitCellOffset) {
 this.notionalUnitCell =  Clazz.newFloatArray (info.length, 0);
@@ -113,7 +103,7 @@ this.unitCellOffset = unitCellOffset;
 for (var i = 0; i < info.length; i++) this.notionalUnitCell[i] = info[i];
 
 this.asc.haveUnitCell = true;
-this.asc.setAtomSetAuxiliaryInfo ("notionalUnitcell", this.notionalUnitCell);
+this.asc.setCurrentModelInfo ("notionalUnitcell", this.notionalUnitCell);
 if (this.asc.isTrajectory) {
 if (this.trajectoryUnitCells == null) {
 this.trajectoryUnitCells =  new JU.Lst ();
@@ -123,51 +113,56 @@ this.asc.setInfo ("unitCells", this.trajectoryUnitCells);
 this.getSymmetry ().setUnitCell (this.notionalUnitCell, false);
 if (unitCellOffset != null) {
 this.symmetry.setOffsetPt (unitCellOffset);
-this.asc.setAtomSetAuxiliaryInfo ("unitCellOffset", unitCellOffset);
+this.asc.setCurrentModelInfo ("unitCellOffset", unitCellOffset);
 }if (matUnitCellOrientation != null) {
 this.symmetry.initializeOrientation (matUnitCellOrientation);
-this.asc.setAtomSetAuxiliaryInfo ("matUnitCellOrientation", matUnitCellOrientation);
+this.asc.setCurrentModelInfo ("matUnitCellOrientation", matUnitCellOrientation);
 }}, "~A,JU.M3,JU.P3");
 Clazz.defineMethod (c$, "addSpaceGroupOperation", 
-function (acr, xyz) {
-if (acr != null) this.setLatticeCells (acr);
+function (xyz, andSetLattice) {
+if (andSetLattice) this.setLatticeCells ();
 this.symmetry.setSpaceGroup (this.doNormalize);
 return this.symmetry.addSpaceGroupOperation (xyz, 0);
-}, "J.adapter.smarter.AtomSetCollectionReader,~S");
+}, "~S,~B");
 Clazz.defineMethod (c$, "setLatticeParameter", 
 function (latt) {
 this.symmetry.setSpaceGroup (this.doNormalize);
 this.symmetry.setLattice (latt);
 }, "~N");
 Clazz.defineMethod (c$, "applySymmetryFromReader", 
-function (acr, readerSymmetry) {
-this.asc.setCoordinatesAreFractional (acr.iHaveFractionalCoordinates);
-this.setNotionalUnitCell (acr.notionalUnitCell, acr.matUnitCellOrientation, acr.unitCellOffset);
-this.asc.setAtomSetSpaceGroupName (acr.sgName);
-this.setSymmetryRange (acr.symmetryRange);
-if (acr.doConvertToFractional || acr.fileCoordinatesAreFractional) {
-this.setLatticeCells (acr);
+function (readerSymmetry) {
+this.asc.setCoordinatesAreFractional (this.acr.iHaveFractionalCoordinates);
+this.setNotionalUnitCell (this.acr.notionalUnitCell, this.acr.matUnitCellOrientation, this.acr.unitCellOffset);
+this.setAtomSetSpaceGroupName (this.acr.sgName);
+this.setSymmetryRange (this.acr.symmetryRange);
+if (this.acr.doConvertToFractional || this.acr.fileCoordinatesAreFractional) {
+this.setLatticeCells ();
 var doApplySymmetry = true;
-if (acr.ignoreFileSpaceGroupName || !acr.iHaveSymmetryOperators) {
-if (!acr.merging || readerSymmetry == null) readerSymmetry = acr.getNewSymmetry ();
-doApplySymmetry = readerSymmetry.createSpaceGroup (acr.desiredSpaceGroupIndex, (acr.sgName.indexOf ("!") >= 0 ? "P1" : acr.sgName), acr.notionalUnitCell);
+if (this.acr.ignoreFileSpaceGroupName || !this.acr.iHaveSymmetryOperators) {
+if (!this.acr.merging || readerSymmetry == null) readerSymmetry = this.acr.getNewSymmetry ();
+doApplySymmetry = readerSymmetry.createSpaceGroup (this.acr.desiredSpaceGroupIndex, (this.acr.sgName.indexOf ("!") >= 0 ? "P1" : this.acr.sgName), this.acr.notionalUnitCell);
 } else {
-acr.doPreSymmetry ();
-this.vibsFractional = acr.vibsFractional;
+this.acr.doPreSymmetry ();
 readerSymmetry = null;
-}if (doApplySymmetry) {
+}this.packingError = this.acr.packingError;
+if (doApplySymmetry) {
 if (readerSymmetry != null) this.symmetry.setSpaceGroupFrom (readerSymmetry);
-this.packingError = acr.packingError;
-this.applySymmetryLattice (acr.ms, acr.altCell);
-if (readerSymmetry != null && this.filterSymop == null) this.asc.setAtomSetSpaceGroupName (readerSymmetry.getSpaceGroupName ());
-}}if (acr.iHaveFractionalCoordinates && acr.merging && readerSymmetry != null) {
-this.asc.toCartesian (readerSymmetry);
+this.applySymmetryLattice (this.acr.ms, this.acr.strSupercell);
+if (readerSymmetry != null && this.filterSymop == null) this.setAtomSetSpaceGroupName (readerSymmetry.getSpaceGroupName ());
+}}if (this.acr.iHaveFractionalCoordinates && this.acr.merging && readerSymmetry != null) {
+var atoms = this.asc.atoms;
+for (var i = this.asc.getLastAtomSetAtomIndex (), n = this.asc.ac; i < n; i++) readerSymmetry.toCartesian (atoms[i], true);
+
 this.asc.setCoordinatesAreFractional (false);
-acr.addVibrations = false;
+this.acr.addVibrations = false;
 }return this.symmetry;
-}, "J.adapter.smarter.AtomSetCollectionReader,J.api.SymmetryInterface");
+}, "J.api.SymmetryInterface");
+Clazz.defineMethod (c$, "setAtomSetSpaceGroupName", 
+ function (spaceGroupName) {
+this.asc.setCurrentModelInfo ("spaceGroup", spaceGroupName + "");
+}, "~S");
 Clazz.defineMethod (c$, "applySymmetryLattice", 
- function (ms, altCell) {
+ function (ms, supercell) {
 if (!this.asc.coordinatesAreFractional || this.symmetry.getSpaceGroup () == null) return;
 var maxX = this.latticeCells[0];
 var maxY = this.latticeCells[1];
@@ -183,26 +178,42 @@ this.nVib = 0;
 var va = null;
 var vb = null;
 var vc = null;
-if (altCell != null && altCell.indexOf (",") >= 0) {
-oabc = this.symmetry.getV0abc (altCell);
+this.baseSymmetry = this.symmetry;
+if (supercell != null && supercell.indexOf (",") >= 0) {
+oabc = this.symmetry.getV0abc (supercell);
 if (oabc != null) {
 this.minXYZ =  new JU.P3i ();
 this.maxXYZ = JU.P3i.new3 (maxX, maxY, maxZ);
 this.symmetry.setMinMaxLatticeParameters (this.minXYZ, this.maxXYZ);
 pt0 = JU.P3.newP (oabc[0]);
-this.symmetry.toFractional (pt0, true);
 va = JU.P3.newP (oabc[1]);
 vb = JU.P3.newP (oabc[2]);
 vc = JU.P3.newP (oabc[3]);
-oabc[0].scaleAdd2 (this.minXYZ.x, va, oabc[0]);
+var pa =  new JU.P3 ();
+var pb =  new JU.P3 ();
+var pc =  new JU.P3 ();
+if (this.acr.forcePacked) {
+pa.setT (va);
+pb.setT (vb);
+pc.setT (vc);
+pa.scale (this.packingError);
+pb.scale (this.packingError);
+pc.scale (this.packingError);
+}oabc[0].scaleAdd2 (this.minXYZ.x, va, oabc[0]);
 oabc[0].scaleAdd2 (this.minXYZ.y, vb, oabc[0]);
 oabc[0].scaleAdd2 (this.minXYZ.z, vc, oabc[0]);
+oabc[0].sub (pa);
+oabc[0].sub (pb);
+oabc[0].sub (pc);
 var pt = JU.P3.newP (oabc[0]);
 this.symmetry.toFractional (pt, true);
 this.setSymmetryMinMax (pt);
 oabc[1].scale (this.maxXYZ.x - this.minXYZ.x);
 oabc[2].scale (this.maxXYZ.y - this.minXYZ.y);
 oabc[3].scale (this.maxXYZ.z - this.minXYZ.z);
+oabc[1].scaleAdd2 (2, pa, oabc[1]);
+oabc[2].scaleAdd2 (2, pb, oabc[2]);
+oabc[3].scaleAdd2 (2, pc, oabc[3]);
 for (var i = 0; i < 3; i++) {
 for (var j = i + 1; j < 4; j++) {
 pt.add2 (oabc[i], oabc[j]);
@@ -217,67 +228,51 @@ this.symmetry.toFractional (pt, false);
 this.setSymmetryMinMax (pt);
 this.minXYZ = JU.P3i.new3 (Clazz.doubleToInt (Math.floor (this.rminx + 0.001)), Clazz.doubleToInt (Math.floor (this.rminy + 0.001)), Clazz.doubleToInt (Math.floor (this.rminz + 0.001)));
 this.maxXYZ = JU.P3i.new3 (Clazz.doubleToInt (Math.ceil (this.rmaxx - 0.001)), Clazz.doubleToInt (Math.ceil (this.rmaxy - 0.001)), Clazz.doubleToInt (Math.ceil (this.rmaxz - 0.001)));
-}} else if (this.fmatSupercell != null) {
-var pt =  new JU.P3 ();
-for (var i = 0; i <= 1; i++) for (var j = 0; j <= 1; j++) for (var k = 0; k <= 1; k++) {
-pt.set (i, j, k);
-this.setSym (pt);
-}
-
-
-offset = this.asc.getAtomSetAuxiliaryInfoValue (-1, "unitCellOffset");
-this.minXYZ = JU.P3i.new3 (Clazz.floatToInt (this.rminx), Clazz.floatToInt (this.rminy), Clazz.floatToInt (this.rminz));
-this.maxXYZ = JU.P3i.new3 (Clazz.floatToInt (this.rmaxx), Clazz.floatToInt (this.rmaxy), Clazz.floatToInt (this.rmaxz));
-va = this.setSym (JU.P3.new3 (1, 0, 0));
-vb = this.setSym (JU.P3.new3 (0, 1, 0));
-vc = this.setSym (JU.P3.new3 (0, 0, 1));
-}if (this.rminx == 3.4028235E38) {
-this.fmatSupercell = null;
+}}if (this.rminx == 3.4028235E38) {
 this.matSupercell = null;
-altCell = null;
+supercell = null;
 oabc = null;
 } else {
 JU.Logger.info ("setting min/max for original lattice to " + this.minXYZ + " and " + this.maxXYZ);
 var doPack0 = this.doPackUnitCell;
-this.doPackUnitCell = (oabc != null);
+this.doPackUnitCell = doPack0;
 if (this.asc.bsAtoms == null) this.asc.bsAtoms = JU.BSUtil.setAll (this.asc.ac);
 bsAtoms = this.asc.bsAtoms;
-this.applyAllSymmetry (ms, null, false);
+this.applyAllSymmetry (ms, null);
 this.doPackUnitCell = doPack0;
-this.setVibVectors ();
 var atoms = this.asc.atoms;
 var atomCount = this.asc.ac;
 var iAtomFirst = this.asc.getLastAtomSetAtomIndex ();
-for (var i = iAtomFirst; i < atomCount; i++) {
-this.symmetry.toCartesian (atoms[i], true);
-}
+for (var i = iAtomFirst; i < atomCount; i++) this.symmetry.toCartesian (atoms[i], true);
+
 this.symmetry = null;
 this.symmetry = this.getSymmetry ();
 this.setNotionalUnitCell ([0, 0, 0, 0, 0, 0, va.x, va.y, va.z, vb.x, vb.y, vb.z, vc.x, vc.y, vc.z], null, offset);
-this.asc.setAtomSetSpaceGroupName (oabc == null ? "P1" : "cell=" + altCell);
+this.setAtomSetSpaceGroupName (oabc == null ? "P1" : "cell=" + supercell);
 this.symmetry.setSpaceGroup (this.doNormalize);
 this.symmetry.addSpaceGroupOperation ("x,y,z", 0);
+if (pt0 != null) this.symmetry.toFractional (pt0, true);
 for (var i = iAtomFirst; i < atomCount; i++) {
 this.symmetry.toFractional (atoms[i], true);
 if (pt0 != null) atoms[i].sub (pt0);
 }
 this.asc.haveAnisou = false;
-this.asc.setAtomSetAuxiliaryInfo ("matUnitCellOrientation", null);
+this.asc.setCurrentModelInfo ("matUnitCellOrientation", null);
 }this.minXYZ =  new JU.P3i ();
 this.maxXYZ = JU.P3i.new3 (maxX, maxY, maxZ);
 if (oabc == null) {
-this.applyAllSymmetry (ms, bsAtoms, this.fmatSupercell != null);
-this.fmatSupercell = null;
-} else {
-this.trimAtomSet ();
+this.minXYZ =  new JU.P3i ();
+this.maxXYZ = JU.P3i.new3 (maxX, maxY, maxZ);
+this.applyAllSymmetry (ms, bsAtoms);
+} else if (this.acr.forcePacked || this.doPackUnitCell) {
+this.symmetry.setMinMaxLatticeParameters (this.minXYZ, this.maxXYZ);
+var bs = this.asc.bsAtoms;
+var atoms = this.asc.atoms;
+if (bs == null) bs = this.asc.bsAtoms = JU.BSUtil.newBitSet2 (0, this.asc.ac);
+for (var i = bs.nextSetBit (0); i >= 0; i = bs.nextSetBit (i + 1)) {
+if (!this.isWithinCell (this.dtype, atoms[i], this.minXYZ.x, this.maxXYZ.x, this.minXYZ.y, this.maxXYZ.y, this.minXYZ.z, this.maxXYZ.z, this.packingError)) bs.clear (i);
+}
 }}, "J.adapter.smarter.MSInterface,~S");
-Clazz.defineMethod (c$, "setSym", 
- function (pt) {
-this.matSupercell.rotate (pt);
-this.setSymmetryMinMax (pt);
-this.symmetry.toCartesian (pt, false);
-return pt;
-}, "JU.P3");
 Clazz.defineMethod (c$, "setSymmetryMinMax", 
  function (c) {
 if (this.rminx > c.x) this.rminx = c.x;
@@ -296,7 +291,7 @@ function (dtype, pt, minX, maxX, minY, maxY, minZ, maxZ, slop) {
 return (pt.x > minX - slop && pt.x < maxX + slop && (dtype < 2 || pt.y > minY - slop && pt.y < maxY + slop) && (dtype < 3 || pt.z > minZ - slop && pt.z < maxZ + slop));
 }, "~N,JU.P3,~N,~N,~N,~N,~N,~N,~N");
 Clazz.defineMethod (c$, "applyAllSymmetry", 
- function (ms, bsAtoms, disableSymmetry) {
+ function (ms, bsAtoms) {
 if (this.asc.ac == 0) return;
 this.noSymmetryCount = (this.asc.baseSymmetryAtomCount == 0 ? this.asc.getLastAtomSetAtomCount () : this.asc.baseSymmetryAtomCount);
 this.asc.setTensors ();
@@ -307,7 +302,7 @@ this.dtype = Clazz.floatToInt (this.symmetry.getUnitCellInfoType (6));
 this.symmetry.setMinMaxLatticeParameters (this.minXYZ, this.maxXYZ);
 if (this.doCentroidUnitCell) this.asc.setInfo ("centroidMinMax", [this.minXYZ.x, this.minXYZ.y, this.minXYZ.z, this.maxXYZ.x, this.maxXYZ.y, this.maxXYZ.z, (this.centroidPacked ? 1 : 0)]);
 if (this.ptSupercell != null) {
-this.asc.setAtomSetAuxiliaryInfo ("supercell", this.ptSupercell);
+this.asc.setCurrentModelInfo ("supercell", this.ptSupercell);
 switch (this.dtype) {
 case 3:
 this.minXYZ.z *= Clazz.floatToInt (Math.abs (this.ptSupercell.z));
@@ -357,7 +352,7 @@ this.rmaxx = this.rmaxy = this.rmaxz = -3.4028235E38;
 }var symmetry = this.symmetry;
 var lastSymmetry = symmetry;
 this.latticeOp = symmetry.getLatticeOp ();
-this.checkAll = (disableSymmetry || this.asc.atomSetCount == 1 && this.asc.checkSpecial && this.latticeOp >= 0);
+this.checkAll = (this.asc.atomSetCount == 1 && this.asc.checkSpecial && this.latticeOp >= 0);
 this.latticeOnly = (this.asc.checkLatticeOnly && this.latticeOp >= 0);
 var pttemp = null;
 var op = symmetry.getSpaceGroupOperation (0);
@@ -382,6 +377,7 @@ if (this.doPackUnitCell) {
 symmetry.toUnitCell (c, this.ptOffset);
 pttemp.setT (c);
 symmetry.toFractional (pttemp, false);
+if (this.acr.fixJavaFloat) JU.PT.fixPtFloats (pttemp, 100000.0);
 if (bsAtoms == null) atom.setT (pttemp);
  else if (atom.distance (pttemp) < 0.0001) bsAtoms.set (atom.index);
  else {
@@ -400,7 +396,7 @@ this.rminz -= absRange;
 this.rmaxx += absRange;
 this.rmaxy += absRange;
 this.rmaxz += absRange;
-}cell555Count = pt = this.symmetryAddAtoms (0, 0, 0, 0, pt, iCell * operationCount, cartesians, ms, false);
+}cell555Count = pt = this.symmetryAddAtoms (0, 0, 0, 0, pt, iCell * operationCount, cartesians, ms);
 }
 
 
@@ -414,22 +410,23 @@ this.rmaxz += absRange;
 }iCell = 0;
 for (var tx = this.minXYZ.x; tx < this.maxXYZ.x; tx++) for (var ty = this.minXYZ.y; ty < this.maxXYZ.y; ty++) for (var tz = this.minXYZ.z; tz < this.maxXYZ.z; tz++) {
 iCell++;
-if (tx != 0 || ty != 0 || tz != 0) pt = this.symmetryAddAtoms (tx, ty, tz, cell555Count, pt, iCell * operationCount, cartesians, ms, disableSymmetry);
+if (tx != 0 || ty != 0 || tz != 0) pt = this.symmetryAddAtoms (tx, ty, tz, cell555Count, pt, iCell * operationCount, cartesians, ms);
 }
 
 
 if (iCell * this.noSymmetryCount == this.asc.ac - this.firstSymmetryAtom) this.duplicateAtomProperties (iCell);
 this.setSymmetryOps ();
-this.asc.setAtomSetAuxiliaryInfo ("presymmetryAtomIndex", Integer.$valueOf (this.firstSymmetryAtom));
-this.asc.setAtomSetAuxiliaryInfo ("presymmetryAtomCount", Integer.$valueOf (this.noSymmetryCount));
-this.asc.setAtomSetAuxiliaryInfo ("latticeDesignation", symmetry.getLatticeDesignation ());
-this.asc.setAtomSetAuxiliaryInfo ("unitCellRange", unitCells);
-this.asc.setAtomSetAuxiliaryInfo ("unitCellTranslations", this.unitCellTranslations);
+this.asc.setCurrentModelInfo ("presymmetryAtomIndex", Integer.$valueOf (this.firstSymmetryAtom));
+this.asc.setCurrentModelInfo ("presymmetryAtomCount", Integer.$valueOf (this.noSymmetryCount));
+this.asc.setCurrentModelInfo ("latticeDesignation", symmetry.getLatticeDesignation ());
+this.asc.setCurrentModelInfo ("unitCellRange", unitCells);
+this.asc.setCurrentModelInfo ("unitCellTranslations", this.unitCellTranslations);
+this.baseUnitCell = this.notionalUnitCell;
 this.notionalUnitCell =  Clazz.newFloatArray (6, 0);
 this.reset ();
-}, "J.adapter.smarter.MSInterface,JU.BS,~B");
+}, "J.adapter.smarter.MSInterface,JU.BS");
 Clazz.defineMethod (c$, "symmetryAddAtoms", 
- function (transX, transY, transZ, baseCount, pt, iCellOpPt, cartesians, ms, disableSymmetry) {
+ function (transX, transY, transZ, baseCount, pt, iCellOpPt, cartesians, ms) {
 var isBaseCell = (baseCount == 0);
 var addBonds = (this.bondCount0 > this.asc.bondIndex0 && this.applySymmetryToBonds);
 var atomMap = (addBonds ?  Clazz.newIntArray (this.noSymmetryCount, 0) : null);
@@ -452,7 +449,7 @@ var code = null;
 var subSystemId = '\u0000';
 for (var iSym = 0; iSym < nOperations; iSym++) {
 if (isBaseCell && iSym == 0 || this.latticeOnly && iSym > 0 && iSym != this.latticeOp) continue;
-var pt0 = (disableSymmetry ? 0 : checkSpecial ? pt : checkRange111 ? baseCount : 0);
+var pt0 = (checkSpecial ? pt : checkRange111 ? baseCount : 0);
 var spinOp = (this.asc.vibScale == 0 ? symmetry.getSpinOp (iSym) : this.asc.vibScale);
 for (var i = this.firstSymmetryAtom; i < atomMax; i++) {
 var a = this.asc.atoms[i];
@@ -468,12 +465,14 @@ if (code != null) {
 subSystemId = code.charAt (0);
 symmetry = ms.getSymmetryFromCode (code);
 if (symmetry.getSpaceGroupOperationCount () == 0) this.finalizeSymmetry (symmetry);
-}}var cartesian = JU.P3.newP (ptAtom);
+}}if (this.acr.fixJavaFloat) JU.PT.fixPtFloats (ptAtom, 100000.0);
+var cartesian = JU.P3.newP (ptAtom);
 symmetry.toCartesian (cartesian, false);
 if (this.doPackUnitCell) {
 symmetry.toUnitCell (cartesian, this.ptOffset);
 ptAtom.setT (cartesian);
 symmetry.toFractional (ptAtom, false);
+if (this.acr.fixJavaFloat) JU.PT.fixPtFloats (ptAtom, 100000.0);
 if (!this.isWithinCell (this.dtype, ptAtom, this.minXYZ0.x, this.maxXYZ0.x, this.minXYZ0.y, this.maxXYZ0.y, this.minXYZ0.z, this.maxXYZ0.z, this.packingError)) continue;
 }if (checkSymmetryMinMax) this.setSymmetryMinMax (cartesian);
 var special = null;
@@ -507,7 +506,6 @@ atom1.setT (ptAtom);
 if (spinOp != 0 && atom1.vib != null) {
 symmetry.getSpaceGroupOperation (iSym).rotate (atom1.vib);
 atom1.vib.scale (spinOp);
-System.out.println ("vib for iSym " + iSym + " " + atom1 + " " + atom1.vib);
 }atom1.atomSite = atomSite;
 if (code != null) atom1.altLoc = subSystemId;
 atom1.bsSymmetry = JU.BSUtil.newAndSetBit (iCellOpPt + iSym);
@@ -537,7 +535,7 @@ if (iAtom1 >= atomMax || iAtom2 >= atomMax) this.asc.addNewBondWithOrder (iAtom1
 }
 }}
 return pt;
-}, "~N,~N,~N,~N,~N,~N,~A,J.adapter.smarter.MSInterface,~B");
+}, "~N,~N,~N,~N,~N,~N,~A,J.adapter.smarter.MSInterface");
 Clazz.defineMethod (c$, "duplicateAtomProperties", 
  function (nTimes) {
 var p = this.asc.getAtomSetAuxiliaryInfoValue (-1, "atomProperties");
@@ -561,7 +559,7 @@ Clazz.defineMethod (c$, "finalizeSymmetry",
  function (symmetry) {
 var name = this.asc.getAtomSetAuxiliaryInfoValue (-1, "spaceGroup");
 symmetry.setFinalOperations (name, this.asc.atoms, this.firstSymmetryAtom, this.noSymmetryCount, this.doNormalize, this.filterSymop);
-if (this.filterSymop != null || name == null || name.equals ("unspecified!")) this.asc.setAtomSetSpaceGroupName (symmetry.getSpaceGroupName ());
+if (this.filterSymop != null || name == null || name.equals ("unspecified!")) this.setAtomSetSpaceGroupName (symmetry.getSpaceGroupName ());
 }, "J.api.SymmetryInterface");
 Clazz.defineMethod (c$, "setSymmetryOps", 
  function () {
@@ -570,9 +568,9 @@ if (operationCount > 0) {
 var symmetryList =  new Array (operationCount);
 for (var i = 0; i < operationCount; i++) symmetryList[i] = "" + this.symmetry.getSpaceGroupXyz (i, this.doNormalize);
 
-this.asc.setAtomSetAuxiliaryInfo ("symmetryOperations", symmetryList);
-this.asc.setAtomSetAuxiliaryInfo ("symmetryOps", this.symmetry.getSymmetryOperations ());
-}this.asc.setAtomSetAuxiliaryInfo ("symmetryCount", Integer.$valueOf (operationCount));
+this.asc.setCurrentModelInfo ("symmetryOperations", symmetryList);
+this.asc.setCurrentModelInfo ("symmetryOps", this.symmetry.getSymmetryOperations ());
+}this.asc.setCurrentModelInfo ("symmetryCount", Integer.$valueOf (operationCount));
 });
 Clazz.defineMethod (c$, "applySymmetryBio", 
 function (thisBiomolecule, notionalUnitCell, applySymmetryToBonds, filter) {
@@ -586,9 +584,9 @@ if (biomts.size () < 2) return;
 this.symmetry = null;
 if (!Float.isNaN (notionalUnitCell[0])) this.setNotionalUnitCell (notionalUnitCell, null, this.unitCellOffset);
 this.getSymmetry ().setSpaceGroup (this.doNormalize);
-this.addSpaceGroupOperation (null, "x,y,z");
+this.addSpaceGroupOperation ("x,y,z", false);
 var name = thisBiomolecule.get ("name");
-this.asc.setAtomSetSpaceGroupName (name);
+this.setAtomSetSpaceGroupName (name);
 var len = biomts.size ();
 this.applySymmetryToBonds = applySymmetryToBonds;
 this.bondCount0 = this.asc.bondCount;
@@ -640,6 +638,7 @@ for (var i = atomMax; --i >= this.firstSymmetryAtom; ) a.add (atoms[i]);
 a.scale (1 / (atomMax - this.firstSymmetryAtom));
 a.atomName = "Pt";
 a.radius = 16;
+this.asc.addAtom (a);
 this.firstSymmetryAtom = atomMax++;
 break;
 }
@@ -683,10 +682,10 @@ throw e;
 if (i > 0) this.symmetry.addBioMoleculeOperation (mat, false);
 }
 this.noSymmetryCount = atomMax - this.firstSymmetryAtom;
-this.asc.setAtomSetAuxiliaryInfo ("presymmetryAtomIndex", Integer.$valueOf (this.firstSymmetryAtom));
-this.asc.setAtomSetAuxiliaryInfo ("presymmetryAtomCount", Integer.$valueOf (this.noSymmetryCount));
-this.asc.setAtomSetAuxiliaryInfo ("biosymmetryCount", Integer.$valueOf (len));
-this.asc.setAtomSetAuxiliaryInfo ("biosymmetry", this.symmetry);
+this.asc.setCurrentModelInfo ("presymmetryAtomIndex", Integer.$valueOf (this.firstSymmetryAtom));
+this.asc.setCurrentModelInfo ("presymmetryAtomCount", Integer.$valueOf (this.noSymmetryCount));
+this.asc.setCurrentModelInfo ("biosymmetryCount", Integer.$valueOf (len));
+this.asc.setCurrentModelInfo ("biosymmetry", this.symmetry);
 this.finalizeSymmetry (this.symmetry);
 this.setSymmetryOps ();
 this.reset ();
@@ -694,7 +693,7 @@ this.reset ();
 Clazz.defineMethod (c$, "reset", 
  function () {
 this.asc.coordinatesAreFractional = false;
-this.asc.setAtomSetAuxiliaryInfo ("hasSymmetry", Boolean.TRUE);
+this.asc.setCurrentModelInfo ("hasSymmetry", Boolean.TRUE);
 this.asc.setGlobalBoolean (1);
 });
 Clazz.defineMethod (c$, "addRotatedTensor", 
@@ -702,7 +701,7 @@ function (a, t, iSym, reset, symmetry) {
 if (this.ptTemp == null) {
 this.ptTemp =  new JU.P3 ();
 this.mTemp =  new JU.M3 ();
-}return a.addTensor ((J.api.Interface.getUtil ("Tensor")).setFromEigenVectors (symmetry.rotateAxes (iSym, t.eigenVectors, this.ptTemp, this.mTemp), t.eigenValues, t.isIsotropic ? "iso" : t.type, t.id, t), null, reset);
+}return a.addTensor ((this.acr.getInterface ("JU.Tensor")).setFromEigenVectors (symmetry.rotateAxes (iSym, t.eigenVectors, this.ptTemp, this.mTemp), t.eigenValues, t.isIsotropic ? "iso" : t.type, t.id, t), null, reset);
 }, "J.adapter.smarter.Atom,JU.Tensor,~N,~B,J.api.SymmetryInterface");
 Clazz.defineMethod (c$, "setTensors", 
 function () {
@@ -710,7 +709,7 @@ var n = this.asc.ac;
 for (var i = this.asc.getLastAtomSetAtomIndex (); i < n; i++) {
 var a = this.asc.atoms[i];
 if (a.anisoBorU == null) continue;
-a.addTensor (this.symmetry.getTensor (a.anisoBorU), null, false);
+a.addTensor (this.symmetry.getTensor (this.acr.vwr, a.anisoBorU), null, false);
 if (Float.isNaN (a.bfactor)) a.bfactor = a.anisoBorU[7] * 100;
 a.anisoBorU = null;
 }
@@ -721,34 +720,48 @@ this.symmetry.setTimeReversal (op, timeRev);
 }, "~N,~N");
 Clazz.defineMethod (c$, "rotateToSuperCell", 
 function (t) {
-if (this.matSupercell != null) this.matSupercell.rotate (t);
+if (this.matSupercell != null) this.matSupercell.rotTrans (t);
 }, "JU.V3");
-Clazz.defineMethod (c$, "setVibVectors", 
+Clazz.defineMethod (c$, "setSpinVectors", 
 function () {
-if (this.nVib > 0 || this.asc.iSet < 0 || !this.vibsFractional) return this.nVib;
+if (this.nVib > 0 || this.asc.iSet < 0 || !this.acr.vibsFractional) return this.nVib;
 var i0 = this.asc.getAtomSetAtomIndex (this.asc.iSet);
+var sym = this.getBaseSymmetry ();
 for (var i = this.asc.ac; --i >= i0; ) {
-if (this.asc.atoms[i].vib != null) {
-var v =  new JU.Vibration ();
-v.setT (this.asc.atoms[i].vib);
-v.modDim = -2;
-this.symmetry.toCartesian (v, true);
+var v = this.asc.atoms[i].vib;
+if (v != null) {
+if (v.modDim > 0) {
+(v).setMoment ();
+} else {
+v = v.clone ();
+sym.toCartesian (v, true);
 this.asc.atoms[i].vib = v;
-this.nVib++;
+}this.nVib++;
 }}
 return this.nVib;
 });
-Clazz.defineMethod (c$, "trimAtomSet", 
- function () {
-this.symmetry.setMinMaxLatticeParameters (this.minXYZ, this.maxXYZ);
-var bs = this.asc.bsAtoms;
-var atoms = this.asc.atoms;
-if (bs == null) bs = this.asc.bsAtoms = JU.BSUtil.newBitSet2 (0, this.asc.ac);
-for (var i = bs.nextSetBit (0); i >= 0; i = bs.nextSetBit (i + 1)) {
-if (!this.isWithinCell (this.dtype, atoms[i], this.minXYZ.x, this.maxXYZ.x, this.minXYZ.y, this.maxXYZ.y, this.minXYZ.z, this.maxXYZ.z, this.packingError)) {
-bs.clear (i);
+Clazz.defineMethod (c$, "scaleFractionalVibs", 
+function () {
+var params = this.getBaseSymmetry ().getNotionalUnitCell ();
+var ptScale = JU.P3.new3 (1 / params[0], 1 / params[1], 1 / params[2]);
+var i0 = this.asc.getAtomSetAtomIndex (this.asc.iSet);
+for (var i = this.asc.ac; --i >= i0; ) {
+var v = this.asc.atoms[i].vib;
+if (v != null) {
+v.scaleT (ptScale);
 }}
 });
+Clazz.defineMethod (c$, "getBaseSymmetry", 
+function () {
+return (this.baseSymmetry == null ? this.symmetry : this.baseSymmetry);
+});
+Clazz.defineMethod (c$, "finalizeUnitCell", 
+function (ptSupercell) {
+if (ptSupercell != null && this.baseUnitCell != null) {
+this.baseUnitCell[22] = Math.max (1, Clazz.floatToInt (ptSupercell.x));
+this.baseUnitCell[23] = Math.max (1, Clazz.floatToInt (ptSupercell.y));
+this.baseUnitCell[24] = Math.max (1, Clazz.floatToInt (ptSupercell.z));
+}}, "JU.P3");
 Clazz.defineStatics (c$,
 "PARTICLE_NONE", 0,
 "PARTICLE_CHAIN", 1,
