@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.jvxl.data");
-Clazz.load (null, "J.jvxl.data.JvxlCoder", ["java.lang.Character", "$.Float", "JU.BS", "$.Lst", "$.P3", "$.PT", "$.SB", "$.XmlUtil", "J.jvxl.data.VolumeData", "JU.BSUtil", "$.C", "$.Escape", "$.Logger"], function () {
+Clazz.load (null, "J.jvxl.data.JvxlCoder", ["java.lang.Float", "JU.BS", "$.Lst", "$.P3", "$.PT", "$.SB", "$.XmlUtil", "J.jvxl.data.VolumeData", "JU.BSUtil", "$.C", "$.Escape", "$.Logger"], function () {
 c$ = Clazz.declareType (J.jvxl.data, "JvxlCoder");
 c$.jvxlGetFile = Clazz.defineMethod (c$, "jvxlGetFile", 
 function (volumeData, jvxlData, title) {
@@ -149,6 +149,7 @@ if (!Float.isNaN (jvxlData.pointSize)) J.jvxl.data.JvxlCoder.addAttrib (attribs,
  else if (jvxlData.diameter != 0) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  diameter", "" + jvxlData.diameter);
 if (!jvxlData.allowVolumeRender) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  allowVolumeRender", "false");
 if (jvxlData.jvxlPlane == null || vertexDataOnly) {
+if (jvxlData.fixedLattice != null && !vertexDataOnly) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  fixedLattice", "" + jvxlData.fixedLattice);
 if (jvxlData.isContoured) {
 J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  contoured", "true");
 J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  colorMapped", "true");
@@ -189,7 +190,8 @@ if (jvxlData.jvxlPlane != null) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  c
 J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  nContours", "" + jvxlData.contourValues.length);
 J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  contourValues", JU.Escape.eAF (jvxlData.contourValuesUsed == null ? jvxlData.contourValues : jvxlData.contourValuesUsed));
 J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  contourColors", jvxlData.contourColors);
-}}if (jvxlData.insideOut) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  insideOut", "true");
+}if (jvxlData.thisContour > 0) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  thisContour", "" + jvxlData.thisContour);
+}if (jvxlData.insideOut) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  insideOut", "true");
 if (jvxlData.vertexDataOnly) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  note", "vertex/face data only");
  else if (jvxlData.isXLowToHigh) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  note", "progressive JVXL+ -- X values read from low(0) to high(" + (jvxlData.nPointsX - 1) + ")");
 J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  xyzMin", JU.Escape.eP (jvxlData.boundingBox[0]));
@@ -232,12 +234,12 @@ var c1 = ' ';
 var c2 = ' ';
 for (var i = bs.nextSetBit (0); i >= 0; i = bs.nextSetBit (i + 1)) {
 var vertexIndexes = polygonIndexes[i];
-while (pt < nBuf && !Character.isDigit (c1 = fData.charAt (pt++))) {
+while (pt < nBuf && !JU.PT.isDigit (c1 = fData.charAt (pt++))) {
 }
 type = c1.charCodeAt (0) - 48;
-while (pt < nBuf && Character.isWhitespace (c1 = fData.charAt (pt++))) {
+while (pt < nBuf && JU.PT.isWhitespace (c1 = fData.charAt (pt++))) {
 }
-while (pt < nBuf && Character.isWhitespace (c2 = fData.charAt (pt++))) {
+while (pt < nBuf && JU.PT.isWhitespace (c2 = fData.charAt (pt++))) {
 }
 var f1 = J.jvxl.data.JvxlCoder.jvxlFractionFromCharacter (c1.charCodeAt (0), 35, 90, 0);
 var f2 = J.jvxl.data.JvxlCoder.jvxlFractionFromCharacter (c2.charCodeAt (0), 35, 90, 0);
@@ -537,13 +539,13 @@ var value = 0;
 var ich = next[0];
 var ichMax = str.length;
 if (ich < 0) return -2147483648;
-while (ich < ichMax && Character.isWhitespace (str.charAt (ich))) ++ich;
+while (ich < ichMax && JU.PT.isWhitespace (str.charAt (ich))) ++ich;
 
 if (ich >= ichMax) return -2147483648;
 var factor = 1;
 var isLong = (str.charCodeAt (ich) == (offset + base));
 if (isLong) ich++;
-while (ich < ichMax && !Character.isWhitespace (str.charAt (ich))) {
+while (ich < ichMax && !JU.PT.isWhitespace (str.charAt (ich))) {
 var i = str.charCodeAt (ich);
 if (i < offset) i = 92;
 value += (i - offset) * factor;
