@@ -9,9 +9,8 @@ return this.needTranslucent;
 });
 Clazz.overrideMethod (c$, "renderInfo", 
 function () {
-if (this.vwr.am.cmi < 0 || this.mesh.title == null || !this.g3d.setC (this.vwr.getColixBackgroundContrast ())) return;
-var fid = this.g3d.getFontFidFS ("Serif", 14 * this.imageFontScaling);
-this.g3d.setFontFid (fid);
+if (this.isExport || this.vwr.am.cmi < 0 || this.mesh.title == null || !this.g3d.setC (this.vwr.cm.colixBackgroundContrast) || this.vwr.gdata.getTextPosition () != 0) return;
+this.vwr.gdata.setFontFid (this.vwr.gdata.getFontFidFS ("Serif", 14 * this.imageFontScaling));
 var lineheight = Math.round (15 * this.imageFontScaling);
 var x = Math.round (5 * this.imageFontScaling);
 var y = lineheight;
@@ -19,5 +18,6 @@ for (var i = 0; i < this.mesh.title.length; i++) if (this.mesh.title[i].length >
 this.g3d.drawStringNoSlab (this.mesh.title[i], null, x, y, 0, 0);
 y += lineheight;
 }
+this.vwr.gdata.setTextPosition (y);
 });
 });
