@@ -26,7 +26,7 @@ return;
 JU.BSUtil.deleteBits (this.bsHighlight, bs);
 }this.setPropAS (propertyName, value, bs);
 }, "~S,~O,JU.BS");
-Clazz.overrideMethod (c$, "setVisibilityFlags", 
+Clazz.overrideMethod (c$, "setModelVisibilityFlags", 
 function (bs) {
 var bsSelected = (this.vwr.getSelectionHaloEnabled (false) ? this.vwr.bsA () : null);
 for (var i = this.ac; --i >= 0; ) {
