@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.shapesurface");
-Clazz.load (["J.jvxl.api.MeshDataServer", "J.shape.MeshCollection", "JU.P3i", "$.P4"], "J.shapesurface.Isosurface", ["java.io.BufferedReader", "java.lang.Boolean", "$.Float", "java.util.Hashtable", "JU.A4", "$.AU", "$.BS", "$.CU", "$.Lst", "$.M3", "$.P3", "$.PT", "$.Quat", "$.Rdr", "$.SB", "$.V3", "J.jvxl.data.JvxlCoder", "$.JvxlData", "$.MeshData", "J.jvxl.readers.SurfaceGenerator", "J.shape.Mesh", "J.shapesurface.IsosurfaceMesh", "JU.C", "$.Escape", "$.Logger", "$.MeshSurface", "$.Txt", "JV.JC", "$.Viewer"], function () {
+Clazz.load (["J.jvxl.api.MeshDataServer", "J.shape.MeshCollection", "JU.P3i", "$.P4"], "J.shapesurface.Isosurface", ["java.io.BufferedReader", "java.lang.Boolean", "$.Float", "java.util.Hashtable", "JU.A4", "$.AU", "$.BS", "$.CU", "$.Lst", "$.M3", "$.P3", "$.PT", "$.Quat", "$.Rdr", "$.SB", "$.V3", "J.jvxl.data.JvxlCoder", "$.JvxlData", "$.MeshData", "J.jvxl.readers.SurfaceGenerator", "J.shape.Mesh", "J.shapesurface.IsosurfaceMesh", "JU.C", "$.Escape", "$.Logger", "$.TempArray", "JV.JC", "$.Viewer"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.isomeshes = null;
 this.thisMesh = null;
@@ -42,7 +42,7 @@ Clazz.overrideMethod (c$, "allocMesh",
 function (thisID, m) {
 var index = this.meshCount++;
 this.meshes = this.isomeshes = JU.AU.ensureLength (this.isomeshes, this.meshCount * 2);
-this.currentMesh = this.thisMesh = this.isomeshes[index] = (m == null ?  new J.shapesurface.IsosurfaceMesh (thisID, this.colix, index) : m);
+this.currentMesh = this.thisMesh = this.isomeshes[index] = (m == null ?  new J.shapesurface.IsosurfaceMesh (this.vwr, thisID, this.colix, index) : m);
 this.currentMesh.index = index;
 if (this.sg != null) this.sg.setJvxlData (this.jvxlData = this.thisMesh.jvxlData);
 }, "~S,J.shape.Mesh");
@@ -55,8 +55,8 @@ this.newSg ();
 Clazz.defineMethod (c$, "newSg", 
 function () {
 this.sg =  new J.jvxl.readers.SurfaceGenerator (this.vwr, this, null, this.jvxlData =  new J.jvxl.data.JvxlData ());
-this.sg.getParams ().showTiming = this.vwr.getBoolean (603979934);
-this.sg.setVersion ("Jmol " + JV.Viewer.getJmolVersion ());
+this.sg.params.showTiming = this.vwr.getBoolean (603979934);
+this.sg.version = "Jmol " + JV.Viewer.getJmolVersion ();
 });
 Clazz.defineMethod (c$, "clearSg", 
 function () {
@@ -136,7 +136,7 @@ this.thisMesh.colorVertices (JU.C.getColixO (value), bs, false);
 var colors = value;
 var colix0 = JU.C.getColix ((colors[0]).intValue ());
 var colix1 = JU.C.getColix ((colors[1]).intValue ());
-var id = (this.thisMesh != null ? this.thisMesh.thisID : JU.Txt.isWild (this.previousMeshID) ? this.previousMeshID : null);
+var id = (this.thisMesh != null ? this.thisMesh.thisID : JU.PT.isWild (this.previousMeshID) ? this.previousMeshID : null);
 var list = this.getMeshList (id, false);
 for (var i = list.size (); --i >= 0; ) this.setColorPhase (list.get (i), colix0, colix1);
 
@@ -146,7 +146,7 @@ var color = JU.C.getHexCode (JU.C.getColixO (value));
 if (this.thisMesh != null) {
 this.setIsoMeshColor (this.thisMesh, color);
 } else {
-var list = this.getMeshList (JU.Txt.isWild (this.previousMeshID) ? this.previousMeshID : null, false);
+var list = this.getMeshList (JU.PT.isWild (this.previousMeshID) ? this.previousMeshID : null, false);
 for (var i = list.size (); --i >= 0; ) this.setIsoMeshColor (list.get (i), color);
 
 }this.setPropertySuper (propertyName, value, bs);
@@ -175,13 +175,13 @@ return;
 if (!this.iHaveModelIndex) {
 this.modelIndex = (value).intValue ();
 this.isFixed = (this.modelIndex < 0);
-this.sg.setModelIndex (Math.abs (this.modelIndex));
+this.sg.params.modelIndex = Math.abs (this.modelIndex);
 }return;
 }if ("lcaoCartoon" === propertyName || "lonePair" === propertyName || "radical" === propertyName) {
 var info = value;
 if (!this.explicitID) {
 this.setPropertySuper ("thisID", null, null);
-}if (!this.sg.setParameter ("lcaoCartoonCenter", info[2])) this.drawLcaoCartoon (info[0], info[1], info[3], ("lonePair" === propertyName ? 2 : "radical" === propertyName ? 1 : 0));
+}if (!this.sg.setProp ("lcaoCartoonCenter", info[2], null)) this.drawLcaoCartoon (info[0], info[1], info[3], ("lonePair" === propertyName ? 2 : "radical" === propertyName ? 1 : 0));
 return;
 }if ("select" === propertyName) {
 if (this.iHaveBitSets) return;
@@ -220,7 +220,7 @@ return;
 if (this.thisMesh != null) {
 var cmd = value;
 if (cmd != null && !cmd.startsWith ("; isosurface map")) {
-this.thisMesh.setDiscreteColixes (this.sg.getParams ().contoursDiscrete, this.sg.getParams ().contourColixes);
+this.thisMesh.setDiscreteColixes (this.sg.params.contoursDiscrete, this.sg.params.contourColixes);
 this.setJvxlInfo ();
 }this.setScriptInfo (cmd);
 }this.clearSg ();
@@ -228,12 +228,15 @@ return;
 }if ("connections" === propertyName) {
 if (this.currentMesh != null) {
 this.connections = value;
-if (this.connections[0] >= 0 && this.connections[0] < this.vwr.getAtomCount ()) this.currentMesh.connections = this.connections;
+if (this.connections[0] >= 0 && this.connections[0] < this.vwr.ms.ac) this.currentMesh.connections = this.connections;
  else this.connections = this.currentMesh.connections = null;
 }return;
 }if ("cutoffRange" === propertyName) {
 this.cutoffRange = value;
 return;
+}if ("fixLattice" === propertyName) {
+if (this.thisMesh != null) this.thisMesh.fixLattice ();
+return;
 }if ("slab" === propertyName) {
 if (Clazz.instanceOf (value, Integer)) {
 if (this.thisMesh != null) this.thisMesh.jvxlData.slabValue = (value).intValue ();
@@ -253,11 +256,11 @@ this.slabPolygons (slabInfo);
 return;
 }}if ("cap" === propertyName) {
 if (this.thisMesh != null && this.thisMesh.pc != 0) {
-this.thisMesh.slabPolygons (value, true);
+this.thisMesh.getMeshSlicer ().slabPolygons (value, true);
 this.thisMesh.initialize (this.thisMesh.lighting, null, null);
 return;
 }}if ("map" === propertyName) {
-if (this.sg != null) this.sg.getParams ().isMapped = true;
+if (this.sg != null) this.sg.params.isMapped = true;
 this.setProperty ("squareData", Boolean.FALSE, null);
 if (this.thisMesh == null || this.thisMesh.vc == 0) return;
 }if ("deleteVdw" === propertyName) {
@@ -267,9 +270,9 @@ this.currentMesh = this.thisMesh = null;
 return;
 }if ("mapColor" === propertyName || "readFile" === propertyName) {
 if (value == null) {
-value = this.vwr.getBufferedReaderOrErrorMessageFromName (this.sg.getFileName (), null, true);
+value = this.vwr.fm.getBufferedReaderOrErrorMessageFromName (this.sg.params.fileName, null, true, true);
 if (Clazz.instanceOf (value, String)) {
-JU.Logger.error ("Isosurface: could not open file " + this.sg.getFileName () + " -- " + value);
+JU.Logger.error ("Isosurface: could not open file " + this.sg.params.fileName + " -- " + value);
 return;
 }if (!(Clazz.instanceOf (value, java.io.BufferedReader))) try {
 value = JU.Rdr.getBufferedReader (value, "ISO-8859-1");
@@ -294,7 +297,7 @@ this.defaultColix = JU.C.getColix (rgb);
 }} else if ("contour" === propertyName) {
 this.explicitContours = true;
 } else if ("functionXY" === propertyName) {
-if (this.sg.isStateDataRead ()) this.setScriptInfo (null);
+if (this.sg.params.state == 2) this.setScriptInfo (null);
 } else if ("init" === propertyName) {
 this.newSg ();
 } else if ("getSurfaceSets" === propertyName) {
@@ -334,9 +337,9 @@ this.withinDistance2 *= this.withinDistance2;
 this.withinPoints = o[3];
 if (this.withinPoints.size () == 0) this.withinPoints = this.vwr.ms.getAtomPointVector (o[2]);
 } else if (("nci" === propertyName || "orbital" === propertyName) && this.sg != null) {
-this.sg.getParams ().testFlags = (this.vwr.getTestFlag (2) ? 2 : 0);
+this.sg.params.testFlags = (this.vwr.getTestFlag (2) ? 2 : 0);
 }if (this.sg != null && this.sg.setProp (propertyName, value, bs)) {
-if (this.sg.isValid ()) return;
+if (this.sg.isValid) return;
 propertyName = "delete";
 }if ("init" === propertyName) {
 this.explicitID = false;
@@ -345,9 +348,9 @@ var script = (Clazz.instanceOf (value, String) ? value : null);
 var pt = (script == null ? -1 : script.indexOf ("# ID="));
 this.actualID = (pt >= 0 ? JU.PT.getQuotedStringAt (script, pt) : null);
 this.setPropertySuper ("thisID", "+PREVIOUS_MESH+", null);
-if (script != null && !(this.iHaveBitSets = this.getScriptBitSets (script, null))) this.sg.setParameter ("select", bs);
+if (script != null && !(this.iHaveBitSets = this.getScriptBitSets (script, null))) this.sg.setProp ("select", bs, null);
 this.initializeIsosurface ();
-this.sg.setModelIndex (this.isFixed ? -1 : this.modelIndex);
+this.sg.params.modelIndex = (this.isFixed ? -1 : this.modelIndex);
 return;
 }if ("clear" === propertyName) {
 this.discardTempData (true);
@@ -383,6 +386,7 @@ Clazz.defineMethod (c$, "setIsoMeshColor",
 m.jvxlData.baseColor = color;
 m.isColorSolid = true;
 m.pcs = null;
+m.colorsExplicit = false;
 m.colorEncoder = null;
 m.vertexColorMap = null;
 }, "J.shapesurface.IsosurfaceMesh,~S");
@@ -409,7 +413,7 @@ var vertexColixes = this.thisMesh.vcs;
 var colix = (this.thisMesh.isColorSolid ? this.thisMesh.colix : 0);
 this.setProperty ("init", null, null);
 this.setProperty ("map", Boolean.FALSE, null);
-this.setProperty ("property",  Clazz.newFloatArray (this.vwr.getAtomCount (), 0), null);
+this.setProperty ("property",  Clazz.newFloatArray (this.vwr.ms.ac, 0), null);
 if (colix != 0) {
 this.thisMesh.colorCommand = "color isosurface " + JU.C.getHexCode (colix);
 this.setProperty ("color", Integer.$valueOf (JU.C.getArgb (colix)), null);
@@ -421,7 +425,7 @@ this.thisMesh.vcs = vertexColixes;
 }}});
 Clazz.defineMethod (c$, "slabPolygons", 
 function (slabInfo) {
-this.thisMesh.slabPolygons (slabInfo, false);
+this.thisMesh.getMeshSlicer ().slabPolygons (slabInfo, false);
 this.thisMesh.reinitializeLightingAndColor (this.vwr);
 }, "~A");
 Clazz.defineMethod (c$, "setPropertySuper", 
@@ -445,7 +449,7 @@ return true;
 var mesh = this.getMesh (data[0]);
 if (mesh == null) return false;
 data[3] = Integer.$valueOf (mesh.modelIndex);
-mesh.getIntersection (0, data[1], null, data[2], null, null, null, false, false, 135266319, false);
+mesh.getMeshSlicer ().getIntersection (0, data[1], null, data[2], null, null, null, false, false, 135266319, false);
 return true;
 }if (property === "getBoundingBox") {
 var id = data[0];
@@ -490,8 +494,17 @@ Clazz.defineMethod (c$, "getPropI",
 function (property) {
 var ret = this.getPropMC (property);
 if (ret != null) return ret;
-if (property === "dataRange") return (this.thisMesh == null || this.jvxlData.jvxlPlane != null && this.thisMesh.colorEncoder == null ? null : [this.jvxlData.mappedDataMin, this.jvxlData.mappedDataMax, (this.jvxlData.isColorReversed ? this.jvxlData.valueMappedToBlue : this.jvxlData.valueMappedToRed), (this.jvxlData.isColorReversed ? this.jvxlData.valueMappedToRed : this.jvxlData.valueMappedToBlue)]);
-if (property === "moNumber") return Integer.$valueOf (this.moNumber);
+if (property === "message") {
+var s = "";
+if (this.shapeID == 24) s += " with cutoff=" + this.jvxlData.cutoff;
+if (this.jvxlData.dataMin != 3.4028235E38) s += " min=" + this.jvxlData.dataMin + " max=" + this.jvxlData.dataMax;
+s += "; " + JV.JC.shapeClassBases[this.shapeID].toLowerCase () + " count: " + this.getPropMC ("count");
+return s + this.getPropI ("dataRangeStr") + this.jvxlData.msg;
+}if (property === "dataRange") return this.getDataRange ();
+if (property === "dataRangeStr") {
+var dataRange = this.getDataRange ();
+return (dataRange != null && dataRange[0] != 3.4028235E38 && dataRange[0] != dataRange[1] ? "\nisosurface full data range " + dataRange[0] + " to " + dataRange[1] + " with color scheme spanning " + dataRange[2] + " to " + dataRange[3] : "");
+}if (property === "moNumber") return Integer.$valueOf (this.moNumber);
 if (property === "moLinearCombination") return this.moLinearCombination;
 if (property === "nSets") return Integer.$valueOf (this.thisMesh == null ? 0 : this.thisMesh.nSets);
 if (property === "area") return (this.thisMesh == null ? Float.$valueOf (NaN) : this.calculateVolumeOrArea (true));
@@ -507,7 +520,7 @@ this.jvxlData.slabInfo = null;
 if (property === "jvxlMeshXml" || this.jvxlData.vertexDataOnly || this.thisMesh.bsSlabDisplay != null && this.thisMesh.bsSlabGhost == null) {
 meshData =  new J.jvxl.data.MeshData ();
 this.fillMeshData (meshData, 1, null);
-meshData.polygonColorData = J.shapesurface.Isosurface.getPolygonColorData (meshData.pc, meshData.pcs, meshData.bsSlabDisplay);
+meshData.polygonColorData = J.shapesurface.Isosurface.getPolygonColorData (meshData.pc, meshData.pcs, (meshData.colorsExplicit ? meshData.pis : null), meshData.bsSlabDisplay);
 } else if (this.thisMesh.bsSlabGhost != null) {
 this.jvxlData.slabInfo = this.thisMesh.slabOptions.toString ();
 }var sb =  new JU.SB ();
@@ -525,6 +538,10 @@ for (var i = list.size (); --i >= 0; ) this.getMeshCommand (sb, i);
 return sb.toString ();
 }return null;
 }, "~S");
+Clazz.defineMethod (c$, "getDataRange", 
+ function () {
+return (this.thisMesh == null || this.jvxlData.jvxlPlane != null && this.thisMesh.colorEncoder == null ? null : [this.jvxlData.mappedDataMin, this.jvxlData.mappedDataMax, (this.jvxlData.isColorReversed ? this.jvxlData.valueMappedToBlue : this.jvxlData.valueMappedToRed), (this.jvxlData.isColorReversed ? this.jvxlData.valueMappedToRed : this.jvxlData.valueMappedToBlue)]);
+});
 Clazz.defineMethod (c$, "calculateVolumeOrArea", 
  function (isArea) {
 if (isArea) {
@@ -539,31 +556,36 @@ if (!isArea && this.thisMesh.jvxlData.colorDensity) {
 var f = this.thisMesh.jvxlData.voxelVolume;
 f *= (this.thisMesh.bsSlabDisplay == null ? this.thisMesh.vc : this.thisMesh.bsSlabDisplay.cardinality ());
 return this.thisMesh.calculatedVolume = Float.$valueOf (f);
-}var ret = meshData.calculateVolumeOrArea (this.thisMesh.jvxlData.thisSet, isArea, false);
+}var ret = J.jvxl.data.MeshData.calculateVolumeOrArea (meshData, this.thisMesh.jvxlData.thisSet, isArea, false);
+if (this.thisMesh.nSets <= 0) this.thisMesh.nSets = -meshData.nSets;
 if (isArea) this.thisMesh.calculatedArea = ret;
  else this.thisMesh.calculatedVolume = ret;
 return ret;
 }, "~B");
 c$.getPolygonColorData = Clazz.defineMethod (c$, "getPolygonColorData", 
-function (ccount, colixes, bsSlabDisplay) {
-if (colixes == null) return null;
+function (ccount, colixes, polygons, bsSlabDisplay) {
+var isExplicit = (polygons != null);
+if (colixes == null && polygons == null) return null;
 var list1 =  new JU.SB ();
 var count = 0;
 var colix = 0;
+var color = 0;
+var colorNext = 0;
 var done = false;
 for (var i = 0; i < ccount || (done = true) == true; i++) {
 if (!done && bsSlabDisplay != null && !bsSlabDisplay.get (i)) continue;
-if (done || colixes[i] != colix) {
-if (count != 0) list1.append (" ").appendI (count).append (" ").appendI ((colix == 0 ? 0 : JU.C.getArgb (colix)));
+if (done || (isExplicit ? (colorNext = polygons[i][4]) != color : colixes[i] != colix)) {
+if (count != 0) list1.append (" ").appendI (count).append (" ").appendI ((isExplicit ? color : colix == 0 ? 0 : JU.C.getArgb (colix)));
 if (done) break;
-colix = colixes[i];
+if (isExplicit) color = colorNext;
+ else colix = colixes[i];
 count = 1;
 } else {
 count++;
 }}
 list1.append ("\n");
 return list1.toString ();
-}, "~N,~A,JU.BS");
+}, "~N,~A,~A,JU.BS");
 Clazz.overrideMethod (c$, "getShapeState", 
 function () {
 this.clean ();
@@ -578,7 +600,7 @@ Clazz.defineMethod (c$, "getMeshCommand",
 var imesh = this.meshes[i];
 if (imesh == null || imesh.scriptCommand == null) return;
 var cmd = imesh.scriptCommand;
-var modelCount = this.vwr.getModelCount ();
+var modelCount = this.vwr.ms.mc;
 if (modelCount > 1) J.shape.Shape.appendCmd (sb, "frame " + this.vwr.getModelNumberDotted (imesh.modelIndex));
 cmd = JU.PT.rep (cmd, ";; isosurface map", " map");
 cmd = JU.PT.rep (cmd, "; isosurface map", " map");
@@ -603,7 +625,7 @@ if (!imesh.isColorSolid && imesh.colorType == 0 && JU.C.isColixTranslucent (imes
 if (imesh.colorCommand != null && imesh.colorType == 0 && !imesh.colorCommand.equals ("#inherit;")) {
 J.shape.Shape.appendCmd (sb, imesh.colorCommand);
 }var colorArrayed = (imesh.isColorSolid && imesh.pcs != null);
-if (imesh.isColorSolid && imesh.colorType == 0 && !colorArrayed) {
+if (imesh.isColorSolid && imesh.colorType == 0 && !imesh.colorsExplicit && !colorArrayed) {
 J.shape.Shape.appendCmd (sb, J.shape.Shape.getColorCommandUnk (this.myType, imesh.colix, this.translucentAllowed));
 } else if (imesh.jvxlData.isBicolorMap && imesh.colorPhased) {
 J.shape.Shape.appendCmd (sb, "color isosurface phase " + J.shape.Shape.encodeColor (imesh.jvxlData.minColorIndex) + " " + J.shape.Shape.encodeColor (imesh.jvxlData.maxColorIndex));
@@ -631,13 +653,13 @@ if (i < 0) return false;
 var j = script.indexOf ("})", i);
 if (j < 0) return false;
 var bs = JU.BS.unescape (script.substring (i + 2, j + 2));
-if (bsCmd == null) this.sg.setParameter ("select", bs);
+if (bsCmd == null) this.sg.setProp ("select", bs, null);
  else bsCmd[0] = bs;
 if ((i = script.indexOf ("({", j)) < 0) return true;
 j = script.indexOf ("})", i);
 if (j < 0) return false;
 bs = JU.BS.unescape (script.substring (i + 1, j + 1));
-if (bsCmd == null) this.sg.setParameter ("ignore", bs);
+if (bsCmd == null) this.sg.setProp ("ignore", bs, null);
  else bsCmd[1] = bs;
 if ((i = script.indexOf ("/({", j)) == j + 2) {
 if ((j = script.indexOf ("})", i)) < 0) return false;
@@ -649,16 +671,32 @@ if (bsCmd == null) this.vwr.ms.setTrajectoryBs (bs);
 Clazz.defineMethod (c$, "getCapSlabInfo", 
 function (script) {
 var i = script.indexOf ("# SLAB=");
-if (i >= 0) this.sg.setParameter ("slab", JU.MeshSurface.getCapSlabObject (JU.PT.getQuotedStringAt (script, i), false));
+if (i >= 0) this.sg.setProp ("slab", this.getCapSlabObject (JU.PT.getQuotedStringAt (script, i), false), null);
 i = script.indexOf ("# CAP=");
-if (i >= 0) this.sg.setParameter ("slab", JU.MeshSurface.getCapSlabObject (JU.PT.getQuotedStringAt (script, i), true));
+if (i >= 0) this.sg.setProp ("slab", this.getCapSlabObject (JU.PT.getQuotedStringAt (script, i), true), null);
 }, "~S");
+Clazz.defineMethod (c$, "getCapSlabObject", 
+ function (s, isCap) {
+try {
+if (s.indexOf ("array") == 0) {
+var pts = JU.PT.split (s.substring (6, s.length - 1), ",");
+return JU.TempArray.getSlabObjectType (1679429641, [JU.Escape.uP (pts[0]), JU.Escape.uP (pts[1]), JU.Escape.uP (pts[2]), JU.Escape.uP (pts[3])], isCap, null);
+}var plane = JU.Escape.uP (s);
+if (Clazz.instanceOf (plane, JU.P4)) return JU.TempArray.getSlabObjectType (135266319, plane, isCap, null);
+} catch (e) {
+if (Clazz.exceptionOf (e, Exception)) {
+} else {
+throw e;
+}
+}
+return null;
+}, "~S,~B");
 Clazz.defineMethod (c$, "initializeIsosurface", 
  function () {
 if (!this.iHaveModelIndex) this.modelIndex = this.vwr.am.cmi;
 this.atomIndex = -1;
 this.bsDisplay = null;
-this.center = JU.P3.new3 (3.4028235E38, 3.4028235E38, 3.4028235E38);
+this.center = JU.P3.new3 (NaN, 0, 0);
 this.colix = 5;
 this.connections = null;
 this.cutoffRange = null;
@@ -683,7 +721,7 @@ this.sg.initState ();
 Clazz.defineMethod (c$, "setMeshI", 
  function () {
 this.thisMesh.visible = true;
-if ((this.thisMesh.atomIndex = this.atomIndex) >= 0) this.thisMesh.modelIndex = this.vwr.getAtomModelIndex (this.atomIndex);
+if ((this.thisMesh.atomIndex = this.atomIndex) >= 0) this.thisMesh.modelIndex = this.vwr.ms.at[this.atomIndex].mi;
  else if (this.isFixed) this.thisMesh.modelIndex = -1;
  else if (this.modelIndex >= 0) this.thisMesh.modelIndex = this.modelIndex;
  else this.thisMesh.modelIndex = this.vwr.am.cmi;
@@ -701,16 +739,16 @@ this.thisMesh.surfaceSet = null;
 Clazz.defineMethod (c$, "getDefaultColix", 
  function () {
 if (this.defaultColix != 0) return this.defaultColix;
-if (!this.sg.isCubeData ()) return this.colix;
-var argb = (this.sg.getCutoff () >= 0 ? -11525984 : -6283184);
+if (!this.sg.jvxlData.wasCubic) return this.colix;
+var argb = (this.sg.params.cutoff >= 0 ? -11525984 : -6283184);
 return JU.C.getColix (argb);
 });
 Clazz.defineMethod (c$, "drawLcaoCartoon", 
  function (z, x, rotAxis, nElectrons) {
 var lcaoCartoon = this.sg.setLcao ();
 var rotRadians = rotAxis.x + rotAxis.y + rotAxis.z;
-this.defaultColix = JU.C.getColix (this.sg.getColor (1));
-var colixNeg = JU.C.getColix (this.sg.getColor (-1));
+this.defaultColix = JU.C.getColix (this.sg.params.colorPos);
+var colixNeg = JU.C.getColix (this.sg.params.colorNeg);
 var y =  new JU.V3 ();
 var isReverse = (lcaoCartoon.length > 0 && lcaoCartoon.charAt (0) == '-');
 if (isReverse) lcaoCartoon = lcaoCartoon.substring (1);
@@ -777,7 +815,7 @@ return;
 this.createLcaoLobe (y, -sense, nElectrons);
 return;
 }if (lcaoCartoon.equals ("spacefill") || lcaoCartoon.equals ("cpk")) {
-this.createLcaoLobe (null, 2 * this.vwr.getAtomRadius (this.atomIndex), nElectrons);
+this.createLcaoLobe (null, 2 * this.vwr.ms.at[this.atomIndex].getRadius (), nElectrons);
 return;
 }this.createLcaoLobe (null, 1, nElectrons);
 return;
@@ -810,7 +848,7 @@ Clazz.overrideMethod (c$, "fillMeshData",
 function (meshData, mode, mesh) {
 if (meshData == null) {
 if (this.thisMesh == null) this.allocMesh (null, null);
-if (!this.thisMesh.isMerged) this.thisMesh.clearType (this.myType, this.sg.getIAddGridPoints ());
+if (!this.thisMesh.isMerged) this.thisMesh.clearType (this.myType, this.sg.params.iAddGridPoints);
 this.thisMesh.connections = this.connections;
 this.thisMesh.colix = this.getDefaultColix ();
 this.thisMesh.colorType = this.colorType;
@@ -837,6 +875,7 @@ meshData.slabMeshType = mesh.slabMeshType;
 meshData.polygonCount0 = mesh.polygonCount0;
 meshData.vertexCount0 = mesh.vertexCount0;
 meshData.slabOptions = mesh.slabOptions;
+meshData.colorsExplicit = mesh.colorsExplicit;
 return;
 case 2:
 if (mesh.vcs == null || mesh.vc > mesh.vcs.length) mesh.vcs =  Clazz.newShortArray (mesh.vc, 0);
@@ -864,6 +903,7 @@ mesh.polygonCount0 = meshData.polygonCount0;
 mesh.vertexCount0 = meshData.vertexCount0;
 mesh.mergeVertexCount0 = meshData.mergeVertexCount0;
 mesh.slabOptions = meshData.slabOptions;
+mesh.colorsExplicit = meshData.colorsExplicit;
 return;
 }
 }, "J.jvxl.data.MeshData,~N,J.shapesurface.IsosurfaceMesh");
@@ -872,44 +912,45 @@ function () {
 this.setMeshI ();
 this.setBsVdw ();
 this.thisMesh.insideOut = this.sg.isInsideOut ();
-this.thisMesh.vertexSource = this.sg.getVertexSource ();
+this.thisMesh.vertexSource = this.sg.params.vertexSource;
 this.thisMesh.spanningVectors = this.sg.getSpanningVectors ();
 this.thisMesh.calculatedArea = null;
 this.thisMesh.calculatedVolume = null;
-var params = this.sg.getParams ();
-if (!this.thisMesh.isMerged) this.thisMesh.initialize (this.sg.isFullyLit () ? 1073741964 : 1073741958, null, this.sg.getPlane ());
-if (!params.allowVolumeRender) this.thisMesh.jvxlData.allowVolumeRender = false;
-this.thisMesh.setColorsFromJvxlData (this.sg.getParams ().colorRgb);
+if (!this.thisMesh.isMerged) {
+this.thisMesh.initialize (this.sg.isFullyLit () ? 1073741964 : 1073741958, null, this.sg.params.thePlane);
+if (this.jvxlData.fixedLattice != null) {
+this.thisMesh.lattice = this.jvxlData.fixedLattice;
+this.thisMesh.fixLattice ();
+}return;
+}if (!this.sg.params.allowVolumeRender) this.thisMesh.jvxlData.allowVolumeRender = false;
+this.thisMesh.setColorsFromJvxlData (this.sg.params.colorRgb);
 if (this.thisMesh.jvxlData.slabInfo != null) this.vwr.runScript ("isosurface " + this.thisMesh.jvxlData.slabInfo);
-if (this.sg.getParams ().psi_monteCarloCount > 0) this.thisMesh.diameter = -1;
+if (this.sg.params.psi_monteCarloCount > 0) this.thisMesh.diameter = -1;
 });
 Clazz.overrideMethod (c$, "notifySurfaceMappingCompleted", 
 function () {
-if (!this.thisMesh.isMerged) {
-this.thisMesh.initialize (this.sg.isFullyLit () ? 1073741964 : 1073741958, null, this.sg.getPlane ());
-this.thisMesh.setJvxlDataRendering ();
-}this.setBsVdw ();
+if (!this.thisMesh.isMerged) this.thisMesh.initialize (this.sg.isFullyLit () ? 1073741964 : 1073741958, null, this.sg.params.thePlane);
+this.setBsVdw ();
 this.thisMesh.isColorSolid = false;
 this.thisMesh.colorDensity = this.jvxlData.colorDensity;
 this.thisMesh.volumeRenderPointSize = this.jvxlData.pointSize;
-this.thisMesh.colorEncoder = this.sg.getColorEncoder ();
+this.thisMesh.colorEncoder = this.sg.params.colorEncoder;
 this.thisMesh.getContours ();
 if (this.thisMesh.jvxlData.nContours != 0 && this.thisMesh.jvxlData.nContours != -1) this.explicitContours = true;
 if (this.explicitContours && this.thisMesh.jvxlData.jvxlPlane != null) this.thisMesh.havePlanarContours = true;
 this.setPropertySuper ("token", Integer.$valueOf (this.explicitContours ? 1073742046 : 1073741938), null);
 this.setPropertySuper ("token", Integer.$valueOf (this.explicitContours ? 1073741898 : 1073742039), null);
-var slabInfo = this.sg.getSlabInfo ();
-if (slabInfo != null) {
-this.thisMesh.slabPolygonsList (slabInfo, false);
+if (!this.thisMesh.isMerged) this.thisMesh.setJvxlDataRendering ();
+if (this.sg.params.slabInfo != null) {
+this.thisMesh.slabPolygonsList (this.sg.params.slabInfo, false);
 this.thisMesh.reinitializeLightingAndColor (this.vwr);
 }this.thisMesh.setColorCommand ();
 });
 Clazz.defineMethod (c$, "setBsVdw", 
  function () {
-var bs = this.sg.geVdwBitSet ();
-if (bs == null) return;
+if (this.sg.bsVdw == null) return;
 if (this.thisMesh.bsVdw == null) this.thisMesh.bsVdw =  new JU.BS ();
-this.thisMesh.bsVdw.or (bs);
+this.thisMesh.bsVdw.or (this.sg.bsVdw);
 });
 Clazz.overrideMethod (c$, "calculateGeodesicSurface", 
 function (bsSelected, envelopeRadius) {
@@ -925,12 +966,12 @@ if (this.cutoffRange != null && (value < this.cutoffRange[0] || value > this.cut
 return (this.withinPoints != null && !J.shape.Mesh.checkWithin (vertexXYZ, this.withinPoints, this.withinDistance2, this.isWithinNot) ? -1 : this.thisMesh.addVertexCopy (vertexXYZ, value, assocVertex, this.associateNormals, asCopy));
 }, "JU.T3,~N,~N,~B");
 Clazz.overrideMethod (c$, "addTriangleCheck", 
-function (iA, iB, iC, check, check2, isAbsolute, color) {
-return (iA < 0 || iB < 0 || iC < 0 || isAbsolute && !J.jvxl.data.MeshData.checkCutoff (iA, iB, iC, this.thisMesh.vvs) ? -1 : this.thisMesh.addTriangleCheck (iA, iB, iC, check, check2, color));
+function (iA, iB, iC, check, iContour, isAbsolute, color) {
+return (iA < 0 || iB < 0 || iC < 0 || isAbsolute && !J.jvxl.data.MeshData.checkCutoff (iA, iB, iC, this.thisMesh.vvs) ? -1 : this.thisMesh.addTriangleCheck (iA, iB, iC, check, iContour, color));
 }, "~N,~N,~N,~N,~N,~B,~N");
 Clazz.defineMethod (c$, "setScriptInfo", 
 function (strCommand) {
-var script = (strCommand == null ? this.sg.getScript () : strCommand);
+var script = (strCommand == null ? this.sg.params.script : strCommand);
 var pt = (script == null ? -1 : script.indexOf ("; isosurface map"));
 if (pt == 0) {
 if (this.thisMesh.scriptCommand == null) return;
@@ -938,9 +979,9 @@ pt = this.thisMesh.scriptCommand.indexOf ("; isosurface map");
 if (pt >= 0) this.thisMesh.scriptCommand = this.thisMesh.scriptCommand.substring (0, pt);
 this.thisMesh.scriptCommand += script;
 return;
-}this.thisMesh.title = this.sg.getTitle ();
-this.thisMesh.dataType = this.sg.getParams ().dataType;
-this.thisMesh.scale3d = this.sg.getParams ().scale3d;
+}this.thisMesh.title = this.sg.params.title;
+this.thisMesh.dataType = this.sg.params.dataType;
+this.thisMesh.scale3d = this.sg.params.scale3d;
 if (script != null) {
 if (script.charAt (0) == ' ') {
 script = this.myType + " ID " + JU.PT.esc (this.thisMesh.thisID) + script;
@@ -956,7 +997,7 @@ if (this.scriptAppendix.indexOf (fileName) < 0) this.scriptAppendix += fileName;
 }, "~S");
 Clazz.defineMethod (c$, "setJvxlInfo", 
  function () {
-if (this.sg.getJvxlData () !== this.jvxlData || this.sg.getJvxlData () !== this.thisMesh.jvxlData) this.jvxlData = this.thisMesh.jvxlData = this.sg.getJvxlData ();
+if (this.sg.jvxlData !== this.jvxlData || this.sg.jvxlData !== this.thisMesh.jvxlData) this.jvxlData = this.thisMesh.jvxlData = this.sg.jvxlData;
 });
 Clazz.overrideMethod (c$, "getShapeDetail", 
 function () {
@@ -977,7 +1018,7 @@ info.put ("visible", Boolean.$valueOf (mesh.visible));
 info.put ("vertexCount", Integer.$valueOf (mesh.vc));
 if (mesh.calculatedVolume != null) info.put ("volume", mesh.calculatedVolume);
 if (mesh.calculatedArea != null) info.put ("area", mesh.calculatedArea);
-if (mesh.ptCenter.x != 3.4028235E38) info.put ("center", mesh.ptCenter);
+if (!Float.isNaN (mesh.ptCenter.x)) info.put ("center", mesh.ptCenter);
 if (mesh.mat4 != null) info.put ("mat4", mesh.mat4);
 if (mesh.scale3d != 0) info.put ("scale3d", Float.$valueOf (mesh.scale3d));
 info.put ("xyzMin", mesh.jvxlData.boundingBox[0]);
@@ -1006,7 +1047,7 @@ return true;
 }if (!this.vwr.getDrawHover ()) return false;
 var s = this.findValue (x, y, false, bsVisible);
 if (s == null) return false;
-if (this.gdata.isDisplayAntialiased ()) {
+if (this.vwr.gdata.antialiasEnabled) {
 x <<= 1;
 y <<= 1;
 }this.vwr.hoverOnPt (x, y, s, this.pickedMesh.thisID, this.pickedPt);
@@ -1032,7 +1073,7 @@ s = "" + (vContours[i].get (2)).floatValue ();
 var g = this.thisMesh.colorEncoder.quantize (f, true);
 f = this.thisMesh.colorEncoder.quantize (f, false);
 s = "" + g + " - " + f;
-}if (this.gdata.isAntialiased ()) {
+}if (this.vwr.gdata.isAntialiased ()) {
 x <<= 1;
 y <<= 1;
 }this.vwr.hoverOnPt (x, y, s, null, null);
@@ -1048,7 +1089,7 @@ function (x, y, action, bsVisible, drawPicking) {
 if (!drawPicking) return null;
 if (!this.vwr.isBound (action, 18)) return null;
 var dmin2 = 100;
-if (this.gdata.isAntialiased ()) {
+if (this.vwr.gdata.isAntialiased ()) {
 x <<= 1;
 y <<= 1;
 dmin2 <<= 1;
@@ -1096,7 +1137,7 @@ return m.visibilityFlags != 0 && (m.modelIndex < 0 || bsVisible.get (m.modelInde
 Clazz.defineMethod (c$, "findValue", 
  function (x, y, isPicking, bsVisible) {
 var dmin2 = 100;
-if (this.gdata.isAntialiased ()) {
+if (this.vwr.gdata.isAntialiased ()) {
 x <<= 1;
 y <<= 1;
 dmin2 <<= 1;
@@ -1138,6 +1179,20 @@ this.pickedPt = v;
 }}
 if (pickedVertex != -1) break;
 } else if (m.vvs != null) {
+if (m.bsSlabDisplay != null) {
+for (var k = m.bsSlabDisplay.nextSetBit (0); k >= 0; k = m.bsSlabDisplay.nextSetBit (k + 1)) {
+var p = m.pis[k];
+for (var l = 0; l < 3; l++) {
+var v = m.vs[p[l]];
+var d2 = this.coordinateInRange (x, y, v, dmin2, this.ptXY);
+if (d2 >= 0) {
+dmin2 = d2;
+pickedVertex = p[l];
+this.pickedMesh = m;
+this.pickedPt = v;
+}}
+}
+} else {
 for (var k = m.vc; --k >= ilast; ) {
 var v = m.vs[k];
 var d2 = this.coordinateInRange (x, y, v, dmin2, this.ptXY);
@@ -1147,7 +1202,7 @@ pickedVertex = k;
 this.pickedMesh = m;
 this.pickedPt = v;
 }}
-if (pickedVertex != -1) break;
+}if (pickedVertex != -1) break;
 }}
 return (pickedVertex == -1 ? null : (JU.Logger.debugging ? "$" + m.thisID + "[" + (pickedVertex + 1) + "] " + m.vs[pickedVertex] + ": " : m.thisID + ": ") + m.vvs[pickedVertex]);
 }, "~N,~N,~B,JU.BS");
