@@ -1,13 +1,12 @@
 Clazz.declarePackage ("JM");
-Clazz.load (["JM.AtomCollection", "JU.BS"], "JM.BondCollection", ["JU.AU", "JM.Bond", "$.BondIteratorSelected", "$.HBond", "JU.BSUtil", "$.Edge", "$.Logger"], function () {
+Clazz.load (["JM.AtomCollection"], "JM.BondCollection", ["JU.AU", "$.BS", "JM.Bond", "$.BondIteratorSelected", "$.HBond", "JU.BSUtil", "$.C", "$.Edge", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
-this.molecules = null;
-this.moleculeCount = 0;
 this.bo = null;
 this.bondCount = 0;
 this.numCached = null;
 this.freeBonds = null;
-this.haveWarned = false;
+this.molecules = null;
+this.moleculeCount = 0;
 this.defaultCovalentMad = 0;
 this.bsAromaticSingle = null;
 this.bsAromaticDouble = null;
@@ -15,13 +14,14 @@ this.bsAromatic = null;
 this.haveHiddenBonds = false;
 Clazz.instantialize (this, arguments);
 }, JM, "BondCollection", JM.AtomCollection);
-Clazz.prepareFields (c$, function () {
+Clazz.defineMethod (c$, "setupBC", 
+function () {
+this.bsAromatic =  new JU.BS ();
 this.numCached =  Clazz.newIntArray (5, 0);
 this.freeBonds =  new Array (5);
-{
 for (var i = 5; --i > 0; ) this.freeBonds[i] =  new Array (200);
 
-}this.bsAromatic =  new JU.BS ();
+this.setupAC ();
 });
 Clazz.overrideMethod (c$, "releaseModelSet", 
 function () {
@@ -38,10 +38,6 @@ function () {
 this.molecules = null;
 this.moleculeCount = 0;
 });
-Clazz.defineMethod (c$, "getBondAt", 
-function (bondIndex) {
-return this.bo[bondIndex];
-}, "~N");
 Clazz.defineMethod (c$, "getBondIteratorForType", 
 function (bondType, bsAtoms) {
 return  new JM.BondIteratorSelected (this.bo, this.bondCount, bondType, bsAtoms, this.vwr.getBoolean (603979812));
@@ -50,33 +46,13 @@ Clazz.defineMethod (c$, "getBondIterator",
 function (bsBonds) {
 return  new JM.BondIteratorSelected (this.bo, this.bondCount, 131071, bsBonds, false);
 }, "JU.BS");
-Clazz.defineMethod (c$, "getBondAtom1", 
-function (i) {
-return this.bo[i].atom1;
-}, "~N");
-Clazz.defineMethod (c$, "getBondAtom2", 
-function (i) {
-return this.bo[i].atom2;
-}, "~N");
-Clazz.defineMethod (c$, "getBondRadius", 
-function (i) {
-return this.bo[i].getRadius ();
-}, "~N");
-Clazz.defineMethod (c$, "getBondOrder", 
-function (i) {
-return this.bo[i].order;
-}, "~N");
 Clazz.defineMethod (c$, "getBondColix1", 
 function (i) {
-return this.bo[i].getColix1 ();
+return JU.C.getColixInherited (this.bo[i].colix, this.bo[i].atom1.colixAtom);
 }, "~N");
 Clazz.defineMethod (c$, "getBondColix2", 
 function (i) {
-return this.bo[i].getColix2 ();
-}, "~N");
-Clazz.defineMethod (c$, "getBondModelIndex", 
-function (i) {
-return this.bo[i].atom1.mi;
+return JU.C.getColixInherited (this.bo[i].colix, this.bo[i].atom2.colixAtom);
 }, "~N");
 Clazz.defineMethod (c$, "getBondCountInModel", 
 function (modelIndex) {
@@ -107,7 +83,7 @@ atom1.group.addAtoms (atom1.i);
 }}return bond;
 }, "JM.Atom,JM.Atom,~N,~N,JU.BS,~N,~B,~B");
 Clazz.defineMethod (c$, "getOrAddBond", 
- function (atom, atomOther, order, mad, bsBonds, energy, overrideBonding) {
+function (atom, atomOther, order, mad, bsBonds, energy, overrideBonding) {
 var i;
 if (order == 131071 || order == 65535) order = 1;
 if (atom.isBonded (atomOther)) {
@@ -175,20 +151,6 @@ var maxAcceptable = bondingRadiusA + bondingRadiusB + bondTolerance;
 var maxAcceptable2 = maxAcceptable * maxAcceptable;
 return (distance2 > maxAcceptable2 ? 0 : 1);
 }, "~N,~N,~N,~N,~N");
-Clazz.defineMethod (c$, "checkValencesAndBond", 
-function (atomA, atomB, order, mad, bsBonds) {
-if (atomA.getCurrentBondCount () > 20 || atomB.getCurrentBondCount () > 20) {
-if (!this.haveWarned) JU.Logger.warn ("maximum auto bond count reached");
-this.haveWarned = true;
-return false;
-}var formalChargeA = atomA.getFormalCharge ();
-if (formalChargeA != 0) {
-var formalChargeB = atomB.getFormalCharge ();
-if ((formalChargeA < 0 && formalChargeB < 0) || (formalChargeA > 0 && formalChargeB > 0)) return false;
-}if (atomA.altloc != atomB.altloc && atomA.altloc != '\0' && atomB.altloc != '\0' && this.getVibration (atomA.i, false) == null) return false;
-this.getOrAddBond (atomA, atomB, order, mad, bsBonds, 0, false);
-return true;
-}, "JM.Atom,JM.Atom,~N,~N,JU.BS");
 Clazz.defineMethod (c$, "deleteAllBonds2", 
 function () {
 this.vwr.setShapeProperty (1, "reset", null);
@@ -283,10 +245,6 @@ var bond = this.bo[i];
 if (bond.isAromatic ()) bond.setOrder (515);
 }
 });
-Clazz.defineMethod (c$, "assignAromaticBonds", 
-function () {
-this.assignAromaticBondsBs (true, null);
-});
 Clazz.defineMethod (c$, "assignAromaticBondsBs", 
 function (isUserCalculation, bsBonds) {
 if (!isUserCalculation) this.bsAromatic =  new JU.BS ();
@@ -493,15 +451,15 @@ try {
 if (bondOrder == 0) {
 var bs =  new JU.BS ();
 bs.set (bond.index);
-bsAtoms.set (bond.getAtomIndex1 ());
-bsAtoms.set (bond.getAtomIndex2 ());
+bsAtoms.set (bond.atom1.i);
+bsAtoms.set (bond.atom2.i);
 this.dBm (bs, false);
 return bsAtoms;
 }bond.setOrder (bondOrder | 131072);
 this.removeUnnecessaryBonds (bond.atom1, false);
 this.removeUnnecessaryBonds (bond.atom2, false);
-bsAtoms.set (bond.getAtomIndex1 ());
-bsAtoms.set (bond.getAtomIndex2 ());
+bsAtoms.set (bond.atom1.i);
+bsAtoms.set (bond.atom2.i);
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
 JU.Logger.error ("Exception in seBondOrder: " + e.toString ());
