@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["javajs.api.JSONEncodable", "JS.T", "JU.P3"], "JS.SV", ["java.lang.Boolean", "$.Float", "java.util.Arrays", "$.Collections", "$.Hashtable", "$.Map", "JU.AU", "$.BArray", "$.BS", "$.Base64", "$.Lst", "$.M3", "$.M34", "$.M4", "$.Measure", "$.P4", "$.PT", "$.Quat", "$.SB", "$.T3", "$.V3", "JM.BondSet", "JS.ScriptContext", "JU.BSUtil", "$.Escape", "$.Txt"], function () {
+Clazz.load (["javajs.api.JSONEncodable", "JS.T", "JU.P3"], "JS.SV", ["java.lang.Boolean", "$.Float", "java.util.Arrays", "$.Collections", "$.Hashtable", "$.Map", "JU.AU", "$.BArray", "$.BS", "$.Base64", "$.Lst", "$.M3", "$.M34", "$.M4", "$.Measure", "$.P4", "$.PT", "$.Quat", "$.SB", "$.T3", "$.V3", "JM.BondSet", "JS.ScriptContext", "JU.BSUtil", "$.Escape"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.index = 2147483647;
 this.flags = 2;
@@ -620,7 +620,7 @@ var tokenOut = JS.SV.newSV (tokenIn.tok, 2147483647, null);
 switch (tokenIn.tok) {
 case 10:
 if (Clazz.instanceOf (tokenIn.value, JM.BondSet)) {
-bs =  new JM.BondSet (tokenIn.value, (tokenIn.value).getAssociatedAtoms ());
+bs = JM.BondSet.newBS (tokenIn.value, (tokenIn.value).associatedAtoms);
 len = JU.BSUtil.cardinalityOf (bs);
 } else {
 bs = JU.BSUtil.copy (tokenIn.value);
@@ -817,7 +817,7 @@ if (v == null) v = JU.Escape.uABsM (s);
 if (Clazz.instanceOf (v, JU.P3)) return (JS.SV.newV (8, v));
 if (Clazz.instanceOf (v, JU.P4)) return JS.SV.newV (9, v);
 if (Clazz.instanceOf (v, JU.BS)) {
-if (s != null && s.indexOf ("[{") == 0) v =  new JM.BondSet (v);
+if (s != null && s.indexOf ("[{") == 0) v = JM.BondSet.newBS (v, null);
 return JS.SV.newV (10, v);
 }if (Clazz.instanceOf (v, JU.M34)) return (JS.SV.newV (Clazz.instanceOf (v, JU.M3) ? 11 : 12, v));
 return o;
@@ -852,7 +852,7 @@ if (ve != null) ve[0] = JS.SV.fValue ($var);
 if (getS) of[3] = JS.SV.sValue ($var);
 if (getP) of[4] = $var.value;
 if (getQ) of[5] = $var.value;
-return JU.Txt.sprintf (strFormat, "IFDspq", of);
+return JU.PT.sprintf (strFormat, "IFDspq", of);
 }, "~S,JS.SV,~A,~A,~A,~A,~B,~B,~B");
 c$.getFormatType = Clazz.defineMethod (c$, "getFormatType", 
 function (format) {
@@ -904,7 +904,7 @@ var sb =  new JU.SB ();
 var format = JU.PT.split (JU.PT.rep (JS.SV.sValue (args[0]), "%%", "\1"), "%");
 sb.append (format[0]);
 for (var i = 1; i < format.length; i++) {
-var ret = JS.SV.sprintf (JU.Txt.formatCheck ("%" + format[i]), (i < args.length ? args[i] : null));
+var ret = JS.SV.sprintf (JU.PT.formatCheck ("%" + format[i]), (i < args.length ? args[i] : null));
 if (JU.PT.isAS (ret)) {
 var list = ret;
 for (var j = 0; j < list.length; j++) sb.append (list[j]).append ("\n");
