@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["JS.ScriptTokenParser", "JU.Lst"], "JS.ScriptCompiler", ["java.lang.Boolean", "$.Character", "$.Float", "java.util.Hashtable", "JU.AU", "$.BS", "$.M34", "$.M4", "$.PT", "$.SB", "J.api.Interface", "J.i18n.GT", "J.io.JmolBinary", "JM.BondSet", "$.Group", "JS.ContextToken", "$.SV", "$.ScriptContext", "$.ScriptError", "$.ScriptFlowContext", "$.ScriptFunction", "$.ScriptManager", "$.ScriptParam", "$.T", "JU.Escape", "$.Logger", "JV.Viewer"], function () {
+Clazz.load (["JS.ScriptTokenParser", "JU.Lst"], "JS.ScriptCompiler", ["java.lang.Boolean", "$.Float", "java.util.Hashtable", "JU.AU", "$.BS", "$.M34", "$.M4", "$.PT", "$.SB", "J.api.Interface", "J.i18n.GT", "J.io.JmolBinary", "JM.BondSet", "$.Group", "JS.ContextToken", "$.SV", "$.ScriptContext", "$.ScriptError", "$.ScriptFlowContext", "$.ScriptFunction", "$.ScriptManager", "$.ScriptParam", "$.T", "JU.Escape", "$.Logger", "JV.Viewer"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.filename = null;
 this.isSilent = false;
@@ -59,7 +59,6 @@ this.vPush =  new JU.Lst ();
 });
 Clazz.makeConstructor (c$, 
 function (vwr) {
-Clazz.superConstructor (this, JS.ScriptCompiler, []);
 this.vwr = vwr;
 }, "JV.Viewer");
 Clazz.defineMethod (c$, "compile", 
@@ -603,9 +602,9 @@ Clazz.defineMethod (c$, "checkSpecialParameterSyntax",
  function () {
 if (this.lookingAtString (!this.implicitString)) {
 if (this.cchToken < 0) return this.ERROR (4);
-var str = this.getUnescapedStringLiteral (this.lastToken != null && !this.iHaveQuotedString && this.lastToken.tok != 1073741983 && (this.tokCommand == 1085443 && this.nTokens == 2 && this.lastToken.tok == 545259546 || this.tokCommand == 135271426 || this.tokCommand == 1610616835 || this.tokCommand == 135271429));
+var str = this.getUnescapedStringLiteral (this.lastToken != null && !this.iHaveQuotedString && this.lastToken.tok != 1073741983 && (this.tokCommand == 1085443 && this.nTokens == 2 && this.lastToken.tok == 545259546 || this.tokCommand == 135271427 || this.tokCommand == 1610616835 || this.tokCommand == 135271429));
 this.iHaveQuotedString = true;
-if (this.tokCommand == 135271426 && this.lastToken.tok == 135270408 || this.tokCommand == 135270408 && str.indexOf ("@") < 0) {
+if (this.tokCommand == 135271427 && this.lastToken.tok == 135270408 || this.tokCommand == 135270408 && str.indexOf ("@") < 0) {
 if (!this.getData (str)) {
 return this.ERROR (11, "data");
 }} else {
@@ -658,13 +657,13 @@ return 2;
 }}}switch (this.tokCommand) {
 case 135270926:
 if (this.nTokens != 2 || this.lastToken.tok != 1073741925 && this.lastToken.tok != 1073742189) return 0;
-case 135271426:
+case 135271427:
 case 135271429:
 case 1276121098:
 if (this.script.charAt (this.ichToken) == '@') {
 this.iHaveQuotedString = true;
 return 0;
-}if (this.tokCommand == 135271426) {
+}if (this.tokCommand == 135271427) {
 if (this.nTokens == 1 || this.nTokens == 2 && this.tokAt (1) == 1073741839) {
 var isDataBase = JV.Viewer.isDatabaseCode (this.charAt (this.ichToken));
 if (this.lookingAtLoadFormat (isDataBase)) {
@@ -674,6 +673,7 @@ switch (token == null ? 0 : token.tok) {
 case 1073742015:
 case 1073742077:
 case 1073741839:
+case 1610616855:
 if (this.nTokens != 1) return 4;
 case 135270408:
 case 1229984263:
@@ -696,7 +696,7 @@ if (this.script.charAt (this.ichToken) == '{' || this.parenCount > 0) break;
 if ((bs = this.lookingAtBitset ()) != null) {
 this.addTokenToPrefix (JS.T.o (10, bs));
 return 2;
-}}if (!this.iHaveQuotedString && this.lookingAtImpliedString (this.tokCommand == 135270926, this.tokCommand == 135271426, this.nTokens > 1 || this.tokCommand != 135271429)) {
+}}if (!this.iHaveQuotedString && this.lookingAtImpliedString (this.tokCommand == 135270926, this.tokCommand == 135271427, this.nTokens > 1 || this.tokCommand != 135271429)) {
 var str = this.script.substring (this.ichToken, this.ichToken + this.cchToken);
 if (this.tokCommand == 135271429) {
 if (str.startsWith ("javascript:")) {
@@ -787,7 +787,7 @@ return 2;
 var isBondOrMatrix = (this.script.charAt (this.ichToken) == '[');
 var bs = this.lookingAtBitset ();
 if (bs != null) {
-this.addTokenToPrefix (JS.T.o (10, isBondOrMatrix ?  new JM.BondSet (bs) : bs));
+this.addTokenToPrefix (JS.T.o (10, isBondOrMatrix ? JM.BondSet.newBS (bs, null) : bs));
 return 2;
 }if (isBondOrMatrix) {
 var m = this.lookingAtMatrix ();
@@ -859,6 +859,7 @@ this.setEqualPt = this.ichToken;
 return 0;
 }return 2;
 case 1150985:
+if (this.tokCommand == 135174 || this.tokCommand == 4103 && this.nTokens == 1) return 0;
 case 364548:
 if (this.flowContext != null) this.flowContext.forceEndIf = false;
 case 364547:
@@ -940,7 +941,7 @@ this.addTokenToPrefix (JS.T.tokenRightParen);
 this.needRightParen = false;
 }break;
 case 269484096:
-if (this.ichToken > 0 && Character.isWhitespace (this.script.charAt (this.ichToken - 1))) this.addTokenToPrefix (JS.T.tokenSpaceBeforeSquare);
+if (this.ichToken > 0 && JU.PT.isWhitespace (this.script.charAt (this.ichToken - 1))) this.addTokenToPrefix (JS.T.tokenSpaceBeforeSquare);
 this.bracketCount++;
 break;
 case 269484097:
@@ -1155,7 +1156,7 @@ this.newContextVariable (this.ident);
 break;
 } else if (this.ident.equals (",")) {
 return 2;
-} else if (!Character.isLetter (this.ident.charAt (0))) {
+} else if (!JU.PT.isLetter (this.ident.charAt (0))) {
 if (this.nTokens != 2) return this.ERROR (0);
 this.replaceCommand (JS.T.tokenSet);
 } else {
@@ -1180,7 +1181,7 @@ this.replaceCommand (JS.T.tokenSet);
 this.addTokenToPrefix (this.lastToken);
 break;
 }}break;
-case 135271426:
+case 135271427:
 if (this.theTok == 1060866 && (this.nTokens == 1 || this.lastToken.tok == 1073741940 || this.lastToken.tok == 1073742152)) {
 this.addTokenToPrefix (JS.T.tokenDefineString);
 return 2;
@@ -1231,7 +1232,7 @@ return 0;
 });
 c$.newScriptParallelProcessor = Clazz.defineMethod (c$, "newScriptParallelProcessor", 
  function (name, tok) {
-var jpp = J.api.Interface.getInterface ("JS.ScriptParallelProcessor");
+var jpp = J.api.Interface.getInterface ("JS.ScriptParallelProcessor", null, null);
 jpp.set (name, tok);
 return jpp;
 }, "~S,~N");
@@ -1249,7 +1250,7 @@ Clazz.defineMethod (c$, "checkUnquotedFileName",
  function () {
 var ichT = this.ichToken;
 var ch;
-while (++ichT < this.cchScript && !Character.isWhitespace (ch = this.script.charAt (ichT)) && ch != '#' && ch != ';' && ch != '}') {
+while (++ichT < this.cchScript && !JU.PT.isWhitespace (ch = this.script.charAt (ichT)) && ch != '#' && ch != ';' && ch != '}') {
 }
 var name = this.script.substring (this.ichToken, ichT).$replace ('\\', '/');
 this.cchToken = ichT - this.ichToken;
@@ -1594,7 +1595,7 @@ Clazz.defineMethod (c$, "lookingAtLoadFormat",
  function (allchar) {
 var ichT = this.ichToken;
 var ch;
-while ((Character.isLetterOrDigit (ch = this.charAt (ichT)) && (allchar || Character.isLetter (ch)) || allchar && (!this.eol (ch) && !Character.isWhitespace (ch)))) ++ichT;
+while ((JU.PT.isLetterOrDigit (ch = this.charAt (ichT)) && (allchar || JU.PT.isLetter (ch)) || allchar && (!this.eol (ch) && !JU.PT.isWhitespace (ch)))) ++ichT;
 
 if (!allchar && ichT == this.ichToken || !JS.ScriptCompiler.isSpaceOrTab (ch)) return false;
 this.cchToken = ichT - this.ichToken;
@@ -1635,7 +1636,7 @@ if (parenpt < 0 && (this.braceCount > 0 || this.iBrace > 0)) {
 isOK = false;
 continue;
 }default:
-if (Character.isWhitespace (ch)) {
+if (JU.PT.isWhitespace (ch)) {
 if (ptSpace < 0) ptSpace = ichT;
 } else {
 ptLastChar = ichT;
@@ -1657,12 +1658,12 @@ var pt0 = ichT;
 if (this.script.charAt (ichT) == '-') ++ichT;
 var isOK = false;
 var ch = 'X';
-while (Character.isDigit (ch = this.charAt (ichT))) {
+while (JU.PT.isDigit (ch = this.charAt (ichT))) {
 ++ichT;
 isOK = true;
 }
 if (ichT < this.cchScript && ch == '.') ++ichT;
-while (Character.isDigit (ch = this.charAt (ichT))) {
+while (JU.PT.isDigit (ch = this.charAt (ichT))) {
 ++ichT;
 isOK = true;
 }
@@ -1671,7 +1672,7 @@ isOK = (ch != 'E' && ch != 'e');
 if (isOK || ++ichT == this.cchScript) return NaN;
 ch = this.script.charAt (ichT);
 if (ch == '-' || ch == '+') ichT++;
-while (Character.isDigit (this.charAt (ichT))) {
+while (JU.PT.isDigit (this.charAt (ichT))) {
 ichT++;
 isOK = true;
 }
@@ -1686,14 +1687,14 @@ var ichT = this.ichToken;
 if (this.script.charAt (ichT) == '-') ++ichT;
 var digitSeen = false;
 var ch;
-while (Character.isDigit (ch = this.charAt (ichT++))) digitSeen = true;
+while (JU.PT.isDigit (ch = this.charAt (ichT++))) digitSeen = true;
 
 if (ch != '.') return false;
 var ch1;
 if (!this.eol (ch1 = this.charAt (ichT))) {
-if (Character.isLetter (ch1) || ch1 == '?' || ch1 == '*') return false;
-if (Character.isLetter (ch1 = this.charAt (ichT + 1)) || ch1 == '?') return false;
-}while (Character.isDigit (this.charAt (ichT))) {
+if (JU.PT.isLetter (ch1) || ch1 == '?' || ch1 == '*') return false;
+if (JU.PT.isLetter (ch1 = this.charAt (ichT + 1)) || ch1 == '?') return false;
+}while (JU.PT.isDigit (this.charAt (ichT))) {
 ++ichT;
 digitSeen = true;
 }
@@ -1709,13 +1710,13 @@ ch = '^';
 ++ichT;
 } else {
 if (this.script.charAt (ichT) == '-') ++ichT;
-while (Character.isDigit (ch = this.charAt (ichT))) ++ichT;
+while (JU.PT.isDigit (ch = this.charAt (ichT))) ++ichT;
 
 }if (ch != '^') return false;
 ichT++;
 if (ichT == this.cchScript) ch = ' ';
  else ch = this.script.charAt (ichT++);
-if (ch != ' ' && ch != '*' && ch != '?' && !Character.isLetter (ch)) return false;
+if (ch != ' ' && ch != '*' && ch != '?' && !JU.PT.isLetter (ch)) return false;
 this.cchToken = ichT - this.ichToken;
 return true;
 });
@@ -1725,7 +1726,7 @@ if (this.ichToken == this.cchScript) return 2147483647;
 var ichT = this.ichToken;
 if (this.script.charAt (this.ichToken) == '-') ++ichT;
 var ichBeginDigits = ichT;
-while (Character.isDigit (this.charAt (ichT))) ++ichT;
+while (JU.PT.isDigit (this.charAt (ichT))) ++ichT;
 
 if (ichBeginDigits == ichT) return 2147483647;
 this.cchToken = ichT - this.ichToken;
@@ -1759,10 +1760,10 @@ if (this.charAt (ichT) != '$') return false;
 if (this.charAt (++ichT) == '"') return false;
 while (ichT < this.cchScript) {
 var ch;
-if (Character.isWhitespace (ch = this.script.charAt (ichT))) {
+if (JU.PT.isWhitespace (ch = this.script.charAt (ichT))) {
 if (ichT == this.ichToken + 1) return false;
 break;
-}if (!Character.isLetterOrDigit (ch)) {
+}if (!JU.PT.isLetterOrDigit (ch)) {
 switch (ch) {
 default:
 return false;
@@ -1836,13 +1837,13 @@ if ((ch = this.charAt (ichT)) == '<' || ch == '=' || ch == '>') ++ichT;
 this.tokLastMath = 1;
 break;
 default:
-if (!Character.isLetter (ch) && !this.isDotDot) return false;
+if (!JU.PT.isLetter (ch) && !this.isDotDot) return false;
 case '~':
 case '_':
 case '\'':
 case '?':
 if (ch == '?') this.tokLastMath = 1;
-while (Character.isLetterOrDigit (ch = this.charAt (ichT)) || ch == '_' || ch == '*' && this.charAt (ichT - 1) == '?' || ch == '?' || ch == '~' || ch == '\'' || ch == '\\' && this.charAt (ichT + 1) == '?' || ch == '^' && ichT > ichT0 && Character.isDigit (this.charAt (ichT - 1))) ++ichT;
+while (JU.PT.isLetterOrDigit (ch = this.charAt (ichT)) || ch == '_' || ch == '*' && this.charAt (ichT - 1) == '?' || ch == '?' || ch == '~' || ch == '\'' || ch == '\\' && this.charAt (ichT + 1) == '?' || ch == '^' && ichT > ichT0 && JU.PT.isDigit (this.charAt (ichT - 1))) ++ichT;
 
 break;
 }
