@@ -1,4 +1,4 @@
-(function(I,J,K,u,L,k,C,m,n,p,M,t,N,v,D,r,E,z,x,A,q,y,F,G,w,O,P,Q,R,S,T,H,U,V,W,X,Y,Z,$,aa,ba,ca,da,ea,fa,ga,ha,ia,ja,ka,la,ma,na,oa,pa,d,g){k("JSV.export");m(["JSV.api.ExportInterface"],"JSV.export.Exporter","JU.Base64 $.PT JSV.common.Annotation $.ExportType $.JSVFileManager $.JSViewer".split(" "),function(){c$=z(JSV["export"],"Exporter",null,JSV.api.ExportInterface);t(c$,function(){});g(c$,"write",function(a,b,c){if(null==b)return this.printPDF(a,null,!1);var e=null,f=null,d,j,s=a.selectedPanel;
+(function(I,K,L,u,M,k,C,m,n,p,N,O,t,P,v,D,r,E,z,x,A,q,y,F,G,w,Q,R,S,T,U,V,H,W,X,Y,Z,$,aa,ba,ca,da,ea,fa,ga,ha,ia,ja,ka,la,ma,na,oa,pa,qa,ra,d,g){k("JSV.export");m(["JSV.api.ExportInterface"],"JSV.export.Exporter","JU.Base64 $.PT JSV.common.Annotation $.ExportType $.JSVFileManager $.JSViewer".split(" "),function(){c$=z(JSV["export"],"Exporter",null,JSV.api.ExportInterface);t(c$,function(){});g(c$,"write",function(a,b,c){if(null==b)return this.printPDF(a,null,!1);var e=null,f=null,d,j,s=a.selectedPanel;
 try{switch(b.size()){default:return"WRITE what?";case 1:f=JU.PT.trimQuotes(b.get(0));f.indexOf(".");if(null==s)return null;d=JSV.common.ExportType.getType(f);switch(d){case JSV.common.ExportType.PDF:case JSV.common.ExportType.PNG:case JSV.common.ExportType.JPG:return this.exportTheSpectrum(a,d,null,null,-1,-1,null,!1);default:a.fileHelper.setFileChooser(d);var h=this.getExportableItems(a,d.equals(JSV.common.ExportType.SOURCE)),g=null==h?-1:a.getOptionFromDialog(h,"Export","Choose a spectrum to export");
 if(-2147483648==g)return null;var B=a.fileHelper.getFile(this.getSuggestedFileName(a,d),s,!0);if(null==B)return null;j=a.getOutputChannel(B.getFullPath(),!1);var k=this.exportSpectrumOrImage(a,d,g,j);k.startsWith("OK")&&a.si.siUpdateRecentMenus(B.getFullPath());return k}case 2:e=b.get(0).toUpperCase(),f=JU.PT.trimQuotes(b.get(1))}var m=f.substring(f.lastIndexOf(".")+1).toUpperCase();m.equals("BASE64")?f=";base64,":m.equals("JDX")?null==e&&(e="XY"):JSV.common.ExportType.isExportMode(m)?e=m:JSV.common.ExportType.isExportMode(e)&&
 (f+="."+e);d=JSV.common.ExportType.getType(e);c&&d===JSV.common.ExportType.SVG&&(d=JSV.common.ExportType.SVGI);j=a.getOutputChannel(f,!1);return this.exportSpectrumOrImage(a,d,-1,j)}catch(n){if(v(n,Exception))return System.out.println(n),null;throw n;}},"JSV.common.JSViewer,JU.Lst,~B");d(c$,"exportSpectrumOrImage",function(a,b,c,e){var f,d=a.pd();if(0>c&&0>(c=d.getCurrentSpectrumIndex()))return"Error exporting spectrum: No spectrum selected";f=d.getSpectrumAt(c);var j=d.getStartingPointIndex(c);c=
@@ -10,17 +10,17 @@ b=g.getFile(b,j,!0);if(null==b)return null;a.isJS||a.setProperty("directoryLastE
 "JSV.common.JSViewer,~S,~B");d(c$,"getExportableItems",function(a,b){var c=a.pd(),e=a.currentSource.isView,f=c.getNumberOfSpectraInCurrentSet();if(1==f||!e&&b||0<=c.getCurrentSpectrumIndex())return null;for(var e=Array(f),d=0;d<f;d++)e[d]=c.getSpectrumAt(d).getTitle();return e},"JSV.common.JSViewer,~B");d(c$,"getSuggestedFileName",function(a,b){var c=a.pd(),e=c.getSpectrum().getFilePath(),e=JSV.common.JSVFileManager.getTagName(e);e.startsWith("$")&&(e=e.substring(1));var f=e.lastIndexOf("."),e=0>
 f?e:e.substring(0,f),f=".jdx",d=!1;switch(b){case JSV.common.ExportType.XY:case JSV.common.ExportType.FIX:case JSV.common.ExportType.PAC:case JSV.common.ExportType.SQZ:case JSV.common.ExportType.DIF:case JSV.common.ExportType.DIFDUP:case JSV.common.ExportType.SOURCE:e.endsWith("_"+b)||(e+="_"+b);f=".jdx";break;case JSV.common.ExportType.AML:f=".xml";break;case JSV.common.ExportType.JPG:case JSV.common.ExportType.PNG:case JSV.common.ExportType.PDF:d=!0;default:f="."+b.toString().toLowerCase()}a.currentSource.isView&&
 (e=c.getPrintJobTitle(d));return e+f},"JSV.common.JSViewer,JSV.common.ExportType");c$.fileCopy=d(c$,"fileCopy",function(a,b){try{for(var c=JSV.common.JSVFileManager.getBufferedReaderFromName(a,null),e=null;null!=(e=c.readLine());)b.append(e),b.append(JSV["export"].Exporter.newLine);b.closeChannel();return"OK "+b.getByteCount()+" bytes"}catch(f){if(v(f,Exception))return f.toString();throw f;}},"~S,JU.OC");c$.newLine=c$.prototype.newLine=System.getProperty("line.separator")});k("JSV.api");m(["JSV.api.JSVExporter"],
-"JSV.api.ExportInterface",null,function(){y(JSV.api,"ExportInterface",JSV.api.JSVExporter)});k("JSV.api");y(JSV.api,"JSVExporter");k("JSV.api");y(JSV.api,"JSVPdfWriter");k("JSV.common");m(["JSV.api.JSVGraphics","$.JSVPdfWriter"],"JSV.common.PDFWriter",["java.util.Hashtable","javajs.export.PDFCreator","JU.CU","JSV.common.JSVersion"],function(){c$=p(function(){this.pdf=this.date=this.g2d=null;this.inPath=!1;this.rgb=null;n(this,arguments)},JSV.common,"PDFWriter",null,[JSV.api.JSVGraphics,JSV.api.JSVPdfWriter]);
-x(c$,function(){this.rgb=E(3,0)});t(c$,function(){this.pdf=new javajs["export"].PDFCreator});g(c$,"createPdfDocument",function(a,b,c){var e=b.layout.equals("landscape");this.date=b.date;this.pdf.setOutputStream(c);this.g2d=a.getPanelData().g2d;try{this.pdf.newDocument(b.paperWidth,b.paperHeight,e);var f=new java.util.Hashtable;f.put("Producer",JSV.common.JSVersion.VERSION);f.put("Creator","JSpecView "+JSV.common.JSVersion.VERSION);f.put("Author","JSpecView");null!=this.date&&f.put("CreationDate",
-this.date);this.pdf.addInfo(f);a.getPanelData().printPdf(this,b);this.pdf.closeDocument()}catch(d){if(v(d,Exception))a.showMessage(d.toString(),"PDF Creation Error");else throw d;}},"JSV.api.JSVPanel,JSV.common.PrintLayout,java.io.OutputStream");g(c$,"canDoLineTo",function(){return!0});g(c$,"doStroke",function(a,b){(this.inPath=b)||this.pdf.stroke()},"~O,~B");g(c$,"drawCircle",function(a,b,c,e){this.pdf.doCircle(b,c,u(e/2),!1)},"~O,~N,~N,~N");g(c$,"drawLine",function(a,b,c,e,f){this.pdf.moveto(b,
-c);this.pdf.lineto(e,f);this.inPath||this.pdf.stroke()},"~O,~N,~N,~N,~N");g(c$,"drawPolygon",function(a,b,c,e){this.pdf.doPolygon(b,c,e,!1)},"~O,~A,~A,~N");g(c$,"drawRect",function(a,b,c,e,f){this.pdf.doRect(b,c,e,f,!1)},"~O,~N,~N,~N,~N");g(c$,"drawString",function(a,b,c,e){this.pdf.drawStringRotated(b,c,e,0)},"~O,~S,~N,~N");g(c$,"drawStringRotated",function(a,b,c,e,f){this.pdf.drawStringRotated(b,c,e,u(f))},"~O,~S,~N,~N,~N");g(c$,"fillBackground",function(){},"~O,javajs.api.GenericColor");g(c$,"fillCircle",
-function(a,b,c,e){this.pdf.doCircle(b,c,u(e/2),!0)},"~O,~N,~N,~N");g(c$,"fillPolygon",function(a,b,c,e){this.pdf.doPolygon(c,b,e,!0)},"~O,~A,~A,~N");g(c$,"fillRect",function(a,b,c,e,f){this.pdf.doRect(b,c,e,f,!0)},"~O,~N,~N,~N,~N");g(c$,"lineTo",function(a,b,c){this.pdf.lineto(b,c)},"~O,~N,~N");g(c$,"setGraphicsColor",function(a,b){JU.CU.toRGB3f(b.getRGB(),this.rgb);this.pdf.setColor(this.rgb,!0);this.pdf.setColor(this.rgb,!1)},"~O,javajs.api.GenericColor");g(c$,"setFont",function(a,b){var c="/Helvetica";
-switch(b.idFontStyle){case 1:c+="-Bold";break;case 3:c+="-BoldOblique";break;case 2:c+="-Oblique"}this.pdf.setFont(c,b.fontSizeNominal);return b},"~O,javajs.awt.Font");g(c$,"setStrokeBold",function(a,b){this.pdf.setLineWidth(b?2:1)},"~O,~B");g(c$,"translateScale",function(a,b,c,e){this.pdf.translateScale(b,c,e)},"~O,~N,~N,~N");g(c$,"newGrayScaleImage",function(a,b,c,e,f){this.pdf.addImageResource(b,c,e,f,!1);return b},"~O,~O,~N,~N,~A");g(c$,"drawGrayScaleImage",function(a,b,c,e,f,d,j,g,h,k){this.pdf.drawImage(b,
-c,e,f,d,j,g,h,k)},"~O,~O,~N,~N,~N,~N,~N,~N,~N,~N");g(c$,"setWindowParameters",function(){},"~N,~N");d(c$,"getColor1",function(a){return this.g2d.getColor1(a)},"~N");d(c$,"getColor3",function(a,b,c){return this.g2d.getColor3(a,b,c)},"~N,~N,~N");d(c$,"getColor4",function(a,b,c,e){return this.g2d.getColor4(a,b,c,e)},"~N,~N,~N,~N")});k("javajs.export");m(null,"javajs.export.PDFCreator",["java.lang.Double","java.util.Hashtable","javajs.export.PDFObject","JU.Lst","$.SB"],function(){c$=p(function(){this.graphics=
-this.root=this.indirectObjects=this.os=null;this.width=this.height=this.count=this.xrefPt=this.pt=0;this.images=this.fonts=null;n(this,arguments)},javajs["export"],"PDFCreator");t(c$,function(){});d(c$,"setOutputStream",function(a){this.os=a},"java.io.OutputStream");d(c$,"newDocument",function(a,b,c){this.width=c?b:a;this.height=c?a:b;System.out.println("Creating PDF with width="+this.width+" and height="+this.height);this.fonts=new java.util.Hashtable;this.indirectObjects=new JU.Lst;this.root=this.newObject("Catalog");
-var e=this.newObject("Pages"),f=this.newObject("Page"),d=this.newObject(null);this.graphics=this.newObject("XObject");this.root.addDef("Pages",e.getRef());e.addDef("Count","1");e.addDef("Kids","[ "+f.getRef()+" ]");f.addDef("Parent",e.getRef());f.addDef("MediaBox","[ 0 0 "+a+" "+b+" ]");c&&f.addDef("Rotate","90");d.addDef("Length","?");d.append((c?"q 0 1 1 0 0 0 ":"q 1 0 0 -1 0 "+b)+" cm /"+this.graphics.getID()+" Do Q");f.addDef("Contents",d.getRef());this.addProcSet(f);this.addProcSet(this.graphics);
-this.graphics.addDef("Subtype","/Form");this.graphics.addDef("FormType","1");this.graphics.addDef("BBox","[0 0 "+this.width+" "+this.height+"]");this.graphics.addDef("Matrix","[1 0 0 1 0 0]");this.graphics.addDef("Length","?");f.addResource("XObject",this.graphics.getID(),this.graphics.getRef());this.g("q 1 w 1 J 1 j 10 M []0 d q ");this.clip(0,0,this.width,this.height)},"~N,~N,~B");d(c$,"addProcSet",function(a){a.addResource(null,"ProcSet","[/PDF /Text /ImageB /ImageC /ImageI]")},"javajs.export.PDFObject");
-d(c$,"clip",function(a,b,c,e){this.moveto(a,b);this.lineto(c,b);this.lineto(c,e);this.lineto(a,e);this.g("h W n")},"~N,~N,~N,~N");d(c$,"moveto",function(a,b){this.g(a+" "+b+" m")},"~N,~N");d(c$,"lineto",function(a,b){this.g(a+" "+b+" l")},"~N,~N");d(c$,"newObject",function(a){var b=new javajs["export"].PDFObject(++this.count);null!=a&&b.addDef("Type","/"+a);this.indirectObjects.addLast(b);return b},"~S");d(c$,"addInfo",function(a){var b=new java.util.Hashtable,c;for(a=a.entrySet().iterator();a.hasNext()&&
+"JSV.api.ExportInterface",null,function(){y(JSV.api,"ExportInterface",JSV.api.JSVExporter)});k("JSV.api");y(JSV.api,"JSVExporter");k("JSV.api");y(JSV.api,"JSVPdfWriter");k("JSV.common");m(["JSV.api.JSVPdfWriter","J.api.GenericGraphics"],"JSV.common.PDFWriter",["java.util.Hashtable","javajs.export.PDFCreator","JU.CU","JSV.common.JSVersion"],function(){c$=p(function(){this.pdf=this.date=this.g2d=null;this.inPath=!1;this.rgb=null;n(this,arguments)},JSV.common,"PDFWriter",null,[J.api.GenericGraphics,
+JSV.api.JSVPdfWriter]);x(c$,function(){this.rgb=E(3,0)});t(c$,function(){this.pdf=new javajs["export"].PDFCreator});g(c$,"createPdfDocument",function(a,b,c){var e=b.layout.equals("landscape");this.date=b.date;this.pdf.setOutputStream(c);this.g2d=a.getPanelData().g2d;try{this.pdf.newDocument(b.paperWidth,b.paperHeight,e);var f=new java.util.Hashtable;f.put("Producer",JSV.common.JSVersion.VERSION);f.put("Creator","JSpecView "+JSV.common.JSVersion.VERSION);f.put("Author","JSpecView");null!=this.date&&
+f.put("CreationDate",this.date);this.pdf.addInfo(f);a.getPanelData().printPdf(this,b);this.pdf.closeDocument()}catch(d){if(v(d,Exception))a.showMessage(d.toString(),"PDF Creation Error");else throw d;}},"JSV.api.JSVPanel,JSV.common.PrintLayout,java.io.OutputStream");g(c$,"canDoLineTo",function(){return!0});g(c$,"doStroke",function(a,b){(this.inPath=b)||this.pdf.stroke()},"~O,~B");g(c$,"drawCircle",function(a,b,c,e){this.pdf.doCircle(b,c,u(e/2),!1)},"~O,~N,~N,~N");g(c$,"drawLine",function(a,b,c,e,
+f){this.pdf.moveto(b,c);this.pdf.lineto(e,f);this.inPath||this.pdf.stroke()},"~O,~N,~N,~N,~N");g(c$,"drawPolygon",function(a,b,c,e){this.pdf.doPolygon(b,c,e,!1)},"~O,~A,~A,~N");g(c$,"drawRect",function(a,b,c,e,f){this.pdf.doRect(b,c,e,f,!1)},"~O,~N,~N,~N,~N");g(c$,"drawString",function(a,b,c,e){this.pdf.drawStringRotated(b,c,e,0)},"~O,~S,~N,~N");g(c$,"drawStringRotated",function(a,b,c,e,f){this.pdf.drawStringRotated(b,c,e,u(f))},"~O,~S,~N,~N,~N");g(c$,"fillBackground",function(){},"~O,javajs.api.GenericColor");
+g(c$,"fillCircle",function(a,b,c,e){this.pdf.doCircle(b,c,u(e/2),!0)},"~O,~N,~N,~N");g(c$,"fillPolygon",function(a,b,c,e){this.pdf.doPolygon(c,b,e,!0)},"~O,~A,~A,~N");g(c$,"fillRect",function(a,b,c,e,f){this.pdf.doRect(b,c,e,f,!0)},"~O,~N,~N,~N,~N");g(c$,"lineTo",function(a,b,c){this.pdf.lineto(b,c)},"~O,~N,~N");g(c$,"setGraphicsColor",function(a,b){JU.CU.toRGB3f(b.getRGB(),this.rgb);this.pdf.setColor(this.rgb,!0);this.pdf.setColor(this.rgb,!1)},"~O,javajs.api.GenericColor");g(c$,"setFont",function(a,
+b){var c="/Helvetica";switch(b.idFontStyle){case 1:c+="-Bold";break;case 3:c+="-BoldOblique";break;case 2:c+="-Oblique"}this.pdf.setFont(c,b.fontSizeNominal);return b},"~O,javajs.awt.Font");g(c$,"setStrokeBold",function(a,b){this.pdf.setLineWidth(b?2:1)},"~O,~B");g(c$,"translateScale",function(a,b,c,e){this.pdf.translateScale(b,c,e)},"~O,~N,~N,~N");g(c$,"newGrayScaleImage",function(a,b,c,e,f){this.pdf.addImageResource(b,c,e,f,!1);return b},"~O,~O,~N,~N,~A");g(c$,"drawGrayScaleImage",function(a,b,
+c,e,f,d,j,g,h,k){this.pdf.drawImage(b,c,e,f,d,j,g,h,k)},"~O,~O,~N,~N,~N,~N,~N,~N,~N,~N");g(c$,"setWindowParameters",function(){},"~N,~N");d(c$,"getColor1",function(a){return this.g2d.getColor1(a)},"~N");d(c$,"getColor3",function(a,b,c){return this.g2d.getColor3(a,b,c)},"~N,~N,~N");d(c$,"getColor4",function(a,b,c,e){return this.g2d.getColor4(a,b,c,e)},"~N,~N,~N,~N")});k("javajs.export");m(null,"javajs.export.PDFCreator",["java.lang.Double","java.util.Hashtable","javajs.export.PDFObject","JU.Lst","$.SB"],
+function(){c$=p(function(){this.graphics=this.root=this.indirectObjects=this.os=null;this.width=this.height=this.count=this.xrefPt=this.pt=0;this.images=this.fonts=null;n(this,arguments)},javajs["export"],"PDFCreator");t(c$,function(){});d(c$,"setOutputStream",function(a){this.os=a},"java.io.OutputStream");d(c$,"newDocument",function(a,b,c){this.width=c?b:a;this.height=c?a:b;System.out.println("Creating PDF with width="+this.width+" and height="+this.height);this.fonts=new java.util.Hashtable;this.indirectObjects=
+new JU.Lst;this.root=this.newObject("Catalog");var e=this.newObject("Pages"),f=this.newObject("Page"),d=this.newObject(null);this.graphics=this.newObject("XObject");this.root.addDef("Pages",e.getRef());e.addDef("Count","1");e.addDef("Kids","[ "+f.getRef()+" ]");f.addDef("Parent",e.getRef());f.addDef("MediaBox","[ 0 0 "+a+" "+b+" ]");c&&f.addDef("Rotate","90");d.addDef("Length","?");d.append((c?"q 0 1 1 0 0 0 ":"q 1 0 0 -1 0 "+b)+" cm /"+this.graphics.getID()+" Do Q");f.addDef("Contents",d.getRef());
+this.addProcSet(f);this.addProcSet(this.graphics);this.graphics.addDef("Subtype","/Form");this.graphics.addDef("FormType","1");this.graphics.addDef("BBox","[0 0 "+this.width+" "+this.height+"]");this.graphics.addDef("Matrix","[1 0 0 1 0 0]");this.graphics.addDef("Length","?");f.addResource("XObject",this.graphics.getID(),this.graphics.getRef());this.g("q 1 w 1 J 1 j 10 M []0 d q ");this.clip(0,0,this.width,this.height)},"~N,~N,~B");d(c$,"addProcSet",function(a){a.addResource(null,"ProcSet","[/PDF /Text /ImageB /ImageC /ImageI]")},
+"javajs.export.PDFObject");d(c$,"clip",function(a,b,c,e){this.moveto(a,b);this.lineto(c,b);this.lineto(c,e);this.lineto(a,e);this.g("h W n")},"~N,~N,~N,~N");d(c$,"moveto",function(a,b){this.g(a+" "+b+" m")},"~N,~N");d(c$,"lineto",function(a,b){this.g(a+" "+b+" l")},"~N,~N");d(c$,"newObject",function(a){var b=new javajs["export"].PDFObject(++this.count);null!=a&&b.addDef("Type","/"+a);this.indirectObjects.addLast(b);return b},"~S");d(c$,"addInfo",function(a){var b=new java.util.Hashtable,c;for(a=a.entrySet().iterator();a.hasNext()&&
 ((c=a.next())||1);){var e="("+c.getValue().$replace(")","_").$replace("(","_")+")";b.put(c.getKey(),e)}this.root.addDef("Info",b)},"java.util.Map");d(c$,"addFontResource",function(a){var b=this.newObject("Font");this.fonts.put(a,b);b.addDef("BaseFont",a);b.addDef("Encoding","/WinAnsiEncoding");b.addDef("Subtype","/Type1");this.graphics.addResource("Font",b.getID(),b.getRef());return b},"~S");d(c$,"addImageResource",function(a,b,c,e,d){var l=this.newObject("XObject");null==this.images&&(this.images=
 new java.util.Hashtable);this.images.put(a,l);l.addDef("Subtype","/Image");l.addDef("Length","?");l.addDef("ColorSpace",d?"/DeviceRGB":"/DeviceGray");l.addDef("BitsPerComponent","8");l.addDef("Width",""+b);l.addDef("Height",""+c);this.graphics.addResource("XObject",l.getID(),l.getRef());a=e.length;b=q(a*(d?3:1),0);if(d)for(c=d=0;d<a;d++)b[c++]=e[d]>>16&255,b[c++]=e[d]>>8&255,b[c++]=e[d]&255;else for(d=0;d<a;d++)b[d]=e[d];l.setStream(b);this.graphics.addResource("XObject",l.getID(),l.getRef())},"~O,~N,~N,~A,~B");
 d(c$,"g",function(a){this.graphics.append(a).appendC("\n")},"~S");d(c$,"output",function(a){a=a.getBytes();this.os.write(a,0,a.length);this.pt+=a.length},"~S");d(c$,"closeDocument",function(){this.g("Q Q");this.outputHeader();this.writeObjects();this.writeXRefTable();this.writeTrailer();this.os.flush();this.os.close()});d(c$,"outputHeader",function(){this.output("%PDF-1.3\n%");var a=[-1,-1,-1,-1];this.os.write(a,0,a.length);this.pt+=4;this.output("\n")});d(c$,"writeTrailer",function(){var a=new javajs["export"].PDFObject(-2);
@@ -116,5 +116,5 @@ b,c,d,f){this.static_tree=a;this.extra_bits=b;this.extra_base=c;this.elems=d;thi
 157,8,93,8,221,8,61,8,189,8,125,8,253,8,19,9,275,9,147,9,403,9,83,9,339,9,211,9,467,9,51,9,307,9,179,9,435,9,115,9,371,9,243,9,499,9,11,9,267,9,139,9,395,9,75,9,331,9,203,9,459,9,43,9,299,9,171,9,427,9,107,9,363,9,235,9,491,9,27,9,283,9,155,9,411,9,91,9,347,9,219,9,475,9,59,9,315,9,187,9,443,9,123,9,379,9,251,9,507,9,7,9,263,9,135,9,391,9,71,9,327,9,199,9,455,9,39,9,295,9,167,9,423,9,103,9,359,9,231,9,487,9,23,9,279,9,151,9,407,9,87,9,343,9,215,9,471,9,55,9,311,9,183,9,439,9,119,9,375,9,247,9,503,
 9,15,9,271,9,143,9,399,9,79,9,335,9,207,9,463,9,47,9,303,9,175,9,431,9,111,9,367,9,239,9,495,9,31,9,287,9,159,9,415,9,95,9,351,9,223,9,479,9,63,9,319,9,191,9,447,9,127,9,383,9,255,9,511,9,0,7,64,7,32,7,96,7,16,7,80,7,48,7,112,7,8,7,72,7,40,7,104,7,24,7,88,7,56,7,120,7,4,7,68,7,36,7,100,7,20,7,84,7,52,7,116,7,3,8,131,8,67,8,195,8,35,8,163,8,99,8,227,8],"static_dtree",[0,5,16,5,8,5,24,5,4,5,20,5,12,5,28,5,2,5,18,5,10,5,26,5,6,5,22,5,14,5,30,5,1,5,17,5,9,5,25,5,5,5,21,5,13,5,29,5,3,5,19,5,11,5,27,5,
 7,5,23,5]);c$.static_l_desc=c$.prototype.static_l_desc=new JU.StaticTree(JU.StaticTree.static_ltree,JU.Tree.extra_lbits,257,286,15);c$.static_d_desc=c$.prototype.static_d_desc=new JU.StaticTree(JU.StaticTree.static_dtree,JU.Tree.extra_dbits,0,30,15);c$.static_bl_desc=c$.prototype.static_bl_desc=new JU.StaticTree(null,JU.Tree.extra_blbits,0,19,7)});k("JU");y(JU,"Checksum")})(Clazz,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,Clazz.load,
-Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.makeConstructor,Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,Clazz.newBooleanArray,
+Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,Clazz.newBooleanArray,
 Clazz.newCharArray,Clazz.implementOf,Clazz.newDoubleArray,Clazz.overrideConstructor,Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,Clazz.getParamsType,Clazz.isAF,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,Clazz.isAII,Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
