@@ -1,4 +1,4 @@
-(function(z,A,B,u,C,d,v,h,j,l,D,k,E,t,F,s,G,p,w,m,H,r,I,K,L,M,N,O,x,P,Q,y,R,S,T,U,V,W,X,Y,Z,$,aa,ba,ca,da,ea,fa,ga,ha,ia,ja,ka,la,ma,b,e){d("javajs.awt");h(["javajs.awt.LayoutManager"],"javajs.awt.BorderLayout",null,function(){c$=p(javajs.awt,"BorderLayout",javajs.awt.LayoutManager);s(c$,"CENTER","Center","NORTH","North","SOUTH","South","EAST","East","WEST","West")});d("javajs.awt");h(null,"javajs.awt.Component",["JU.CU"],function(){c$=l(function(){this.visible=!1;this.enabled=!0;this.name=this.text=
+(function(z,A,B,u,C,d,v,h,j,l,D,E,k,F,t,G,s,H,p,w,m,I,r,K,L,M,N,O,P,x,Q,R,y,S,T,U,V,W,X,Y,Z,$,aa,ba,ca,da,ea,fa,ga,ha,ia,ja,ka,la,ma,na,b,e){d("javajs.awt");h(["javajs.awt.LayoutManager"],"javajs.awt.BorderLayout",null,function(){c$=p(javajs.awt,"BorderLayout",javajs.awt.LayoutManager);s(c$,"CENTER","Center","NORTH","North","SOUTH","South","EAST","East","WEST","West")});d("javajs.awt");h(null,"javajs.awt.Component",["JU.CU"],function(){c$=l(function(){this.visible=!1;this.enabled=!0;this.name=this.text=
 null;this.height=this.width=0;this.bgcolor=this.mouseListener=this.parent=this.id=null;this.minHeight=this.minWidth=30;this.renderHeight=this.renderWidth=0;j(this,arguments)},javajs.awt,"Component");b(c$,"setParent",function(a){this.parent=a},"~O");k(c$,function(a){this.id=javajs.awt.Component.newID(a);null!=a&&SwingController.register(this,a)},"~S");c$.newID=b(c$,"newID",function(a){return a+(""+Math.random()).substring(3,10)},"~S");b(c$,"setBackground",function(a){this.bgcolor=a},"javajs.api.GenericColor");
 b(c$,"setText",function(a){this.text=a;SwingController.setText(this)},"~S");b(c$,"setName",function(a){this.name=a},"~S");b(c$,"getName",function(){return this.name});b(c$,"getParent",function(){return this.parent});b(c$,"setPreferredSize",function(a){this.width=a.width;this.height=a.height},"javajs.awt.Dimension");b(c$,"addMouseListener",function(a){this.mouseListener=a},"~O");b(c$,"getText",function(){return this.text});b(c$,"isEnabled",function(){return this.enabled});b(c$,"setEnabled",function(a){this.enabled=
 a;SwingController.setEnabled(this)},"~B");b(c$,"isVisible",function(){return this.visible});b(c$,"setVisible",function(a){this.visible=a;SwingController.setVisible(this)},"~B");b(c$,"getHeight",function(){return this.height});b(c$,"getWidth",function(){return this.width});b(c$,"setMinimumSize",function(a){this.minWidth=a.width;this.minHeight=a.height},"javajs.awt.Dimension");b(c$,"getSubcomponentWidth",function(){return this.width});b(c$,"getSubcomponentHeight",function(){return this.height});b(c$,
@@ -70,6 +70,6 @@ h=e.substring(f+1).trim(),j=null;if(0<=(f=g.indexOf("|")))j=g.substring(f+1).tri
 a[e][1]?b:b=a[e][1]).appendC("\n")}return d.toString()},"~A")});d("J.popup");h(["J.popup.PopupHelper"],"J.popup.JSSwingPopupHelper","javajs.swing.ButtonGroup $.JCheckBoxMenuItem $.JMenu $.JMenuItem $.JPopupMenu $.JRadioButtonMenuItem".split(" "),function(){c$=l(function(){this.buttonGroup=this.popup=null;j(this,arguments)},J.popup,"JSSwingPopupHelper",null,J.popup.PopupHelper);k(c$,function(a){this.popup=a},"javajs.api.GenericMenuInterface");e(c$,"menuCreatePopup",function(a,b){var d=new javajs.swing.JPopupMenu(a);
 d.setInvoker(b);return d},"~S,~O");e(c$,"getMenu",function(){return new javajs.swing.JMenu},"~S");e(c$,"getMenuItem",function(a){return new javajs.swing.JMenuItem(a)},"~S");e(c$,"getRadio",function(){return new javajs.swing.JRadioButtonMenuItem},"~S");e(c$,"getCheckBox",function(){return new javajs.swing.JCheckBoxMenuItem},"~S");e(c$,"menuAddButtonGroup",function(a){null==a?this.buttonGroup=null:(null==this.buttonGroup&&(this.buttonGroup=new javajs.swing.ButtonGroup),this.buttonGroup.add(a))},"javajs.api.SC");
 e(c$,"getItemType",function(a){return a.btnType},"javajs.api.SC");e(c$,"menuInsertSubMenu",function(a,b){b.setParent(a)},"javajs.api.SC,javajs.api.SC,~N");e(c$,"getSwingComponent",function(a){return a},"~O");e(c$,"menuClearListeners",function(a){null!=a&&a.disposeMenu()},"javajs.api.SC");b(c$,"itemStateChanged",function(a){this.popup.menuCheckBoxCallback(a.getSource())},"javajs.awt.event.ItemEvent");b(c$,"actionPerformed",function(a){this.popup.menuClickCallback(a.getSource(),a.getActionCommand())},
-"javajs.awt.event.ActionEvent");e(c$,"getButtonGroup",function(){return this.buttonGroup})});d("J.popup");r(J.popup,"PopupHelper")})(Clazz,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.makeConstructor,Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,
-Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,Clazz.newDoubleArray,Clazz.overrideConstructor,Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,Clazz.getParamsType,Clazz.isAF,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,Clazz.isAII,
-Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
+"javajs.awt.event.ActionEvent");e(c$,"getButtonGroup",function(){return this.buttonGroup})});d("J.popup");r(J.popup,"PopupHelper")})(Clazz,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,
+Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,Clazz.newDoubleArray,Clazz.overrideConstructor,Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,Clazz.getParamsType,Clazz.isAF,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,
+Clazz.isAII,Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
