@@ -1,5 +1,6 @@
 // JmolApplet.js -- Jmol._Applet and Jmol._Image
 
+// BY 10/19/2014 8:08:51 PM moved applet._cover and applet._displayCoverImage to 
 // BH 5/8/2014 11:20:21 AM trying to fix AH nd JG problem with multiple applets
 // BH 1/27/2014 8:36:43 AM adding Info.viewSet
 // BH 12/13/2013 9:04:53 AM _evaluate DEPRECATED (see JSmolApi.js Jmol.evaulateVar
@@ -218,7 +219,9 @@
 				+ " code='" + params.code + "' codebase='" + applet._jarPath + "' archive='" + jarFile + "' mayscript='true'>\n"
 				+ t + "<table bgcolor='yellow'><tr><td align='center' valign='middle' " + widthAndHeight + ">\n"
 				+ Applet._noJavaMsg + "</td></tr></table></applet>\n";
-		}	
+		}
+		if (applet._deferApplet)
+			applet._javaCode = t, t="";
 		t = Jmol._getWrapper(applet, true) + t + Jmol._getWrapper(applet, false) 
 			+ (Info.addSelectionOptions ? Jmol._getGrabberOptions(applet) : "");
 		if (Jmol._debugAlert)
@@ -226,6 +229,11 @@
 		applet._code = Jmol._documentWrite(t);
 	}
 
+	proto._newApplet = function(viewerOptions) {
+		this._viewerOptions = viewerOptions;
+		return new J.appletjs.Jmol(viewerOptions);
+	}
+	
 	proto._create = function(id, Info){
 		Jmol._setObject(this, id, Info);
 		var params = {
@@ -304,6 +312,8 @@
 		if (this._2dapplet._isEmbedded) {
 			this._showInfo(false);
 			this._show(!tf);
+			// for whatever reason this must be here
+			this._2dapplet.__showContainer(true, true);
 		}
 	}
 
@@ -537,7 +547,7 @@
 	}
 
 	proto._searchDatabase = function(query, database, script, _jmol_searchDatabase){
-		if (this._2dapplet && this._2dapplet._isEmbedded && Jmol.$(this, "2dappletdiv:visible")[0])
+		if (this._2dapplet && this._2dapplet._isEmbedded && !Jmol.$(this, "appletdiv:visible")[0])
 			return this._2dapplet._searchDatabase(query, database, script); 
 		this._showInfo(false);
 		if (query.indexOf("?") >= 0) {
@@ -666,6 +676,38 @@
 		return false;
 	}
 
+	proto._cover = function (doCover) {
+		if (doCover || !this._deferApplet) {
+			this._displayCoverImage(doCover);
+			return;
+		}
+		// uncovering UNMADE applet upon clicking image
+		var s = (this._coverScript ? this._coverScript : "");
+		this._coverScript = "";
+		if (this._deferUncover)
+			s += ";refresh;javascript " + this._id + "._displayCoverImage(false)";
+		this._script(s, true);
+		if (this._deferUncover && this._coverTitle == "activate 3D model")
+			Jmol._getElement(this, "coverimage").title = "3D model is loading...";
+		if (!this._isJava)
+			this._newCanvas(false);
+		if (this._defaultModel)	
+			Jmol._search(this, this._defaultModel);
+		this._showInfo(false);
+		if (!this._deferUncover)
+			this._displayCoverImage(false);
+		if (this._isJava)
+			Jmol.$html(Jmol.$(this, "appletdiv"), this._javaCode);
+		if (this._init)
+			this._init();
+	};
+
+	proto._displayCoverImage = function(TF) {
+		if (!this._coverImage || this._isCovered == TF) return;
+		this._isCovered = TF;
+		Jmol._getElement(this, "coverdiv").style.display = (TF ? "block" : "none");
+	};
+
   proto._getSmiles = function() {
 		return this._evaluate("{visible}.find('SMILES')");   
   }
