@@ -1,7 +1,15 @@
-// JSmolCore.js -- Jmol core capability  7/23/2014 5:34:47 PM
+	// BH 4/25 -- added text option. setAppletCss(null, "style=\"xxxx\"")
+	// note that since you must add the style keyword, this can be used to add any attribute to these tags, not just css. 
+
+// JSmolCore.js -- Jmol core capability 
 
 // see JSmolApi.js for public user-interface. All these are private functions
 
+// BH 12/6/2014 3:32:54 PM Jmol.setAppletCss() broken
+// BH 9/13/2014 2:15:51 PM embedded JSME loads from SEARCH when Jmol should 
+// BH 8/14/2014 2:52:38 PM drag-drop cache should not be cleared if SPT file is dropped
+// BH 8/5/2014 6:39:54 AM unnecessary messages about binary for PDB finally removed
+// BH 8/4/2014 5:30:00 AM automatically switch to no document after page loading
 // BH 8/2/2014 5:22:40 PM drag-drop broken in JSmol/HTML5 
 // BH 7/23/2014 5:34:08 PM setting a parameter such as readyFunction to null stops file loading
 // BH 7/3/2014 12:30:28 AM lost drag-drop of models
@@ -123,7 +131,7 @@ Jmol = (function(document) {
 		}
 	};
 	var j = {
-		_version: 'JSmol 14.2.3 July 23, 2014',
+		_version: "$Date: 2014-12-19 08:17:57 -0600 (Fri, 19 Dec 2014) $", // svn.keywords:lastUpdated
 		_alertNoBinary: true,
 		// this url is used to Google Analytics tracking of Jmol use. You may remove it or modify it if you wish. 
 		_allowedJmolSize: [25, 2048, 300],   // min, max, default (pixels)
@@ -131,6 +139,8 @@ Jmol = (function(document) {
 				before calling Jmol.getApplet(), limits for applet size can be overriden.
 				2048 standard for GeoWall (http://geowall.geo.lsa.umich.edu/home.html)
 		*/
+		_appletCssClass: "",
+		_appletCssText: "",
 		_fileCache: null, // enabled by Jmol.setFileCaching(applet, true/false)
 		_jarFile: null,  // can be set in URL using _JAR=
 		_j2sPath: null,  // can be set in URL using _J2S=
@@ -215,8 +225,11 @@ Jmol = (function(document) {
 	// hooks to jQuery -- if you have a different AJAX tool, feel free to adapt.
 	// There should be no other references to jQuery in all the JSmol libraries.
 
+	// automatically switch to returning HTML after the page is loaded
+	$(document).ready(function(){ Jmol._document = null });
+
 	Jmol.$ = function(objectOrId, subdiv) {
-		// if a subdivv, then return $("#objectOrId_subdiv") 
+		// if a subdiv, then return $("#objectOrId._id_subdiv") 
 		// or if no subdiv, then just $(objectOrId)
 		if (objectOrId == null)alert (subdiv + arguments.callee.caller.toString());
 			return $(subdiv ? "#" + objectOrId._id + "_" + subdiv : objectOrId);
@@ -241,10 +254,7 @@ Jmol = (function(document) {
 	}
 
 	Jmol._getNCIInfo = function(identifier, what, fCallback) {
-		if (what == "name")
-			what = "names"
-		url = "http://cactus.nci.nih.gov/chemical/structure/"+identifier +"/" + what; 
-		return Jmol._getFileData(url);
+		return Jmol._getFileData("http://cactus.nci.nih.gov/chemical/structure/"+identifier +"/" + (what == "name" ? "names" : what));
 	}
 	
 
@@ -812,6 +822,7 @@ Jmol = (function(document) {
 	Jmol._syncBinaryOK="?";
 
 	Jmol._canSyncBinary = function(isSilent) {
+		if (Jmol._isAsync) return true;
 		if (self.VBArray) return (Jmol._syncBinaryOK = false);
 		if (Jmol._syncBinaryOK != "?") return Jmol._syncBinaryOK;
 		Jmol._syncBinaryOK = true;
@@ -833,7 +844,7 @@ Jmol = (function(document) {
 		return true;  
 	}
 
-	Jmol._binaryTypes = [".gz",".jpg",".png",".zip",".jmol",".bin",".smol",".spartan",".mrc",".pse", ".map", ".omap"];
+	Jmol._binaryTypes = [".gz",".jpg",".gif",".png",".zip",".jmol",".bin",".smol",".spartan",".mrc",".pse", ".map", ".omap"];
 
 	Jmol._isBinaryUrl = function(url) {
 		for (var i = Jmol._binaryTypes.length; --i >= 0;)
@@ -841,16 +852,15 @@ Jmol = (function(document) {
 		return false;
 	}
 
-	Jmol._getFileData = function(fileName, fSuccess) {
+	Jmol._getFileData = function(fileName, fSuccess, doProcess) {
 		// use host-server PHP relay if not from this host
-		var type = (Jmol._isBinaryUrl(fileName) ? "binary" : "text");
+		var isBinary = Jmol._isBinaryUrl(fileName);
 		var isPDB = (fileName.indexOf("pdb.gz") >= 0 && fileName.indexOf("http://www.rcsb.org/pdb/files/") == 0);
-		var asBase64 = (type == "binary" && !Jmol._canSyncBinary(isPDB));
+		var asBase64 = (isBinary && !Jmol._canSyncBinary(isPDB));
 		if (asBase64 && isPDB) {
 			// avoid unnecessary binary transfer
 			fileName = fileName.replace(/pdb\.gz/,"pdb");
-			asBase64 = false;
-			type = "text";
+			asBase64 = isBinary = false;
 		}
 		var isPost = (fileName.indexOf("?POST?") >= 0);
 		if (fileName.indexOf("file:/") == 0 && fileName.indexOf("file:///") != 0)
@@ -860,26 +870,37 @@ Jmol = (function(document) {
 		//if (fileName.indexOf("http://pubchem.ncbi.nlm.nih.gov/") == 0)isDirectCall = false;
 
 		var cantDoSynchronousLoad = (!isMyHost && Jmol.$supportsIECrossDomainScripting());
-		if (!fSuccess || asBase64)
-			if (cantDoSynchronousLoad || asBase64 || !isMyHost && !isDirectCall)
-				return Jmol._getRawDataFromServer("_",fileName, fSuccess, fSuccess, asBase64, true);
-		fileName = fileName.replace(/file:\/\/\/\//, "file://"); // opera
-		var info = {dataType:type,async:!!fSuccess};
-		if (isPost) {
-			info.type = "POST";
-			info.url = fileName.split("?POST?")[0]
-			info.data = fileName.split("?POST?")[1]
+		var data = null;
+		if ((!fSuccess || asBase64) && (cantDoSynchronousLoad || asBase64 || !isMyHost && !isDirectCall)) {
+				data = Jmol._getRawDataFromServer("_",fileName, fSuccess, fSuccess, asBase64, true);
 		} else {
-			info.type = "GET";
-			info.url = fileName;
+			fileName = fileName.replace(/file:\/\/\/\//, "file://"); // opera
+			var info = {dataType:(isBinary ? "binary" : "text"),async:!!fSuccess};
+			if (isPost) {
+				info.type = "POST";
+				info.url = fileName.split("?POST?")[0]
+				info.data = fileName.split("?POST?")[1]
+			} else {
+				info.type = "GET";
+				info.url = fileName;
+			}
+			if (fSuccess) {
+				info.success = function(data) { fSuccess(Jmol._xhrReturn(info.xhr))};
+				info.error = function() { xxi = info;fSuccess(info.xhr.statusText)};
+			}
+			info.xhr = Jmol.$ajax(info);
+			if (!fSuccess) {
+				data = Jmol._xhrReturn(info.xhr);
+			}
 		}
-		if (fSuccess) {
-			info.success = function(data) { fSuccess(Jmol._xhrReturn(info.xhr))};
-			info.error = function() { fSuccess(xhr.statusText)};
+		if (!doProcess)
+			return data;
+		if (data == null) {
+			data = "";
+			isBinary = false;
 		}
-		info.xhr = Jmol.$ajax(info);
-		if (!fSuccess) 
-			return Jmol._xhrReturn(info.xhr);			
+		isBinary && (isBinary = Jmol._canSyncBinary(true));
+		return (isBinary ? Jmol._strToBytes(data) : JU.SB.newS(data));
 	}
 	
 	Jmol._xhrReturn = function(xhr){
@@ -930,14 +951,17 @@ Jmol = (function(document) {
 	Jmol._loadFileAsynchronously = function(fileLoadThread, applet, fileName, appData) {
 		if (fileName.indexOf("?") != 0) {
 			// LOAD ASYNC command
+			var fileName0 = fileName;
 			fileName = Jmol._checkFileName(applet, fileName);
-			var fSuccess = function(data) {Jmol._setData(fileLoadThread, fileName, data, appData)};
+			var fSuccess = function(data) {Jmol._setData(fileLoadThread, fileName, fileName0, data, appData)};
 			fSuccess = Jmol._checkCache(applet, fileName, fSuccess);
+			if (fileName.indexOf("|") >= 0)
+				fileName = fileName.split("|")[0];
 			return (fSuccess == null ? null : Jmol._getFileData(fileName, fSuccess));		
 		}
 		// we actually cannot suggest a fileName, I believe.
 		if (!Jmol.featureDetection.hasFileReader)
-				return fileLoadThread.setData("Local file reading is not enabled in your browser", null, appData);
+				return fileLoadThread.setData("Local file reading is not enabled in your browser", null, null, appData);
 		if (!applet._localReader) {
 			var div = '<div id="ID" style="z-index:'+Jmol._getZ(applet, "fileOpener") + ';position:absolute;background:#E0E0E0;left:10px;top:10px"><div style="margin:5px 5px 5px 5px;"><input type="file" id="ID_files" /><button id="ID_loadfile">load</button><button id="ID_cancel">cancel</button></div><div>'
 			Jmol.$after("#" + applet._id + "_appletdiv", div.replace(/ID/g, applet._id + "_localReader"));
@@ -950,7 +974,7 @@ Jmol = (function(document) {
 			reader.onloadend = function(evt) {
 				if (evt.target.readyState == FileReader.DONE) { // DONE == 2
 					Jmol.$css(Jmol.$(applet, "localReader"), {display : "none"});
-					Jmol._setData(fileLoadThread, file.name, evt.target.result, appData);
+					Jmol._setData(fileLoadThread, file.name, file.name, evt.target.result, appData);
 				}
 			};
 			reader.readAsArrayBuffer(file);
@@ -958,16 +982,16 @@ Jmol = (function(document) {
 		Jmol.$appEvent(applet, "localReader_cancel", "click");
 		Jmol.$appEvent(applet, "localReader_cancel", "click", function(evt) {
 			Jmol.$css(Jmol.$(applet, "localReader"), {display: "none"});
-			fileLoadThread.setData(null, appData);
+			fileLoadThread.setData(null, null, null, appData);
 		});
 		Jmol.$css(Jmol.$(applet, "localReader"), {display : "block"});
 	}
 
-  Jmol._setData = function(fileLoadThread, filename, data, appData) {
+  Jmol._setData = function(fileLoadThread, filename, filename0, data, appData) {
   	data = Jmol._strToBytes(data);
 		if (filename.indexOf(".jdx") >= 0)
 			Jmol.Cache.put("cache://" + filename, data);
-		fileLoadThread.setData(filename, data, appData);
+		fileLoadThread.setData(filename, filename0, data, appData);
   }
   
 	Jmol._toBytes = function(data) {
@@ -989,8 +1013,7 @@ Jmol = (function(document) {
 			return Jmol._saveFile(url, dataOut);
 		if (postOut)
 			url += "?POST?" + postOut;
-		var data = Jmol._getFileData(url)
-		return Jmol._processData(data, Jmol._isBinaryUrl(url));
+		return Jmol._getFileData(url, null, true);
 	}
 
 	// Jmol._localFileSaveFunction --  // do something local here; Maybe try the FileSave interface? return true if successful
@@ -999,7 +1022,10 @@ Jmol = (function(document) {
 		if (Jmol._localFileSaveFunction && Jmol._localFileSaveFunction(filename, data))
 			return "OK";
 		var filename = filename.substring(filename.lastIndexOf("/") + 1);
-		mimetype || (mimetype = (filename.indexOf(".pdf") >= 0 ? "application/pdf" : filename.indexOf(".png") >= 0 ? "image/png" : filename.indexOf(".jpg") >= 0 ? "image/jpg" : ""));
+		mimetype || (mimetype = (filename.indexOf(".pdf") >= 0 ? "application/pdf" 
+			: filename.indexOf(".png") >= 0 ? "image/png" 
+			: filename.indexOf(".gif") >= 0 ? "image/gif" 
+			: filename.indexOf(".jpg") >= 0 ? "image/jpg" : ""));
 		var isString = (typeof data == "string");
 		if (!isString)
 			data = (JU ? JU : J.util).Base64.getBase64(data).toString();
@@ -1044,16 +1070,6 @@ Jmol = (function(document) {
 		return "OK";
 	}
 
-	Jmol._processData = function(data, isBinary) {
-		if (typeof data == "undefined") {
-			data = "";
-			isBinary = false;
-		}
-		if (isBinary)
-			isBinary = Jmol._canSyncBinary();
-		return (isBinary ? Jmol._strToBytes(data) : JU.SB.newS(data));
-	};
-
 	Jmol._strToBytes = function(s) {
 		if (Clazz.instanceOf(s, self.ArrayBuffer))
 			return Jmol._toBytes(s);
@@ -1114,9 +1130,11 @@ Jmol = (function(document) {
 				img = "<div id=\"ID_coverdiv\" style=\"background-color:red;z-index:" + Jmol._getZ(applet, "coverImage")+";width:100%;height:100%;display:inline;position:absolute;top:0px;left:0px\"><image id=\"ID_coverimage\" src=\""
 				 + applet._coverImage + "\" style=\"width:100%;height:100%\"" + more + "/>" + play + "</div>";
 			}
+			var css = Jmol._appletCssText.replace(/\'/g,'"');
+			css = (css.indexOf("style=\"") >= 0 ? css.split("style=\"")[1] : "\" " + css);
 			s = "\
 ...<div id=\"ID_appletinfotablediv\" style=\"width:Wpx;height:Hpx;position:relative;font-size:14px;text-align:left\">IMG\
-......<div id=\"ID_appletdiv\" style=\"z-index:" + Jmol._getZ(applet, "header") + ";width:100%;height:100%;position:absolute;top:0px;left:0px;\">";
+......<div id=\"ID_appletdiv\" style=\"z-index:" + Jmol._getZ(applet, "header") + ";width:100%;height:100%;position:absolute;top:0px;left:0px;" + css + ">";
 			var height = applet._height;
 			var width = applet._width;
 			if (typeof height !== "string" || height.indexOf("%") < 0) 
@@ -1264,10 +1282,10 @@ Jmol = (function(document) {
 		obj._noMonitor = Info.disableJ2SLoadMonitor;
 		Jmol._j2sPath && (Info.j2sPath = Jmol._j2sPath);
 		obj._j2sPath = Info.j2sPath;
-		obj._deferApplet = Info.deferApplet;
-		obj._deferUncover = Info.deferUncover;
-		obj._coverImage = !obj._isJava && Info.coverImage;
+		obj._coverImage = Info.coverImage;
 		obj._isCovered = !!obj._coverImage; 
+		obj._deferApplet = Info.deferApplet || obj._isCovered && obj._isJava; // must do this if covered in Java
+		obj._deferUncover = Info.deferUncover && !obj._isJava; // can't do this with Java
 		obj._coverScript = Info.coverScript;
 		obj._coverTitle = Info.coverTitle;
 
@@ -1879,7 +1897,7 @@ Jmol._track = function(applet) {
 	if (Jmol._tracker){
 		try {  
 			var url = Jmol._tracker + "&applet=" + applet._jmolType + "&version=" + Jmol._version 
-				+ "&appver=" + self.___JmolVersion + "&url=" + encodeURIComponent(document.location.href);
+				+ "&appver=" + Jmol.___JmolVersion + "&url=" + encodeURIComponent(document.location.href);
 			var s = '<iframe style="display:none" width="0" height="0" frameborder="0" tabindex="-1" src="' + url + '"></iframe>'
 			Jmol.$after("body", s);
 		} catch (e) {
@@ -2140,7 +2158,8 @@ Jmol.Cache.put = function(filename, data) {
 				if (evt.target.readyState == FileReader.DONE) {
 					var cacheName = "cache://DROP_" + file.name;
 					var bytes = Jmol._toBytes(evt.target.result);
-					me._applet.cacheFileByName("cache://DROP_*",false);
+					if (!cacheName.endsWith(".spt"))
+						me._applet.cacheFileByName("cache://DROP_*",false);
 					if (me._viewType == "JSV" || cacheName.endsWith(".jdx")) // shared by Jmol and JSV
 						Jmol.Cache.put(cacheName, bytes);
 					else
