@@ -3,6 +3,8 @@
 // see http://peter-ertl.com/jsme/JSME_2013-10-13/api_javadoc/index.html
 
 
+// BH 9/13/2014 2:24:29 PM SMILES fix again
+// BH 9/2/2014 6:56:42 PM  SMILES fix for quaternary carbon with stereochemistry
 // BH 3/1/2014 4:31:18 PM fix for evaluate returning atom sets as arrays
 // BH 1/27/2014 8:37:06 AM adding Info.viewSet  
 // BH 12/4/2013 7:44:26 PM fix for JME independent search box
@@ -69,6 +71,7 @@
 		Jmol._setObject(this, id, Info);
 		this._options = Info.options;
 		(this._options.indexOf("autoez") < 0) && (this._options += ",autoez");
+		(this._options.indexOf("canonize") < 0) && (this._options += ",nocanonize");
 		this._setCheck(true);
 		this._editEnabled = true;
 		this._editOptions =  Info.editOptions || "editEnabled;";
@@ -98,6 +101,9 @@
 				var d = Jmol._document;
 				Jmol._document = null;
 				Jmol.$html(this._divId, this.create());
+				if (this._isEmbedded) {
+					Jmol.$("#"+id)[0].style.zIndex = Jmol._z.header - 1;
+					}
 				Jmol._document = d;
 				this.__showContainer(false, false);
 			} else {
@@ -405,10 +411,10 @@
 			if (this._viewSet != null) {
 			  isOK = false;
 			} else if (jme != null) {
-				var jmeSMILES = this._getSmiles();
+				jmeSMILES = this._getSmiles();
 				// testing here to see that we have the same structure as in the JMOL applet
 				// feature change here --- evaluation of an atom set returns an array now, not an uninterpretable string
-				var jmolAtoms = (jmeSMILES ? jmol._evaluate("{*}.find('SMILES', '" + jmeSMILES.replace(/\\/g,"\\\\")+ "')") : []);
+				jmolAtoms = (jmeSMILES ? jmol._evaluate("{*}.find('SMILES', '" + jmeSMILES.replace(/\\/g,"\\\\")+ "')") : []);
 				var isOK = (jmolAtoms.length > 0);
 			}
 			if (!isOK) {
@@ -422,7 +428,7 @@
 			}
 		}
 		if (this._linkedApplet) {
-		 	this.__showContainer(toJME, true);
+		 	//this.__showContainer(toJME, true);
 			this._showInfo(!toJME);
 		}
 	}
@@ -451,7 +457,7 @@
 		this._setSVG();
 	}
   
-	proto.__showContainer = function(tf, andShow) {
+	proto.__showContainer = function(tf, andShow) {	
 		var jmol = this._linkedApplet;
 		var mydiv = Jmol.$(jmol, "2dappletdiv");
 		if (this._isJava) {
@@ -492,7 +498,7 @@
 
   proto._getSmiles = function(withStereoChemistry) {
   	var s = (arguments.length == 0 || withStereoChemistry ? jme._applet.smiles() : jme._applet.nonisomericSmiles()).replace(/\:1/g,"");
-		s = s.replace(/H/g,"").replace(/\[\]/g,"").replace(/@\]/g,"@H]").replace(/\(\)/g,"");
+		s = s.replace(/@H/g,"@~").replace(/H/g,"").replace(/\[\]/g,"").replace(/\(\)/g,"").replace(/@~/g,"@H");
 		if (s.indexOf("\\") == 0 || s.indexOf("/") == 0)
 		  s= "[H]" + s;
 		return s;
