@@ -118,6 +118,11 @@
 				+ ';syncCallbackFunctionName Jmol._mySyncCallback;';	
 	}
 
+	proto._newApplet = function(viewerOptions) {
+		return (this._isPro ? new JSV.appletjs.JSVAppletPro(viewerOptions) 
+				: new JSV.appletjs.JSVApplet(viewerOptions));
+	}
+
 	proto._create = function(id, Info){
 
 		Jmol._setObject(this, id, Info);
@@ -133,6 +138,14 @@
 		Jmol._Applet._createApplet(this, Info, params);
 	}
 
+	proto._cover = function (doCover) {
+		// TODO: cover options here, including Java
+		if (!this._isJava)
+			this._newCanvas(false);
+		this._showInfo(false);
+		this._init();
+	};
+
 	proto._readyCallback = function(id, fullid, isReady, applet) {
 	 if (!isReady)
 			return; // ignore -- page is closing
